% File src/library/base/man/Syntax.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

% = is treated specially in the parser: see PR#14595

\name{Syntax}
\alias{Syntax}
\title{Operator Syntax and Precedence}
\description{
 \R の構文の概要と演算子の優先度を与える．
}
\details{
  以下の単項・二項演算子が定義されている．それらは優先度が高いものから
低いものへと並べられている．
  \tabular{ll}{
    \code{:: :::}\tab 名前空間中へのアクセス変数\cr
    \code{$ @}\tab 成分 / スロット抽出子\cr
    \code{[ [[}\tab 添字操作\cr
    \code{^}\tab 巾乗 (右から左へ)\cr
    \code{- +}\tab 単項のマイナスとプラス\cr
    \code{:}\tab 数列演算子\cr
    \code{\%any\%}\tab 特殊演算子(\code{\%\%} と \code{\%/\%} を含む)\cr
    \code{* /}\tab 乗算，除算\cr
    \code{+ -}\tab (二項の) 加算，減算\cr
    \code{< > <= >= == !=}\tab 順序と比較\cr
    \code{!}\tab 否定\cr
    \code{&  &&}\tab アンド\cr
    \code{| ||}\tab オア\cr
    \code{~}\tab 公式中で\cr
    \code{-> ->>}\tab 右辺への付値\cr
    \code{<- <<-}\tab 付値 (右から左へ)\cr
    \code{=}\tab 付値 (右から左へ)\cr
    \code{?}\tab ヘルプ (単項と二項)\cr
  }
  一つの表現式中では同意の優先度を持つ演算子は，
指示された箇所を除き，左から右へと評価される．
(\code{=} は必ずしも演算子ではないことを注意する．)

二項演算子 \code{::}, \code{:::}, \code{$} そして \code{@}
 は右辺に名前か文字列定数を必要とする．そして最初の二つはまた
それらを左辺にも必要とする．

  \bold{関連}節中のリンクは基本構文の他の殆どの様相を
カバーする．
}
\note{
  \R と S の間には本質的な優先度の違いがある．
特に，S では \code{?} は(二項の) \code{+ -} と同じ優先度を持つ．
そして \code{& && | ||} は等しい優先度を持つ．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{Arithmetic}}, \code{\link{Comparison}}, \code{\link{Control}},
  \code{\link{Extract}}, \code{\link{Logic}},
  \code{\link{NumericConstants}}, \code{\link{Paren}},
  \code{\link{Quotes}}, \code{\link{Reserved}}.

  マニュアル \sQuote{R Language Definition}．
}
\examples{
## 論理 AND ("&&") は OR ("||") より優先度が高い：
TRUE || TRUE && FALSE   # 次と同じ
TRUE || (TRUE && FALSE) # そして次と異なる
(TRUE || TRUE) && FALSE

## 特殊な演算子は "!" (論理l NOT) より優先度が高い．
## これを \%in\% に対して使うことが出来る：
! 1:10 \%in\% c(2, 3, 5, 7) # !(1:10 \%in\% c(2, 3, 5, 7)) と同じ
## しかしこの場合は "!( ... )" 型式を使うことを強く勧める!

## '=' は '<-' より優先度が低い．従ってそれらを混ぜて使うべきではない
##  (そして '<-' はともかくもより良いスタイルである)：
\donttest{## 従って，これは ("non-catchable") エラーになる
 x <- y = 5  #->  Error in (x <- y) = 5 : ....
}
}
\keyword{documentation}
\keyword{programming}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Syntax.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%% = is treated specially in the parser: see PR#14595
%
%\name{Syntax}
%\alias{Syntax}
%\title{Operator Syntax and Precedence}
%\description{
%  Outlines \R syntax and gives the precedence of operators.
%}
%\details{
%  The following unary and binary operators are defined.  They are listed
%  in precedence groups, from highest to lowest.
%  \tabular{ll}{
%    \code{:: :::}\tab access variables in a namespace\cr
%    \code{$ @}\tab component / slot extraction\cr
%    \code{[ [[}\tab indexing\cr
%    \code{^}\tab exponentiation (right to left)\cr
%    \code{- +}\tab unary minus and plus\cr
%    \code{:}\tab sequence operator\cr
%    \code{\%any\%}\tab special operators (including \code{\%\%} and \code{\%/\%})\cr
%    \code{* /}\tab multiply, divide\cr
%    \code{+ -}\tab (binary) add, subtract\cr
%    \code{< > <= >= == !=}\tab ordering and comparison\cr
%    \code{!}\tab negation\cr
%    \code{&  &&}\tab and\cr
%    \code{| ||}\tab or\cr
%    \code{~}\tab as in formulae\cr
%    \code{-> ->>}\tab rightwards assignment\cr
%    \code{<- <<-}\tab assignment (right to left)\cr
%    \code{=}\tab assignment (right to left)\cr
%    \code{?}\tab help (unary and binary)\cr
%  }
%  Within an expression operators of equal precedence are evaluated
%  from left to right except where indicated.  (Note that \code{=} is not
%  necessarily an operator.)
%
%  The binary operators \code{::}, \code{:::}, \code{$} and \code{@} require
%  names or string constants on the right hand side, and the first two
%  also require them on the left.
%
%  The links in the \bold{See Also} section cover most other aspects of
%  the basic syntax.
%}
%\note{
%  There are substantial precedence differences between \R and S.  In
%  particular, in S \code{?} has the same precedence as (binary) \code{+ -}
%  and \code{& && | ||} have equal precedence.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{Arithmetic}}, \code{\link{Comparison}}, \code{\link{Control}},
%  \code{\link{Extract}}, \code{\link{Logic}},
%  \code{\link{NumericConstants}}, \code{\link{Paren}},
%  \code{\link{Quotes}}, \code{\link{Reserved}}.
%
%  The \sQuote{R Language Definition} manual.
%}
%\examples{
%## Logical AND ("&&") has higher precedence than OR ("||"):
%TRUE || TRUE && FALSE   # is the same as
%TRUE || (TRUE && FALSE) # and different from
%(TRUE || TRUE) && FALSE
%
%## Special operators have higher precedence than "!" (logical NOT).
%## You can use this for \%in\% :
%! 1:10 \%in\% c(2, 3, 5, 7) # same as !(1:10 \%in\% c(2, 3, 5, 7))
%## but we strongly advise to use the "!( ... )" form in this case!
%
%
%## '=' has lower precedence than '<-' ... so you should not mix them
%##     (and '<-' is considered better style anyway):
%\donttest{## Consequently, this gives a ("non-catchable") error
% x <- y = 5  #->  Error in (x <- y) = 5 : ....
%}
%}
%\keyword{documentation}
%\keyword{programming}
%
\encoding{UTF8}
