% File src/library/base/man/Sys.localeconv.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Sys.localeconv}
\alias{localeconv}
\alias{Sys.localeconv}
\title{Find Details of the Numerical and Monetary Representations
  in the Current Locale}
\description{
  現在のロケールでの数値と通貨表現の詳細を得る．
}
\usage{
Sys.localeconv()
}
\details{
普通 \R は \env{LC_NUMERIC} の値を参照せずに動作するため，
小数点は '\code{.}' である．従ってこれらの成分の最初の三つは
もしローカルカテゴリ \code{LC_NUMERIC} を現在の \R セッション
中で(\R が正しく動作しない時)  \code{Sys.setlocale} を使って
設定している時だけ意味を持つ．

通貨成分は \code{LC_MONETARY} カテゴリが設定されている時だけ
既定でない値に設定される(\sQuote{例}を見よ)．
これはしばしば未設定である．どう設定するかは例を見よ．
}
\value{
  18の名前付き成分を持つ文字列ベクトル．意味の詳細については
自分の ISO C ドキュメントを見よ．

\R をロケールのサポート無しにコンパイルすることが可能である．
その場合値は \code{NULL} になる．
}
\seealso{
  ロケールの設定方法については \code{\link{Sys.setlocale}}．
}
\examples{
Sys.localeconv()
## C ロケールでの結果は
##    decimal_point     thousands_sep          grouping   int_curr_symbol
##              "."                ""                ""                ""
##  currency_symbol mon_decimal_point mon_thousands_sep      mon_grouping
##               ""                ""                ""                ""
##    positive_sign     negative_sign   int_frac_digits       frac_digits
##               ""                ""             "127"             "127"
##    p_cs_precedes    p_sep_by_space     n_cs_precedes    n_sep_by_space
##            "127"             "127"             "127"             "127"
##      p_sign_posn       n_sign_posn
##            "127"             "127"

## 自分の既定ロケールを試みる("C" かもしれない).
\donttest{old <- Sys.getlocale()
## カテゴリは設定されていないかもしれない：
## 次のようにすれば良いかもしれない，がサポートされていないかもしれない．
Sys.setlocale("LC_MONETARY", locale = "")
Sys.localeconv()
## もしくは自分自身で適当な値を設定する，例えば
Sys.setlocale("LC_MONETARY", "de_AT")
Sys.localeconv()
Sys.setlocale(locale = old)}

\dontrun{read.table("foo", dec=Sys.localeconv()["decimal_point"])}
}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Sys.localeconv.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Sys.localeconv}
%\alias{localeconv}
%\alias{Sys.localeconv}
%\title{Find Details of the Numerical and Monetary Representations
%  in the Current Locale}
%\description{
%  Get details of the numerical and monetary representations in the
%  current locale.
%}
%\usage{
%Sys.localeconv()
%}
%\details{
%  Normally \R is run without looking at the value of \env{LC_NUMERIC},
%  so the decimal point remains '\code{.}'.  So the first three of these
%  components will only be useful if you have set the locale category
%  \code{LC_NUMERIC} using \code{Sys.setlocale} in the current \R session
%  (when \R may not work correctly).
%
%  The monetary components will only be set to non-default values (see
%  the \sQuote{Examples} section if the \code{LC_MONETARY} category is
%  set.  It often is not set: set the examples for how to trigger setting it.
%}
%\value{
%  A character vector with 18 named components.  See your ISO C
%  documentation for details of the meaning.
%
%  It is possible to compile \R without support for locales, in which
%  case the value will be \code{NULL}.
%}
%\seealso{
%  \code{\link{Sys.setlocale}} for ways to set locales.
%}
%\examples{
%Sys.localeconv()
%## The results in the C locale are
%##    decimal_point     thousands_sep          grouping   int_curr_symbol
%##              "."                ""                ""                ""
%##  currency_symbol mon_decimal_point mon_thousands_sep      mon_grouping
%##               ""                ""                ""                ""
%##    positive_sign     negative_sign   int_frac_digits       frac_digits
%##               ""                ""             "127"             "127"
%##    p_cs_precedes    p_sep_by_space     n_cs_precedes    n_sep_by_space
%##            "127"             "127"             "127"             "127"
%##      p_sign_posn       n_sign_posn
%##            "127"             "127"
%
%## Now try your default locale (which might be "C").
%\donttest{old <- Sys.getlocale()
%## The category may not be set:
%## the following may do so, but it might not be supported.
%Sys.setlocale("LC_MONETARY", locale = "")
%Sys.localeconv()
%## or set an appropriate value yourself, e.g.
%Sys.setlocale("LC_MONETARY", "de_AT")
%Sys.localeconv()
%Sys.setlocale(locale = old)}
%
%\dontrun{read.table("foo", dec=Sys.localeconv()["decimal_point"])}
%}
%\keyword{utilities}
%
\encoding{UTF8}
