% File src/library/base/man/aperm.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{aperm}
%\title{配列の転置 Array Transposition}
\title{Array Transposition}
\alias{aperm}
\alias{aperm.default}
\alias{aperm.table}
\description{
  配列をその次元を並べ替えて転置する．オプションでサイズを変更する．
}
\usage{
aperm(a, perm, \dots)
\method{aperm}{default}(a, perm = NULL, resize = TRUE, \dots)
\method{aperm}{table}(a, perm = NULL, resize = TRUE, keep.class = TRUE, \dots)
}
\arguments{
  \item{a}{転置される配列．}
  \item{perm}{添字を並べ替えるベクトル．普通整数 \code{1:n} の並べ替えで，
 \code{n} は \code{a} の次元．\code{a} が名前付きの次元名を持てば，
これは長さ \code{n} の文字列ベクトルで良く，これらの名前の並べかえを与える．
既定(\code{perm} の長さがゼロなら常に)は次元を逆順にする．}
  \item{resize}{ベクトルはその要素が並べ替えられると同時にサイズも変更すべきかを
指示するフラグ(既定では \code{TRUE})．}
  \item{keep.class}{結果が \code{a} と同じクラスになることを指示する論理値．}
  \item{\dots}{メソッドへの潜在的追加引数．}
}
\value{
  配列 \code{a} の転置版で，添字が \code{perm} により並べ替えられている．
もし \code{resize} が \code{TRUE} ならば，配列はその要素が並べ替えられると同時に
その形も変更され，\code{dimnames} もまた並べ替えられる；
もし \code{resize = FALSE} なら返されるオブジェクトは \code{a} と同じ次元を持ち，
次元名は捨てられる．どちらの場合も他の属性は \code{a} からコピーされる．

関数 \code{t} は行列の転置のより早くて便利な方法を与える．
}
\author{Jonathan Rougier, \email{J.C.Rougier@durham.ac.uk} がより高速な
 C への移植を行った．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{行列の転置は \code{\link{t}}．}
\examples{
# 3次元配列 x の最初の二つの添字を入れ替える
x  <- array(1:24, 2:4)
xt <- aperm(x, c(2,1,3))
stopifnot(t(xt[,,2]) == x[,,2],
          t(xt[,,3]) == x[,,3],
          t(xt[,,4]) == x[,,4])

UCB <- aperm(UCBAdmissions, c(2,1,3))
UCB[1,,]
summary(UCB) # UCB は依然分割表
\dontshow{stopifnot(is.table(UCB))}
}
\keyword{array}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/aperm.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{aperm}
%\title{Array Transposition}
%\alias{aperm}
%\alias{aperm.default}
%\alias{aperm.table}
%\description{
%  Transpose an array by permuting its dimensions and optionally resizing
%  it.
%}
%\usage{
%aperm(a, perm, \dots)
%\method{aperm}{default}(a, perm = NULL, resize = TRUE, \dots)
%\method{aperm}{table}(a, perm = NULL, resize = TRUE, keep.class = TRUE, \dots)
%}
%\arguments{
%  \item{a}{the array to be transposed.}
%  \item{perm}{the subscript permutation vector, usually a permutation of
%    the integers \code{1:n}, where \code{n} is the number of dimensions
%    of \code{a}.  When \code{a} has named dimnames, it can be a
%    character vector of length \code{n} giving a permutation of those
%    names. The default (used whenever \code{perm} has zero length) is to
%    reverse the order of the dimensions.}
%  \item{resize}{a flag indicating whether the vector should be
%    resized as well as having its elements reordered (default \code{TRUE}).}
%  \item{keep.class}{logical indicating if the result should be of the
%    same class as \code{a}.}
%  \item{\dots}{potential further arguments of methods.}
%}
%\value{
%  A transposed version of array \code{a}, with subscripts permuted as
%  indicated by the array \code{perm}.  If \code{resize} is \code{TRUE},
%  the array is reshaped as well as having its elements permuted, the
%  \code{dimnames} are also permuted; if \code{resize = FALSE} then the
%  returned object has the same dimensions as \code{a}, and the dimnames
%  are dropped.  In each case other attributes are copied from \code{a}.
%
%  The function \code{t} provides a faster and more convenient way of
%  transposing matrices.
%}
%\author{Jonathan Rougier, \email{J.C.Rougier@durham.ac.uk} did the
%  faster C implementation.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{\code{\link{t}}, to transpose matrices.
%}
%\examples{
%# interchange the first two subscripts on a 3-way array x
%x  <- array(1:24, 2:4)
%xt <- aperm(x, c(2,1,3))
%stopifnot(t(xt[,,2]) == x[,,2],
%          t(xt[,,3]) == x[,,3],
%          t(xt[,,4]) == x[,,4])
%
%UCB <- aperm(UCBAdmissions, c(2,1,3))
%UCB[1,,]
%summary(UCB) # UCB is still a continency table
%\dontshow{stopifnot(is.table(UCB))}
%}
%\keyword{array}
%
\encoding{UTF8}
