% File src/library/base/man/c.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{c}
\title{Combine Values into a Vector or List}
\usage{
c(\dots, recursive = FALSE)
}
\alias{c}
\description{
  これはその引数を連結する総称的関数である．

  既定メソッドはその引数を連結してベクトルを作る．
  すべての引数は同一の型に強制変換され，それが結果の型になる．
  そして名前以外のすべての属性が取り除かれる．
}
\arguments{
  \item{\dots}{連結されるオブジェクト．}
  \item{recursive}{論理値．もし \code{recursive = TRUE} ならば関数は
    再帰的にリスト(そして対リスト)を下りそれらの要素すべてをベクトルに
    連結する．}
}
\details{
  出力の型は優先順位 NULL < raw < logical < integer < double < complex < character
  < list < expression で最高位の型になる．対リストはリストとして扱われるが，
  非ベクトル成分(名前や呼び出し)は一成分のリストとして扱われ，
  \code{recursive = TRUE} であっても非リスト化できない．

  \code{c} は時折その名前以外の属性を取り除くという副作用のために
  使われる．例えば配列をベクトルにする良うな場合である．
  \code{as.vector} はこれを行うより直感的な方法であるが，同時に名前も取り去る．
  既定以外のメソッドはこれを行うことを要求されないことも注意する
  (そしてこれらはほとんど確実にクラス属性を保存する)．

  これはプリミティブな関数である．
}
\value{
  \code{NULL}，表現式，または適当なモードのベクトル．
  (引数がなければ値は \code{NULL} である．)
}
\section{S4 メソッド}{
  この関数は S4 総称的であるが，引数リスト 
  \code{(x, ..., sive = FALSE)} を持つ．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  属性のないベクトルを作る \code{\link{unlist}} と \code{\link{as.vector}}．
}
\examples{
c(1,7:9)
c(1:5, 10.5, "next")

## 属性を取り除くために一つの引数で使用
x <- 1:4
names(x) <- letters[1:4]
x
c(x)          # 名前を持つ
as.vector(x)  # 名前無し
dim(x) <- c(2,2)
x
c(x)
as.vector(x)

## リストに付加：
ll <- list(A = 1, c = "C")
## 使用しないこと
c(ll, d = 1:3) # これは == c(ll, as.list(c(d = 1:3))
## しかしむしろ 
c(ll, d = list(1:3))  # c() は二つのリストを連結する

c(list(A = c(B = 1)), recursive = TRUE)

c(options(), recursive = TRUE)
c(list(A = c(B = 1, C = 2), B = c(E = 7)), recursive = TRUE)
}
\keyword{manip}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/c.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{c}
%\title{Combine Values into a Vector or List}
%\usage{
%c(\dots, recursive = FALSE)
%}
%\alias{c}
%\description{
%  This is a generic function which combines its arguments.
%
%  The default method combines its arguments to form a vector.
%  All arguments are coerced to a common type which is the type
%  of the returned value, and all attributes except names are removed.
%}
%\arguments{
%  \item{\dots}{objects to be concatenated.}
%  \item{recursive}{logical.  If \code{recursive = TRUE}, the function
%    recursively descends through lists (and pairlists) combining all
%    their elements into a vector.}
%}
%\details{
%  The output type is determined from the highest type of the components
%  in the hierarchy NULL < raw < logical < integer < double < complex < character
%  < list < expression.  Pairlists are treated as lists, but non-vector
%  components (such names and calls) are treated as one-element lists
%  which cannot be unlisted even if \code{recursive = TRUE}.
%
%  \code{c} is sometimes used for its side effect of removing attributes
%  except names, for example to turn an array into a vector.
%  \code{as.vector} is a more intuitive way to do this, but also drops
%  names.  Note too that methods other than the default are not required
%  to do this (and they will almost certainly preserve a class attribute).
%
%  This is a \link{primitive} function.
%}
%\value{
%  \code{NULL} or an expression or a vector of an appropriate mode.
%  (With no arguments the value is \code{NULL}.)
%}
%\section{S4 methods}{
%  This function is S4 generic, but with argument list
%  \code{(x, ..., recursive = FALSE)}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{unlist}} and \code{\link{as.vector}} to produce
%  attribute-free vectors.
%}
%\examples{
%c(1,7:9)
%c(1:5, 10.5, "next")
%
%## uses with a single argument to drop attributes
%x <- 1:4
%names(x) <- letters[1:4]
%x
%c(x)          # has names
%as.vector(x)  # no names
%dim(x) <- c(2,2)
%x
%c(x)
%as.vector(x)
%
%## append to a list:
%ll <- list(A = 1, c = "C")
%## do *not* use
%c(ll, d = 1:3) # which is == c(ll, as.list(c(d = 1:3))
%## but rather
%c(ll, d = list(1:3))  # c() combining two lists
%
%c(list(A = c(B = 1)), recursive = TRUE)
%
%c(options(), recursive = TRUE)
%c(list(A = c(B = 1, C = 2), B = c(E = 7)), recursive = TRUE)
%}
%\keyword{manip}
%
\encoding{UTF8}
