% File src/library/base/man/colnames.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{row+colnames}
\title{Row and Column Names}
\alias{rownames}
\alias{rownames<-}
\alias{colnames}
\alias{colnames<-}
\usage{
rownames(x, do.NULL = TRUE, prefix = "row")
rownames(x) <- value

colnames(x, do.NULL = TRUE, prefix = "col")
colnames(x) <- value
}
\description{
  行列風のオブジェクトの行名や列名を取り出したり設定したりする．
}
\arguments{
  \item{x}{行列風 \R オブジェクトで，\code{colnames} に対して少なくとも
    2次元を持つ．}
  \item{do.NULL}{論理値．もし \code{FALSE} で名前が \code{NULL} なら
    名前が作られる．}
  \item{prefix}{作られる名前用．}
  \item{value}{\code{\link{dimnames}(x)} の成分に対する適正な値．
    行列や配列に対してはこれは \code{NULL} か長さがゼロで無く適当な次元に
    等しい文字列ベクトル．}
}
\details{
  取り出し関数はすべての行列風オブジェクト \code{x} に対し意味のある何かをしようと
  試みる．もしオブジェクトが \code{\link{dimnames}} を持てば，最初の成分が
  行名として使われ，二番目の成分(もしあれば)が列名として使われる．
  データフレームに対しては \code{rownames} と \code{colnames} は
  結局それぞれ \code{\link{row.names}} と \code{\link{names}} を
  呼び出すが，後者が優先される．

  もし \code{do.NULL} が \code{FALSE} ならば，いかなるケースでも文字列ベクトル
  (長さが \code{\link{NROW}(x)} か \code{\link{NCOL}(x)}) が返され，
  もし次元名や対応する次元名の成分が \code{NULL} ならば単純な数に接頭辞
  \code{prefix} が付く．

  配列や行列に対する置き換えメソッドは \code{value} のベクトルと因子値を
  文字列に強制変換するるが，\code{as.character} に対するメソッドを
  選択適用しない．

  データフレームに対しては， \code{rownames} に対する \code{value} は
  重複がなく欠損しない(これは厳守される)文字列ベクトル，
  \code{colnames} に対しては(望ましくは)ユニークで
  構文解析的に適正な文字列なければならない．
  双方のケースで \code{value} は  \code{\link{as.character}} で
  強制変換され，\code{colnames} の設定は行名を文字列に変換する．
}
\note{
  もし置き換え版が次元名のない行列に対して呼び出されると，
  それらは適当な次元名を加える．しかし
\preformatted{    rownames(x)[3] <- "c"}
  のような構成は \code{x} が既に次元名を持つのでなければ動作しないかもしれない．
  なぜならこれは \code{rownames(x)} の \code{NULL} 値から長さ3の
  \code{value} を作りだすから．
}
\seealso{
  \code{\link{dimnames}},
  \code{\link{case.names}},
  \code{\link{variable.names}}.
}
\examples{
m0 <- matrix(NA, 4, 0)
rownames(m0)

m2 <- cbind(1, 1:4)
colnames(m2, do.NULL = FALSE)
colnames(m2) <- c("x","Y")
rownames(m2) <- rownames(m2, do.NULL = FALSE, prefix = "Obs.")
m2
}
\keyword{array}
\keyword{manip}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/colnames.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{row+colnames}
%\title{Row and Column Names}
%\alias{rownames}
%\alias{rownames<-}
%\alias{colnames}
%\alias{colnames<-}
%\usage{
%rownames(x, do.NULL = TRUE, prefix = "row")
%rownames(x) <- value
%
%colnames(x, do.NULL = TRUE, prefix = "col")
%colnames(x) <- value
%}
%\description{
%  Retrieve or set the row or column names of a matrix-like object.
%}
%\arguments{
%  \item{x}{a matrix-like \R object, with at least two dimensions for
%    \code{colnames}.}
%  \item{do.NULL}{logical. If \code{FALSE} and names are \code{NULL}, names are created.}
%  \item{prefix}{for created names.}
%  \item{value}{a valid value for that component of
%    \code{\link{dimnames}(x)}.  For a matrix or array this is either
%    \code{NULL} or a character vector of non-zero length equal to the
%    appropriate dimension.}
%}
%\details{
%  The extractor functions try to do something sensible for any
%  matrix-like object \code{x}.  If the object has \code{\link{dimnames}}
%  the first component is used as the row names, and the second component
%  (if any) is used for the column names.  For a data frame, \code{rownames}
%  and \code{colnames} eventually call \code{\link{row.names}} and
%  \code{\link{names}} respectively, but the latter are preferred.
%
%  If \code{do.NULL} is \code{FALSE}, a character vector (of length
%  \code{\link{NROW}(x)} or \code{\link{NCOL}(x)}) is returned in any
%  case, prepending \code{prefix} to simple numbers, if there are no
%  dimnames or the corresponding component of the dimnames is \code{NULL}.
%
%  The replacement methods for arrays/matrices coerce vector and factor
%  values of \code{value} to character, but do not dispatch methods for
%  \code{as.character}.
%
%  For a data frame, \code{value} for \code{rownames} should be a
%  character vector of non-duplicated and non-missing names (this is
%  enforced), and for \code{colnames} a character vector of (preferably)
%  unique syntactically-valid names.  In both cases, \code{value} will be
%  coerced by \code{\link{as.character}}, and setting \code{colnames}
%  will convert the row names to character.
%}
%\note{
%  If the replacement versions are called on a matrix without any
%  existing dimnames, they will add suitable dimnames.  But
%  constructions such as
%\preformatted{    rownames(x)[3] <- "c"}
%  may not work unless \code{x} already has dimnames, since this will
%  create a length-3 \code{value} from the \code{NULL} value of
%  \code{rownames(x)}.
%}
%\seealso{
%  \code{\link{dimnames}},
%  \code{\link{case.names}},
%  \code{\link{variable.names}}.
%}
%\examples{
%m0 <- matrix(NA, 4, 0)
%rownames(m0)
%
%m2 <- cbind(1, 1:4)
%colnames(m2, do.NULL = FALSE)
%colnames(m2) <- c("x","Y")
%rownames(m2) <- rownames(m2, do.NULL = FALSE, prefix = "Obs.")
%m2
%}
%\keyword{array}
%\keyword{manip}
%
\encoding{UTF8}
