% File src/library/base/man/factor.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{droplevels}
\title{droplevels}
\alias{droplevels}
\alias{droplevels.factor}
\alias{droplevels.data.frame}
\concept{categorical variable}
\concept{enumerated type}
\concept{category}
\description{
  関数 \code{droplevels} は因子から使われていない水準を取り去るのに使われる．
  もしくは，より普通には，データフレーム中の
  因子から取り去る．
}
\usage{
\S3method{droplevels}{factor}(x, \dots)
\S3method{droplevels}{data.frame}(x, except, \dots)
}
\arguments{
  \item{x}{未使用の水準を取り去るべきオブジェクト．}
  \item{\dots}{メソッドに引き渡される追加引数．}
  \item{except}{水準を取り去らない列の添字．}
}
\value{
  \code{droplevels} は \code{x} と同じクラスのオブジェクトを返す．}
\details{
  クラス \code{"factor"} に対するメソッドは本質的に \code{factor(x)} に等しい．

  \code{except} 引数は通常の添字規則に従う．
}

\note{ この関数は R 2.12.0 で導入された．これは当初データフレーム中の
  一つ又はそれ以上の因子が部分抽出後に縮小された水準集合からの要素だけを
  含むケースを意図していた．
  (部分抽出は一般に未使用の水準を取り去らないことを注意する)．
  既定では水準はデータフレーム中のすべての因子から取り除かれるが，
  \code{except} 引数はこれが好ましくない列を指定することを
  可能にする．
}

\seealso{
  データフレームの部分抽出は \code{\link{subset}}．
  因子の定義は \code{\link{factor}}．
  配列の次元の除去は \code{\link{drop}}．
  モデル式からの項の除去は \code{\link{drop1}}．
  因子の部分抽出は \code{\link{[.factor}}．
}
\examples{
aq <- transform(airquality, Month = factor(Month, labels = month.abb[5:9]))
aq <- subset(aq, Month != "Jul")
table(aq$Month)
table(droplevels(aq)$Month)
}
\keyword{category}
\keyword{NA}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/factor.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{droplevels}
%\title{droplevels}
%\alias{droplevels}
%\alias{droplevels.factor}
%\alias{droplevels.data.frame}
%\concept{categorical variable}
%\concept{enumerated type}
%\concept{category}
%\description{
%  The function \code{droplevels} is used to drop unused levels from a factor or, more commonly, from factors in a data frame.
%}
%\usage{
%\S3method{droplevels}{factor}(x, \dots)
%\S3method{droplevels}{data.frame}(x, except, \dots)
%}
%\arguments{
%  \item{x}{an object from which to drop unused factor levels.}
%  \item{\dots}{further arguments passed to methods}
%  \item{except}{indices of columns from which \emph{not} to drop levels}
%}
%\value{
%  \code{droplevels} returns an object of the same class as \code{x}}
%\details{
%  The method for class \code{"factor"} is essentially equivalent to \code{factor(x)}.
%
%  The \code{except} argument follow the usual indexing rules.
%}
%
%\note{ This function was introduced in R 2.12.0. It is primarily
%  intended for cases where one or more factors in a data frame
%  contains only elements from a reduced level set after
%  subsetting.  (Notice that subsetting does \emph{not} in general drop
%  unused levels).  By default, levels are dropped from all factors in a
%  data frame, but the \code{except} argument allows you to specify
%  columns for which this is not wanted.
%}
%
%\seealso{
%  \code{\link{subset}} for subsetting data frames.
%  \code{\link{factor}} for definition of factors.
%  \code{\link{drop}} for dropping array dimensions.
%  \code{\link{drop1}} for dropping terms from a model.
%  \code{\link{[.factor}} for subsetting of factors.
%}
%\examples{
%aq <- transform(airquality, Month = factor(Month, labels = month.abb[5:9]))
%aq <- subset(aq, Month != "Jul")
%table(aq$Month)
%table(droplevels(aq)$Month)
%}
%\keyword{category}
%\keyword{NA}
%
\encoding{UTF8}
