% File src/library/base/man/duplicated.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{duplicated}
\title{Determine Duplicate Elements}
\alias{duplicated}
\alias{duplicated.default}
\alias{duplicated.data.frame}
\alias{duplicated.matrix}
\alias{duplicated.array}
\alias{anyDuplicated}
\alias{anyDuplicated.default}
\alias{anyDuplicated.array}
\alias{anyDuplicated.matrix}
\alias{anyDuplicated.data.frame}
\description{
  \code{duplicated()} はベクトルやデータフレームのどの要素が
  より小さな添字の要素と重複しているかを決定し，どの要素(行)が重複しているかを
  示す論理値ベクトルを返す．

  \code{anyDuplicated(.)} は \code{any(duplicated(.))} に対する
  一般化されより効率的なショートカットである．
}
\usage{
duplicated(x, incomparables = FALSE, \dots)

\method{duplicated}{default}(x, incomparables = FALSE,
           fromLast = FALSE, nmax = NA, \dots)

\method{duplicated}{array}(x, incomparables = FALSE, MARGIN = 1,
           fromLast = FALSE, \dots)

anyDuplicated(x, incomparables = FALSE, \dots)
\method{anyDuplicated}{default}(x, incomparables = FALSE,
           fromLast = FALSE, \dots)
\method{anyDuplicated}{array}(x, incomparables = FALSE,
           MARGIN = 1, fromLast = FALSE, \dots)
}
\arguments{
  \item{x}{ベクトル，データフレーム，配列もしくは \code{NULL}．}
  \item{incomparables}{比較不可能な値のベクトル．
    \code{FALSE} は特殊値ですべての値が比較可能であることを意味し，
    そして恐らく既定以外のメソッドに対して受け入れられる唯一の
    値である．これは内部的に \code{x} と同じ型に変換される．}
  \item{fromLast}{重複が逆側から考慮されるべきかどうかを指示する論理値，
    つまり同一の要素の最後(又は最右翼)が \code{duplicated = FALSE} に
    対応する．}
  \item{nmax}{期待される最大のユニークな項目の数(1以上)．}
  \item{\dots}{特定のメソッド用の引数．}
  \item{MARGIN}{固定される配列のマージン：
    \code{\link{apply}} を見よ．そして \code{MARGIN = 0} は役に立つかもしれない．}
}
\details{
  これらは総称的な関数で，ベクトル(リスクを含む)，データフレーム，そして
  配列(含む行列)に対するメソッドを持つ．

  既定のメソッドに対して，そして \code{duplicated} と \code{anyDuplicated}
  に対する同値なメソッドが存在する限り 
  \code{anyDuplicated(x, ...)} は一般化された \code{any(duplicated(x, ...))}
  へのショートカットで，もしそうしたものがあれば最初の重複項目 \code{x[i]} の
  添字 \code{i} を返し，さもなければ \code{0} を返す．
  これらの挙動は \code{duplicated} と \code{anyDuplicated} の少なくともひとつが
  関連するメソッドを持てば異なるかもしれない．

  \code{duplicated(x, fromLast = TRUE)} は \code{rev(duplicated(rev(x)))} に
  同値であるが速い．
  
  データフレームメソッドは行の文字表現を \code{\\r} で分離してつなげたものに対して操作するので，
  もしデータフレームが埋め込みの改行を持つ文字列や
  文字列に正しくマップされない列を持てば不完全になるかもしれない．

  配列メソッドは，もし残りの次元が先の(\code{fromLast = TRUE} ならば後の)
  要素のそれらと同じ(行主導で)であれば，
  \code{MARGIN} で指定される副配列の各要素に対して計算を行う．
  これは最も普通には重複した行(既定)や列(\code{MARGIN = 2} の時)を
  見つけるのに使われる．
  \code{MARGIN = 0} は \code{x} と同じ次元を持つ配列を返すことを注意する．

  欠損値は等しいと見做されるが，\code{NaN} は \code{NA_real_} に等しくはない．

  \code{incomparables} 中の値は決して重複しているとマークされない．
  これはかなり少数の値の集合に対して使われることを意図しており，
  非常に大きな集合に対しては効率的ではない．

  一つ以上の列を持つデータフレームや，1以上の長さの次元を比較するときの配列や
  行列に対して使うときは，これは文字列表現の同等性をテストする．
  これは浮動小数点数の正確な同等性に賢明でない信頼を置く者を
  混乱させるであろう!

  文字列は入力のどれかが \code{"bytes"} (\code{\link{Encoding}} を見よ)
  とマークされていればバイト列として比較される．
  
  因子，論理値そしてバイトベクトルを除き，既定の \code{nmax = NA} は
  \code{nmax = length(x)} に等しい．サイズ \code{8*nmax} バイトのハッシュテーブルが
  確保されるので，\code{nmax} を適当に設定すれば大きな量のメモリーを節約できる．
  因子に対してはこれは自動的に
  \code{length(x)} と水準数プラス1(\code{NA} 用)の大きな方に設定される．
  もし \code{nmax} が小さすぎる値に設定されるとエラーになりやすい：
  \code{nmax = 1} は黙って無視される．

  \link{Long vectors} は \code{duplicated} の既定メソッドに対してはサポート
  されているが，\code{nmax} が提供されている時だけ有用かもしれない．
}
\value{
    \code{duplicated()}:
    ベクトル入力に対しては \code{x} と同じ長さの論理値ベクトル．
    データフレームに対しては各行に対して一つの要素の論理値ベクトル．
    行列や配列に対しては，\code{MARGIN = 0} であれば
    同じ次元と次元名の論理値配列．

    \code{anyDuplicated()}: 長さ1の整数又は実数値ベクトルで，
    もし重複があれば最初の重複の添字を値に持つ．さもなければ \code{0}．
}
\section{警告}{
  これをリストに使うと遅い可能性がある．特にもし要素が
  原子的ベクトルでない(\code{\link{vector}} を見よ)か，それらの属性だけが
  異なる場合がそうである．最悪の場合計算量は \eqn{O(n^2)} になる．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{\code{\link{unique}}.}
\examples{
x <- c(9:20, 1:5, 3:7, 0:8)
## ユニークな要素の取り出し
(xu <- x[!duplicated(x)])
## 同じこと，同じ要素であるが異なった順序：
(xu2 <- x[!duplicated(x, fromLast = TRUE)])

## xu == unique(x) であるが unique(x) はより効率的
stopifnot(identical(xu,  unique(x)),
          identical(xu2, unique(x, fromLast = TRUE)))

duplicated(iris)[140:143]

duplicated(iris3, MARGIN = c(1, 3))
anyDuplicated(iris) ## 143
\dontshow{% array & data.frame methods:
stopifnot(identical(anyDuplicated(iris), 143L),
          identical(anyDuplicated(iris3, MARGIN = c(1, 3)), 143L))
}
anyDuplicated(x)
anyDuplicated(x, fromLast = TRUE)
}
\keyword{logic}
\keyword{manip}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/duplicated.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{duplicated}
%\title{Determine Duplicate Elements}
%\alias{duplicated}
%\alias{duplicated.default}
%\alias{duplicated.data.frame}
%\alias{duplicated.matrix}
%\alias{duplicated.array}
%\alias{anyDuplicated}
%\alias{anyDuplicated.default}
%\alias{anyDuplicated.array}
%\alias{anyDuplicated.matrix}
%\alias{anyDuplicated.data.frame}
%\description{
%  \code{duplicated()} determines which elements of a vector or data frame are duplicates
%  of elements with smaller subscripts, and returns a logical vector
%  indicating which elements (rows) are duplicates.
%
%  \code{anyDuplicated(.)} is a \dQuote{generalized} more efficient
%  shortcut for \code{any(duplicated(.))}.
%}
%\usage{
%duplicated(x, incomparables = FALSE, \dots)
%
%\method{duplicated}{default}(x, incomparables = FALSE,
%           fromLast = FALSE, nmax = NA, \dots)
%
%\method{duplicated}{array}(x, incomparables = FALSE, MARGIN = 1,
%           fromLast = FALSE, \dots)
%
%anyDuplicated(x, incomparables = FALSE, \dots)
%\method{anyDuplicated}{default}(x, incomparables = FALSE,
%           fromLast = FALSE, \dots)
%\method{anyDuplicated}{array}(x, incomparables = FALSE,
%           MARGIN = 1, fromLast = FALSE, \dots)
%}
%\arguments{
%  \item{x}{a vector or a data frame or an array or \code{NULL}.}
%  \item{incomparables}{a vector of values that cannot be compared.
%    \code{FALSE} is a special value, meaning that all values can be
%    compared, and may be the only value accepted for methods other than
%    the default.  It will be coerced internally to the same type as
%       \code{x}.}
%  \item{fromLast}{logical indicating if duplication should be considered
%    from the reverse side, i.e., the last (or rightmost) of identical
%    elements would correspond to \code{duplicated = FALSE}.}
%  \item{nmax}{the maximum number of unique items expected (greater than one).}
%  \item{\dots}{arguments for particular methods.}
%  \item{MARGIN}{the array margin to be held fixed: see
%    \code{\link{apply}}, and note that \code{MARGIN = 0} maybe useful.}
%}
%\details{
%  These are generic functions with methods for vectors (including
%  lists), data frames and arrays (including matrices).
%
%  For the default methods, and whenever there are equivalent method
%  definitions for \code{duplicated} and \code{anyDuplicated},
%  \code{anyDuplicated(x, ...)} is a \dQuote{generalized} shortcut for
%  \code{any(duplicated(x, ...))}, in the sense that it returns the
%  \emph{index} \code{i} of the first duplicated entry \code{x[i]} if
%  there is one, and \code{0} otherwise.  Their behaviours may be
%  different when at least one of \code{duplicated} and
%  \code{anyDuplicated} has a relevant method.
%
%  \code{duplicated(x, fromLast = TRUE)} is equivalent to but faster than
%  \code{rev(duplicated(rev(x)))}.
%
%  The data frame method works by pasting together a character
%  representation of the rows separated by \code{\\r}, so may be imperfect
%  if the data frame has characters with embedded carriage returns or
%  columns which do not reliably map to characters.
%
%  The array method calculates for each element of the sub-array
%  specified by \code{MARGIN} if the remaining dimensions are identical
%  to those for an earlier (or later, when \code{fromLast = TRUE}) element
%  (in row-major order).  This would most commonly be used to find
%  duplicated rows (the default) or columns (with \code{MARGIN = 2}).
%  Note that \code{MARGIN = 0} returns an array of the same
%  dimensionality attributes as \code{x}.
%
%  Missing values are regarded as equal, but \code{NaN} is not equal to
%  \code{NA_real_}.
%
%  Values in \code{incomparables} will never be marked as duplicated.
%  This is intended to be used for a fairly small set of values and will
%  not be efficient for a very large set.
%
%  When used on a data frame with more than one column, or an array or
%  matrix when comparing dimensions of length greater than one, this
%  tests for identity of character representations.  This will
%  catch people who unwisely rely on exact equality of floating-point
%  numbers!
%
%  Character strings will be compared as byte sequences if any input is
%  marked as \code{"bytes"} (see \code{\link{Encoding}}).
%
%  Except for factors, logical and raw vectors the default \code{nmax = NA} is
%  equivalent to \code{nmax = length(x)}.  Since a hash table of size
%  \code{8*nmax} bytes is allocated, setting \code{nmax} suitably can
%  save large amounts of memory.  For factors it is automatically set to
%  the smaller of \code{length(x)} and the number of levels plus one (for
%  \code{NA}).  If \code{nmax} is set too small there is liable to be an
%  error: \code{nmax = 1} is silently ignored.
%
%  \link{Long vectors} are supported for the default method of
%  \code{duplicated}, but may only be usable if \code{nmax} is supplied.
%}
%\value{
%    \code{duplicated()}:
%    For a vector input, a logical vector of the same length as
%    \code{x}.  For a data frame, a logical vector with one element for
%    each row.  For a matrix or array, and when \code{MARGIN = 0}, a
%    logical array with the same dimensions and dimnames.
%
%    \code{anyDuplicated()}: an integer or real vector of length one with
%    value the 1-based index of the first duplicate if any, otherwise
%    \code{0}.
%}
%\section{Warning}{
%  Using this for lists is potentially slow, especially if the elements
%  are not atomic vectors (see \code{\link{vector}}) or differ only
%  in their attributes.  In the worst case it is \eqn{O(n^2)}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{\code{\link{unique}}.}
%\examples{
%x <- c(9:20, 1:5, 3:7, 0:8)
%## extract unique elements
%(xu <- x[!duplicated(x)])
%## similar, same elements but different order:
%(xu2 <- x[!duplicated(x, fromLast = TRUE)])
%
%## xu == unique(x) but unique(x) is more efficient
%stopifnot(identical(xu,  unique(x)),
%          identical(xu2, unique(x, fromLast = TRUE)))
%
%duplicated(iris)[140:143]
%
%duplicated(iris3, MARGIN = c(1, 3))
%anyDuplicated(iris) ## 143
%\dontshow{% array & data.frame methods:
%stopifnot(identical(anyDuplicated(iris), 143L),
%          identical(anyDuplicated(iris3, MARGIN = c(1, 3)), 143L))
%}
%anyDuplicated(x)
%anyDuplicated(x, fromLast = TRUE)
%}
%\keyword{logic}
%\keyword{manip}
%
\encoding{UTF8}
