% File src/library/base/man/dynload.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{dyn.load}
\alias{dyn.load}
\alias{dyn.unload}
\alias{is.loaded}
#ifdef windows
\alias{DLLpath}
#endif
\title{Foreign Function Interface}
\description{
  DLL (共有オブジェクトとも呼ばれる)をロードしたりアンロードする．そして
  C 関数や Fortran サブルーティンが利用できるか検査する．
}
\usage{
dyn.load(x, local = TRUE, now = TRUE, ...)
dyn.unload(x)

is.loaded(symbol, PACKAGE = "", type = "")
}
\arguments{
  \item{x}{DLL へのパス名を与える文字列．DLL はまたダイナミック共有オブジェクトとも呼ばれる．
    (これがどういう意味かは\sQuote{詳細}を見よ．)}
  \item{local}{DLL 中のシンボルはそれら自体の局所的テーブルに保管され DLL を
    縦断し共有されないか，それとも大局的なシンボルテーブルに付け加えられるかを
    制御する論理値．これが有効かどうかはシステム依存である．
     Windows では無視される．
  }
  \item{now}{すべてのシンボルがライブラリのロード直後に解決される
    (そして再配置される)か，それらが使われるまで保留するかを制御する論理値．
    この制御は開発者がライブラリが完全ですべての必要ないんぼるを持つかどうか
    検査したり，ユーザが欠損シンボルを無視するのに役にたつ．
    これが有効かどうかはシステム依存である．Windows では無視される．
  }
  \item{\dots}{さらなる拡張のための追加引数．
    Windows では下の \sQuote{Windows} 節を見よ．
  }
  \item{symbol}{シンボル名を与える文字列．}
  \item{PACKAGE}{もし与えられれば，\code{name} の探索をこの引数で与えられる
    DLL (プラス便宜的な拡張，
    \file{.so}, \file{.sl}, \file{.dll}, \dots)に制限する．これは
    パッケージに対する安全性を加えることを意図しており，
    この引数を使うことで他のパッケージがそれらの外部シンボルを無視することを
    保証することが出来る．これは
    \code{\link{.C}}, \code{\link{.Call}},
    \code{\link{.Fortran}} そして \code{\link{.External}} 関数中と同じように
    使われる．}
  \item{type}{探すべきシンボルの型：任意(既定値の \code{""}), \code{"Fortran"},
    \code{"Call"} 又は \code{"External"}．}
}
\details{
  \code{dyn.load} がロードしたオブジェクトはすべての
  プラットフォームで \sQuote{dynamically
    loadable libraries} (\sQuote{DLL} と省略される) と呼ばれる．
  OS X は例外でこの単語は別種のオブジェクトを指す．
  Unix風システムではこれらはまた \sQuote{dynamic
    shared objects} (\sQuote{DSO})，または単に \sQuote{shared objects}
  と呼ばれる．(POSIX 標準は \sQuote{executable object file} と呼ぶが，
  他のどれもが使わない．)

  適当な DLL の作成とインストールについては \sQuote{参考} 節と，
  マニュアル \sQuote{Writing R Extensions} と
  \sQuote{R Installation and Administration} を見よ．

  不幸にもごく僅かなプラットフォーム(例えば Compaq Tru64) は
  \code{PACKAGE} 引数を正確に処理せず，\R にリンクされたシンボルを
  不正確に見つけるかもしれない．

  \code{dyn.load} への追加引数は POSIX システムでは \code{dlopen()} ルーチンへの
  モード引数の異なった様相を反映する．
  これらはユーザが個別のライブラリに対するロードプロセスに対する
  より大きな制御を行えるように提供されている．一般に
  既定値は適切であり，十分な理由と意味を理解している場合だけそれらを
  上書きすべきである．

  (Unixでは) 
  引数 \code{local} は DLL 中に付加されたシンボルが他の DLL にも
  見えるかどうかを制御することを許す．シンボルをそれら自体の名前空間中に
  保持することは良い作法であるが，関連する\sQuote{章}を跨ってシンボルを共有することは
  多くの場合に有益である．
  加えて，プラットフォームとOSのバージョンによっては，
  あるライブラリはすべてのシンボルを成功裏に解決するにはそれらのシンボルを
  大局的にロードする必要がある．

  \code{now} 引数を \code{FALSE} とすることで遅延ロードを使うことによる
  可能な副作用に注意すべきである．欠損したシンボルを持つルーティンが呼び出されると，
  プロセスは即座に停止する．意図されている使い道は，ライブラリの開発者が値 
  \code{TRUE} を使った呼び出しですべてのシンボルが実際に解決されているかを
  使って検査することと，通常のユーザが \code{FALSE} を用いた呼び出しで
  欠損シンボルを無視し利用可能なものが呼び出せることである．

  これらを加えた当初の動機は Java の仮想マシンライブラリの
  \code{_init()} ルーチン中のそうした停止を避けるためである．
  しかしながら，局所的にロードされたシンボルは他の DLL からは
  (恐らく読み込めず)利用できないかもしれない．
  大局的なテーブルに加えられたものはアプリケーションの他のすべての
  要素から利用可能であり，従って二つの異なった DLL を跨って共有できる．

  ある種(非常に古い)のシステムは局所/大局的そして遅延/即座の解決の
  (明示的な)サポートを提供しない．これは微妙なバグの源になり得る．
  サポートされないオプションが使われると警告メッセージが発せられるように
  手配することが出来る．これは \code{\link{options}} 関数を使い
  オプション \code{verbose} か \code{warn} をゼロ以外に設定することで
  なされる．

  幾つかの例を持つこれらの追加引数に関する短い議論が
  \url{http://cm.bell-labs.com/stat/duncan/R/dynload}
  にある．

  (Windows では) 
  外部コードは浮動小数点の制御ワードを変更してはならないが，
  多くの DLL そうする．普通の変更はそれが \R 既定の64ビット精度の代わりに
  53ビット精度を使うように設定することである．もしくは
  幾つかの例外のマスクを外す．\code{dyn.load} はそうした変更を検知し
  \R の制御ワードを既定値の16進数 8001F に戻す．
  これは DLL の不良動作を起こす可能性がある；もしそうならば
  制御ワード自体を保存し回復するように書きなおす必要がある．
  もし \code{warn.FPU} が \code{\link{options}} 関数を使い \code{TRUE} に
  設定されれば警告が出る．(もし警告が制御ワードが 8001F 以外の
  値に変更されたと報告するならば，状況を Windows の保守管理者に
  報告してほしい：それは恐らく内部的なバグを示唆している．)
}
\value{
  関数 \code{dyn.load} は指定された DLL を実行 \R イメージにリンクするという
  副次効果のために使われる．そうすると \code{.C},
  \code{.Call}, \code{.Fortran} そして \code{.External} への呼び出しは
  ライブラリに含まれるコンパイル済みの C 関数や Fortran サブルーチンを
  実行するのに使うことが出来る．
  \code{dyn.load} の返り値はクラス \code{DLLInfo} のオブジェクトである．
  このクラスに関する情報は \code{\link{getLoadedDLLs}} を見よ．

  関数 \code{dyn.unload} は DLL のリンクを解除する．同じ名前の DLL のロード取り消しと
  再ロードは上手く行くこともあれば行かないこともある：
  Solaris ではロードされた最初のバージョンを使う．

  \code{is.loaded} はシンボル名がロードされており検索可能かどうか，
  従って \code{.C} や \code{.Fortran} や \code{.Call} や \code{.External} 
  中の \code{.NAME} 引数に対する文字列値として使えるかどうか，を検査する．
  もし四つの呼び出し関数のどれかが \code{type} が指定されない限り
  エントリーポイントを使用するのに成功すれば成功することになる．
  (Fortran のシンボルがどのようにマップされるかについては \code{\link{.Fortran}} を見よ．)
  基本パッケージ中のシンボルは検索可能ではないことを注意しよう．
  他のパッケージもそのようにマークすることが出来る．
}
\note{
  \code{is.loaded} は \code{.C} 等に与える名前を必要とし，
  (S に於けるような) 廃止された関数 \code{symbol.C} や \code{symbol.For}
  によって再マップされるものではない．

  DLL の作成とその実行プログラムへの実行時リンクは非常に
  プラットフォーム依存である．現在ではこれを行う C サブルーティンコール
  \code{dlopen} が POSIX I標準になってきているため，プロセスは少々簡略化されてきている．
  Unix 風システムでは \code{dyn.load} は \code{dlopen} 機構を使い，
  それをサポートするすべてのプラットフォームで動作するはずである．
  Windows では DLL をロードするのに標準的機構 
  (\code{LoadLibrary})を使う．

  Unix 風システムでの DLL のロードに対するオリジナルのコードは Heiner Schwarte により
  提供された．
}
\section{Windows}{
  \sQuote{DLL をロードする標準的機構}はどこに DLL があるか
  の探索順序(そのほうが好ましいが，もし絶対パスとして与えられなければ)と，
  どこで依存 DLL が見つかるかを含む．
  この検索パスは Windows のバージョンとセキュリティ設定に依存するが，
  Windows XP SP1 以降のバージョンでは次のようになる
  \itemize{
    \item アプリケーションが起動されたディレクトリ．
    \item 様々なシステムディレクトリ．例えば
    \file{c:/Windows/system32}, \file{c:/Windows/system} そして
    \file{c:/Windows}．
    \item 現在のディレクトリ．
    \item 環境変数  \env{PATH} で与えられる実行プログラムに対する検索パスに沿って．
  }

  パッケージはしばしば依存 DLL をそれらの \file{libs} ディレクトリに
  提供することを要求すし，これを \env{PATH} 変数の設定で行う
  (最近の \R のバージョンでは \code{\link{library.dynam}} がそれを
  自動的に行う)が，DLL の検索順序は DLL が起動ディレクトリとシステム
  ディレクトリにあることが好ましいことを意味する．
  Windows XP SP1 とそれ以降では検索順序を変更する方法がある．
  もし引数 \code{DLLpath} が \code{dyn.load} に提供されると，後者は
  \code{DLLpath} の値を二番目の位置に挿入するために Windows のシステムコール
  \code{SetDllDirectory} を利用し，そして \code{dyn.load} 呼び出しの持続期間中
  現在のディレクトリを取り除く．
  (この方法では唯ひとつのディレクトリだけが挿入できることを注意する．)

  ユーザは次のようなメッセージに混乱させられるかもしれない
\preformatted{
 error: unable to load shared object
 '.../library/rJava/libs/x64/rJava.dll':
 LoadLibrary failure:  The specified module could not be found.
}
   最後の行は Windows (\R ではない) の診断である：見つけられなかった \sQuote{module}
   は \file{rJava.dll} ではなく
   Windows が探している何か(ここでは恐らく Java DLL)である：もし運が良ければ
   より詳細を示すダイアローグボックスが与えられる．
}
\section{警告}{
  \code{\link{library.dynam}} によりロードされた DLL に関して \code{dyn.unload}
  を使ってはならない：\cr
  \code{\link{library.dynam.unload}} を使う．
  これはシステムの段取りに対して必要になる．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  パッケージの \code{\link{.onLoad}} 初期化内部で使うには
  \code{\link{library.dynam}}．

  適当な DLL を作るには \code{\link{SHLIB}}．

  \code{\link{.C}},
  \code{\link{.Fortran}},
  \code{\link{.External}},
  \code{\link{.Call}}.
}
\examples{
## R >= 3.0.0 ではこれらすべてが偽であることが期待される．
is.loaded("supsmu") # stats 中の Fortran エントリーポイント
is.loaded("supsmu", "stats", "Fortran")
is.loaded("PDF", type = "External") # grDevices 中の pdf() デバイス
}
\keyword{interface}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/dynload.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{dyn.load}
%\alias{dyn.load}
%\alias{dyn.unload}
%\alias{is.loaded}
%#ifdef windows
%\alias{DLLpath}
%#endif
%\title{Foreign Function Interface}
%\description{
%  Load or unload DLLs (also known as shared objects), and test whether a
%  C function or Fortran subroutine is available.
%}
%\usage{
%dyn.load(x, local = TRUE, now = TRUE, ...)
%dyn.unload(x)
%
%is.loaded(symbol, PACKAGE = "", type = "")
%}
%\arguments{
%  \item{x}{a character string giving the pathname to a DLL, also known
%    as a dynamic shared object.  (See \sQuote{Details} for what these
%    terms mean.)}
%  \item{local}{a logical value controlling whether the symbols in the
%    DLL are stored in their own local table and not shared
%    across DLLs, or added to the global symbol table.  Whether this has
%    any effect is system-dependent.
%#ifdef windows
%    It is ignored on Windows.
%#endif
%  }
%  \item{now}{a logical controlling whether all symbols are resolved (and
%    relocated) immediately the library is loaded or deferred until they
%    are used.  This control is useful for developers testing whether a
%    library is complete and has all the necessary symbols, and for users
%    to ignore missing symbols.  Whether this has any effect is system-dependent.
%#ifdef windows
%    It is ignored on Windows.
%#endif
%  }
%  \item{\dots}{other arguments for future expansion.
%#ifdef windows
%    See section \sQuote{Windows} below.
%#endif
%  }
%  \item{symbol}{a character string giving a symbol name.}
%  \item{PACKAGE}{if supplied, confine the search for the \code{name} to
%    the DLL given by this argument (plus the conventional extension,
%    \file{.so}, \file{.sl}, \file{.dll}, \dots).  This is intended to
%    add safety for packages, which can ensure by using this argument
%    that no other package can override their external symbols.  This is
%    used in the same way as in \code{\link{.C}}, \code{\link{.Call}},
%    \code{\link{.Fortran}} and \code{\link{.External}} functions.}
%  \item{type}{The type of symbol to look for: can be any (\code{""}, the
%    default), \code{"Fortran"}, \code{"Call"} or \code{"External"}.}
%}
%\details{
%  
%  The objects \code{dyn.load} loads are called \sQuote{dynamically
%    loadable libraries} (abbreviated to \sQuote{DLL}) on all platforms
%  except OS X, which uses the term for a different sort
%  of object.  On Unix-alikes they are also called \sQuote{dynamic
%    shared objects} (\sQuote{DSO}), or \sQuote{shared objects} for
%  short.  (The POSIX standards use \sQuote{executable object file},
%  but no one else does.)
%
%  See \sQuote{See Also} and the \sQuote{Writing R Extensions} and
%  \sQuote{R Installation and Administration} manuals for how to create
%  and install a suitable DLL.
%
%  Unfortunately a very few platforms (e.g., Compaq Tru64) do not handle
%  the \code{PACKAGE} argument correctly, and may incorrectly find
%  symbols linked into \R.
%
%  The additional arguments to \code{dyn.load} mirror the different
%  aspects of the mode argument to the \code{dlopen()} routine on POSIX
%  systems.  They are available so that users can exercise greater control
%  over the loading process for an individual library.  In general, the
%  default values are appropriate and you should override them only if
%  there is good reason and you understand the implications.
%
%#ifdef unix
%  The \code{local} argument allows one to control whether the symbols in
%  the DLL being attached are visible to other DLLs.  While maintaining
%  the symbols in their own namespace is good practice, the ability to
%  share symbols across related \sQuote{chapters} is useful in many
%  cases.  Additionally, on certain platforms and versions of an
%  operating system, certain libraries must have their symbols loaded
%  globally to successfully resolve all symbols.
%
%  One should be careful of the potential side-effect of using lazy
%  loading via the \code{now} argument as \code{FALSE}.  If a routine is
%  called that has a missing symbol, the process will terminate
%  immediately.  The intended use is for library developers to call with
%  value \code{TRUE} to check that all symbols are actually resolved and
%  for regular users to call with \code{FALSE} so that missing symbols
%  can be ignored and the available ones can be called.
%
%  The initial motivation for adding these was to avoid such termination
%  in the \code{_init()} routines of the Java virtual machine library.
%  However, symbols loaded locally may not be (read probably) available
%  to other DLLs.  Those added to the global table are available to all
%  other elements of the application and so can be shared across two
%  different DLLs.
%
%  Some (very old) systems do not provide (explicit) support for
%  local/global and lazy/eager symbol resolution.  This can be the source
%  of subtle bugs.  One can arrange to have warning messages emitted when
%  unsupported options are used.  This is done by setting either of the
%  options \code{verbose} or \code{warn} to be non-zero via the
%  \code{\link{options}} function.
%
%  There is a short discussion of these additional arguments with some
%  example code available at
%  \url{http://cm.bell-labs.com/stat/duncan/R/dynload}.
%#endif
%#ifdef windows
%
%  External code must not change the floating point control word, but
%  many DLLs do so.  Common changes are to set it to use 53 bit
%  precision instead of R's default 64 bit precision, or to unmask
%  some exceptions.  \code{dyn.load} detects such changes,
%  and restores R's control word to its default value of hex 8001F.
%  This may cause the DLL to malfunction; if so, it should be rewritten
%  to save and restore the control word itself.  If \code{warn.FPU}
%  is set to \code{TRUE} using the \code{\link{options}} function,
%  a warning will be printed.  (If the warning says
%  that the control word was changed from some other value than 8001F,
%  please report the circumstances to the Windows maintainers:
%  that probably indicates an internal bug.)
%#endif
%}
%\value{
%  The function \code{dyn.load} is used for its side effect which links
%  the specified DLL to the executing \R image.  Calls to \code{.C},
%  \code{.Call}, \code{.Fortran} and \code{.External} can then be used to
%  execute compiled C functions or Fortran subroutines contained in the
%  library.  The return value of \code{dyn.load} is an object of class
%  \code{DLLInfo}.  See \code{\link{getLoadedDLLs}} for information about
%  this class.
%
%  The function \code{dyn.unload} unlinks the DLL.  Note that unloading a
%  DLL and then re-loading a DLL of the same name may or may not work: on
%  Solaris it uses the first version loaded.
%
%  \code{is.loaded} checks if the symbol name is loaded \emph{and
%  searchable} and hence available for use as a character string value
%  for argument \code{.NAME} in \code{.C} or \code{.Fortran} or
%  \code{.Call} or \code{.External}.  It will succeed if any one of the
%  four calling functions would succeed in using the entry point unless
%  \code{type} is specified.  (See \code{\link{.Fortran}} for how Fortran
%  symbols are mapped.)  Note that symbols in base packages are not
%  searchable, and other packages can be so marked.
%}
%\note{
%  \code{is.loaded} requires the name you would give to \code{.C} etc
%  and \strong{not} (as in S) that remapped by the defunct functions
%  \code{symbol.C} or \code{symbol.For}.
%
%  The creation of DLLs and the runtime linking of them into executing
%  programs is very platform dependent.  In recent years there has been
%  some simplification in the process because the C subroutine call
%  \code{dlopen} has become the POSIX standard for doing this.  Under
%  Unix-alikes \code{dyn.load} uses the \code{dlopen} mechanism and
%  should work on all platforms which support it.  On Windows it uses the
%  standard mechanism (\code{LoadLibrary}) for loading DLLs.
%
%  The original code for loading DLLs in Unix-alikes was provided by
%  Heiner Schwarte.
%}
%#ifdef windows
%\section{Windows}{
%  The \sQuote{standard mechanisms for loading DLLs} include a
%  search order for where a DLL is found (if not given as an absolute
%  path, which is preferred), \emph{and} of where its dependent DLLs will
%  be found.  This search path depends on the version of Windows and its
%  security settings, but for versions since Windows XP SP1 it is
%  \itemize{
%    \item The directory from which the application was launched.
%    \item The various system directories,
%    e.g.\sspace{}\file{c:/Windows/system32}, \file{c:/Windows/system} and
%    \file{c:/Windows}.
%    \item The current directory.
%    \item Along the search path for executables given by the environment
%    variable \env{PATH}.
%  }
%
%  Packages often want to supply dependent DLLs in their \file{libs}
%  directory, and do this by setting the \env{PATH} variable
%  (\code{\link{library.dynam}} does that automatically in recent
%  versions of \R), but the DLL search order means that DLLs in the
%  launch directory and in system directories will be preferred.  On
%  Windows XP SP1 and later there is a way to modify the search order.
%  If argument \code{DLLpath} is supplied to \code{dyn.load}, the latter
%  makes use of the Windows system call \code{SetDllDirectory} to insert
%  the value of \code{DLLpath} in second place, and removes the current
%  directory, for the duration of that \code{dyn.load} call.  (Note that
%  only one directory can be inserted in this way.)
%
%  Users have been confused by messages like
%\preformatted{
% error: unable to load shared object
% '.../library/rJava/libs/x64/rJava.dll':
% LoadLibrary failure:  The specified module could not be found.
%}
%   The final line is a Windows (not \R) diagnostic: the \sQuote{module}
%   that could not be found is not \file{rJava.dll} but something else
%   Windows is looking for (here most likely Java DLLs): if you are lucky
%   there will be a dialog box with more details.
%}
%#endif
%\section{Warning}{
%  Do not use \code{dyn.unload} on a DLL loaded by
%  \code{\link{library.dynam}}: use \code{\link{library.dynam.unload}}.
%  This is needed for system housekeeping.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{library.dynam}} to be used inside a package's
%  \code{\link{.onLoad}} initialization.
%
%  \code{\link{SHLIB}} for how to create suitable DLLs.
%
%  \code{\link{.C}},
%  \code{\link{.Fortran}},
%  \code{\link{.External}},
%  \code{\link{.Call}}.
%}
%\examples{
%## expect all of these to be false in R >= 3.0.0.
%is.loaded("supsmu") # Fortran entry point in stats
%is.loaded("supsmu", "stats", "Fortran")
%is.loaded("PDF", type = "External") # pdf() device in grDevices
%}
%\keyword{interface}
%
\encoding{UTF8}
