% File src/library/base/man/encodeString.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2008 R Core Team
% Distributed under GPL 2 or later

\name{encodeString}
\alias{encodeString}
\title{
  Encode Character Vector as for Printing
}
\description{
  \code{encodeString} は文字列中の文字列を
  \code{print.default} が行うのと同じようにエスケープする．
  そしてオプションでエンコードされた文字列を欄幅に合わせる．
}
\usage{
encodeString(x, width = 0, quote = "", na.encode = TRUE,
             justify = c("left", "right", "centre", "none"))
}
\arguments{
  \item{x}{文字列ベクトルもしくはそうしたものに
    \code{\link{as.character}} で変換できるもの．}
  \item{width}{整数：最初の欄幅．もし \code{NULL} か
    \code{NA} なら，これは \code{x} の任意の要素に対して必要な最大幅とされる．}
  \item{quote}{文字：もしあれば引用符．}
  \item{na.encode}{論理値：\code{NA} 文字をエンコードするか?}
  \item{justify}{文字列：部分マッチが許される．もし最小の欄幅まで
    埋めることが必要ならどのように空白を挿入するか?
    \code{format.default} との一貫性のため \code{justify == "none"} は \code{width = 0} に同値．}
}
\details{
  これはバックスラッシュと \samp{\\a} (ベル),
  \samp{\\b} (バックスペース), \samp{\\f} (復帰), \samp{\\n} (行替え),
  \samp{\\r} (改行), \samp{\\t} (タブ) and \samp{\\v}
  (垂直タブ) のような制御文字，及び1バイトロケール中の任意のプリント不可能な文字
  をエスケープする．後者は8進数表現でプリントされる(先頭に0が付く \samp{\\xyz})．.

  どの文字がプリント不可能かは現在のロケールに依存する．
  Windows が報告するプリント可能な文字は信頼できず，従って
  そこではすべての他の制御文字はプリント不可能と見做され，
  そしてすべてのコード 32--255 の文字は1バイトロケールではプリント
  可能とされる．
  多倍長ロケールでプリント不可能な文字がどのように処理されるかについては
  \code{\link{print.default}} を見よ．

  もし \code{quote} が単引用符もしくは二重引用符ならば，同じタイプのすべての
  埋め込み引用符はエスケープされる．行末揃えは引用化文字列に対して行われ，
  従ってエスケープは引用符の外側に加えられる．
}
\note{
  \code{width} に対する既定値は \code{format.default} と異なる．
  これは文字列ベクトルに対して同様のことを行うがエンコーディングはなく
  エスケープを使う．
}
\value{
  \code{x} と同じ
  長さの文字列ベクトルで，同じ属性(名前と次元を含む)を持つがクラスは設定されていない．

  \R 3.0.0 からマークされた UTF-8 エンコーディングは保存される．
}
\seealso{
  \code{\link{print.default}}
}
\examples{
x <- "ab\bc\ndef"
print(x)
cat(x) # エスケープを解釈
cat(encodeString(x), "\n", sep = "") # print() へ同様

factor(x) # 水準のプリントにはこれを使う

x <- c("a", "ab", "abcde")
encodeString(x, width = NA) # left justification
encodeString(x, width = NA, justify = "c")
encodeString(x, width = NA, justify = "r")
encodeString(x, width = NA, quote = "'", justify = "r")
}
\keyword{ utilities }

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/encodeString.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2008 R Core Team
%% Distributed under GPL 2 or later
%
%\name{encodeString}
%\alias{encodeString}
%\title{
%  Encode Character Vector as for Printing
%}
%\description{
%  \code{encodeString} escapes the strings in a character vector in the
%  same way \code{print.default} does, and optionally fits the encoded
%  strings within a field width.
%}
%\usage{
%encodeString(x, width = 0, quote = "", na.encode = TRUE,
%             justify = c("left", "right", "centre", "none"))
%}
%\arguments{
%  \item{x}{A character vector, or an object that can be coerced to one
%    by \code{\link{as.character}}.}
%  \item{width}{integer: the minimum field width.  If \code{NULL} or
%    \code{NA}, this is taken to be the largest field width needed for
%    any element of \code{x}.}
%  \item{quote}{character: quoting character, if any.}
%  \item{na.encode}{logical: should \code{NA} strings be encoded?}
%  \item{justify}{character: partial matches are allowed.  If padding to
%    the minimum field width is needed, how should spaces be inserted?
%    \code{justify == "none"} is equivalent to \code{width = 0}, for
%    consistency with \code{format.default}.}
%}
%\details{
%  This escapes backslash and the control characters \samp{\\a} (bell),
%  \samp{\\b} (backspace), \samp{\\f} (formfeed), \samp{\\n} (line feed),
%  \samp{\\r} (carriage return), \samp{\\t} (tab) and \samp{\\v}
%  (vertical tab) as well as any non-printable characters in a
%  single-byte locale, which are printed in octal notation (\samp{\\xyz}
%  with leading zeroes).
%
%  Which characters are non-printable depends on the current locale.
%  Windows' reporting of printable characters is unreliable, so there all
%  other control characters are regarded as non-printable, and all
%  characters with codes 32--255 as printable in a single-byte locale.
%  See \code{\link{print.default}} for how non-printable characters are
%  handled in multi-byte locales.
%
%  If \code{quote} is a single or double quote any embedded quote of the
%  same type is escaped.  Note that justification is of the quoted
%  string, hence spaces are added outside the quotes.
%}
%\note{
%  The default for \code{width} is different from \code{format.default},
%  which does similar things for character vectors but without encoding
%  using escapes.
%}
%\value{
%  A character vector of the same length as \code{x}, with the same
%  attributes (including names and dimensions) but with no class set.
%
%  As from \R 3.0.0, marked UTF-8 encodings are preserved.
%}
%\seealso{
%  \code{\link{print.default}}
%}
%\examples{
%x <- "ab\bc\ndef"
%print(x)
%cat(x) # interprets escapes
%cat(encodeString(x), "\n", sep = "") # similar to print()
%
%factor(x) # makes use of this to print the levels
%
%x <- c("a", "ab", "abcde")
%encodeString(x, width = NA) # left justification
%encodeString(x, width = NA, justify = "c")
%encodeString(x, width = NA, justify = "r")
%encodeString(x, width = NA, quote = "'", justify = "r")
%}
%\keyword{ utilities }
%
%
\encoding{UTF8}
