% File src/library/base/man/formals.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{formals}
\alias{formals}
\alias{formals<-}
\title{Access to and Manipulation of the Formal Arguments}
\description{
  関数の形式的引数を得る，設定する．
}
\usage{
formals(fun = sys.function(sys.parent()))
formals(fun, envir = environment(fun)) <- value
}
\arguments{
  \item{fun}{関数オブジェク，又は\sQuote{詳細}を見よ．}
  \item{envir}{関数が定義されるべき環境．}
  \item{value}{\R 表現式のリスト(又は対リスト)．}
}
\details{

  最初の形式では \code{fun} はまた操作される関数の名前である文字列でもよく，
  それは親環境から探される．
  もしそれが特定できなければ \code{formals} を呼び出している関数が使われる．

  \emph{クロージャ}だけが形式的引数を持ち，プリミティブな関数は持たない．
}
\value{
  \code{formals} は指定された関数の形式的引数のリストを返す．
  もしくは非関数やプリミティブな関数に対しては \code{NULL} を返す．

  置き換え形式は関数の形式的引数のセットを右側のリスト/対リストに変更し，そして
  (可能性として)関数の環境をリセットする．
}
\seealso{
  人間が読みやすいバージョンは \code{\link{args}}，
  \code{\link{alist}},
  \code{\link{body}},
  \code{\link{function}}.
}
\examples{
require(stats); require(graphics)
length(formals(lm))      # 形式的引数の数
names(formals(boxplot))  # 形式的引数の名前

f <- function(x) a+b
formals(f) <- alist(a = , b = 3) # 関数(a, b = 3) a+b
f(2) # 結果 = 5
}
\keyword{programming}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/formals.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{formals}
%\alias{formals}
%\alias{formals<-}
%\title{Access to and Manipulation of the Formal Arguments}
%\description{
%  Get or set the formal arguments of a function.
%}
%\usage{
%formals(fun = sys.function(sys.parent()))
%formals(fun, envir = environment(fun)) <- value
%}
%\arguments{
%  \item{fun}{a function object, or see \sQuote{Details}.}
%  \item{envir}{environment in which the function should be defined.}
%  \item{value}{a list (or pairlist) of \R expressions.}
%}
%\details{
%
%  For the first form, \code{fun} can also be a character string naming
%  the function to be manipulated, which is searched for from the parent
%  frame.  If it is not specified, the function calling \code{formals} is
%  used.
%
%  Only \emph{closures} have formals, not primitive functions.
%}
%\value{
%  \code{formals} returns the formal argument list of the function
%  specified, as a \code{\link{pairlist}}, or \code{NULL} for a
%  non-function or primitive.
%
%  The replacement form sets the formals of a function to the
%  list/pairlist on the right hand side, and (potentially) resets the
%  environment of the function.
%}
%\seealso{
%  \code{\link{args}} for a human-readable version,
%  \code{\link{alist}},
%  \code{\link{body}},
%  \code{\link{function}}.
%}
%\examples{
%require(stats); require(graphics)
%length(formals(lm))      # the number of formal arguments
%names(formals(boxplot))  # formal arguments names
%
%f <- function(x) a+b
%formals(f) <- alist(a = , b = 3) # function(a, b = 3) a+b
%f(2) # result = 5
%}
%\keyword{programming}
%
\encoding{UTF8}
