% File src/library/base/man/formatDL.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{formatDL}
\alias{formatDL}
\title{Format Description Lists}
\description{項目のベクトルとそれらの記述を2列の表や LaTeX 風の記述リストに
  整形する．
}
\usage{
formatDL(x, y, style = c("table", "list"),
         width = 0.9 * getOption("width"), indent = NULL)
}
\arguments{
  \item{x}{記述されるべき項目を与えるベクトル，長さ2のリスト，又は2列の行列で
    項目と記述の双方を与える．}
  \item{y}{\code{x} と同じ長さのベクトルで対応する記述を持つ．
    \code{x} が既に記述を持っていない時だけ使われる．}
  \item{style}{記述情報の翻訳スタイルを指定する文字列．
    簡略出来る．もし \code{"table"} なら，項目と記述を列に持つ2列の表が
    作られる(Texinfo の \verb{@table} 環境に似る)．もし \code{"list"} なら
    LaTeX 風のタグ付き記述リストが得られる．}
  \item{width}{出力中で行をラップするための目標列を与える正整数．}
  \item{indent}{表スタイル中の第二列のインデント量と，
    リストスタイルで連続業のインデント量を指定する正整数．
    \code{width/2} 以上であってはならず，表スタイルの既定値は
    \code{width/3} で，リストスタイルでは \code{width/9}．}
}
\value{
  整形された項目を持つ文字列ベクトル．
}
\details{
  引数から項目のベクトルと対応する記述を抜き出した後，双方が文字列ベクトルに
  変換される．

  表スタイルでは \code{indent - 3} 文字以上の項目はそれ自体一行で
  表示される．
}
\examples{
## R が稼働している計算機に関する数値的特性のわかりやすい要約を提供する
writeLines(formatDL(unlist(.Machine)))
## "list" スタイルの Sys.getenv() の結果を吟味
## (既定ではこれらは "table" スタイルでプリントされる)：
writeLines(formatDL(Sys.getenv(), style = "list"))
}
\keyword{print}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/formatDL.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{formatDL}
%\alias{formatDL}
%\title{Format Description Lists}
%\description{Format vectors of items and their descriptions as 2-column
%  tables or LaTeX-style description lists.
%}
%\usage{
%formatDL(x, y, style = c("table", "list"),
%         width = 0.9 * getOption("width"), indent = NULL)
%}
%\arguments{
%  \item{x}{a vector giving the items to be described, or a list of
%    length 2 or a matrix with 2 columns giving both items and
%    descriptions.}
%  \item{y}{a vector of the same length as \code{x} with the
%    corresponding descriptions.  Only used if \code{x} does not already
%    give the descriptions.}
%  \item{style}{a character string specifying the rendering style of the
%    description information.  Can be abbreviated.
%    If \code{"table"}, a two-column table with
%    items and descriptions as columns is produced (similar to Texinfo's
%    \verb{@table} environment.  If \code{"list"}, a LaTeX-style tagged
%    description list is obtained.}
%  \item{width}{a positive integer giving the target column for wrapping
%    lines in the output.}
%  \item{indent}{a positive integer specifying the indentation of the
%    second column in table style, and the indentation of continuation
%    lines in list style.  Must not be greater than \code{width/2}, and
%    defaults to \code{width/3} for table style and \code{width/9} for
%    list style.}
%}
%\value{
%  a character vector with the formatted entries.
%}
%\details{
%  After extracting the vectors of items and corresponding descriptions
%  from the arguments, both are coerced to character vectors.
%
%  In table style, items with more than \code{indent - 3} characters are
%  displayed on a line of their own.
%}
%\examples{
%## Provide a nice summary of the numerical characteristics of the
%## machine R is running on:
%writeLines(formatDL(unlist(.Machine)))
%## Inspect Sys.getenv() results in "list" style (by default, these are
%## printed in "table" style):
%writeLines(formatDL(Sys.getenv(), style = "list"))
%}
%\keyword{print}
%
\encoding{UTF8}
