% File src/library/base/man/kappa.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Copyright 2008-2010 The R Foundation
% Distributed under GPL 2 or later

\name{kappa}
\alias{rcond}
\alias{kappa}
\alias{kappa.default}
\alias{kappa.lm}
\alias{kappa.qr}
\alias{.kappa_tri}

\title{Compute or Estimate the Condition Number of a Matrix}
\usage{
kappa(z, \dots)
\method{kappa}{default}(z, exact = FALSE,
      norm = NULL, method = c("qr", "direct"), \dots)
\method{kappa}{lm}(z, \dots)
\method{kappa}{qr}(z, \dots)

.kappa_tri(z, exact = FALSE, LINPACK = TRUE, norm = NULL, \dots)

rcond(x, norm = c("O","I","1"), triangular = FALSE, \dots)
}
\arguments{
  \item{z, x}{行列又は \code{\link{qr}} の結果，もしくは
    \code{"lm"} を継承するクラスからの当てはめ．}
  \item{exact}{論理値．結果は正確であるべきか?}
  \item{norm}{文字列，条件数が計算される行列ノルムを指定する．
    \code{\link{norm}} を見よ．\code{rcond} に対しては既定値は \code{"O"} で
    絶対値ノルム．(現在唯一の)可能な他の値は
    最大値ノルムを意味する \code{"I"}．}
  \item{method}{使われるべきメソッドを指定する部分マッチされた文字列；
    主に過去との一貫性のため \code{"qr"} が既定値．}
  \item{triangular}{論理値．もし真ならば使われる行列は \code{z} の下側三角部分．}
  \item{LINPACK}{論理値．もし真ならば \code{z} は複素数値ではなく，
    LINPACK ルーチン \code{dtrco()} が呼び出される；さもなければ関連する
    ルーチンが呼び出される．}
  \item{\dots}{他のメソッドに・から渡される追加引数；
    \code{kappa.*()} に対しては, \code{norm} が \code{"2"} でない時は特に
    \code{LINPACK}．}
}
\description{
  正規(正方)行列の条件数は行列のノルムとその(一般化)逆行列のノルムの
  積であり．従って行列ノルムの種類に依存する．

  \code{kappa()} は既定では行列か \eqn{QR} 分解の \eqn{R} 行列の
  二乗ノルム条件数(の近似値)を計算する．恐らく線形フィットを使う．
  二乗ノルム条件数は行列の\emph{ゼロでない}最大固有値と最小固有値の比になることが
  知られている．
  
  \code{rcond()} は逆条件数の近似を計算する，詳細を見よ．
}
\details{
  \code{kappa()} に対しては，もし \code{exact = FALSE} (既定)ならば二乗ノルム
  条件数が簡易な近似で推定される．しかしながら(\code{\link{svd}} を使った)
  正確な計算も恐らく同じように十分速い．

  絶対値ノルムと最大値ノルムを使った条件数は相当速く計算でき，
  そして \code{rcond()} はこうした逆条件数を計算する．
  標準の Lapack ルーチンを使う複素数行列に対しても同様である．

  \code{kappa} と \code{rcond} は
    \emph{部分的に}同じ機能への異なったインタフェイスである．
  
  \code{.kappa_tri} は \code{kappa.qr} と \code{kappa.default} によって
  呼び出される内部関数である．

  基礎にある LAPACK コードからの不成功の結果は正のエラーコードを与える
  エラーになる：これらは FORTRAN コードの詳細な吟味によってのみ解釈可能である．
}
\value{
  条件数 \eqn{kappa} または \code{exact = FALSE} ならば近似値．
}
\source{
  LAPACK ルーチン \code{DTRCON} と \code{ZTRCON} そして LINPACK
  ルーチン \code{DTRCO}．

  LAPACK と LINPACK は \url{http://www.netlib.org/lapack} と
  \url{http://www.netlib.org/linpack} から．それらのガイドは参考文献にある．
}
\references{
  Anderson. E. and ten others (1999)
  \emph{LAPACK Users' Guide}. Third Edition. SIAM.\cr
  Available on-line at
  \url{http://www.netlib.org/lapack/lug/lapack_lug.html}.

 Chambers, J. M. (1992)
  \emph{Linear models.}
  Chapter 4 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.

  Dongarra, J. J., Bunch, J. R., Moler, C. B. and Stewart, G. W. (1978)
  \emph{LINPACK Users Guide.}  Philadelphia: SIAM Publications.
}
\author{
  デザインは Chambers (1992) に説明されている同名の S 関数
  にインスピレーションを受けた(しかしかなり異なる)．
}

\seealso{
  \code{\link{norm}};
  特異値分解は \code{\link{svd}} そして
  \eqn{QR} 分解は \code{\link{qr}}．
}
\examples{
kappa(x1 <- cbind(1, 1:10)) # 15.71
kappa(x1, exact = TRUE)        # 13.68
kappa(x2 <- cbind(x1, 2:11)) # 高い! [x2 は特異!]

hilbert <- function(n) { i <- 1:n; 1 / outer(i - 1, i, "+") }
sv9 <- svd(h9 <- hilbert(9))$ d
kappa(h9)  # かなり高い!
kappa(h9, exact = TRUE) == max(sv9) / min(sv9)
kappa(h9, exact = TRUE) / kappa(h9)  # 0.677 (つまり相対誤差 = 32\%)
}
\keyword{math}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/kappa.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Copyright 2008-2010 The R Foundation
%% Distributed under GPL 2 or later
%
%\name{kappa}
%\alias{rcond}
%\alias{kappa}
%\alias{kappa.default}
%\alias{kappa.lm}
%\alias{kappa.qr}
%\alias{.kappa_tri}
%
%\title{Compute or Estimate the Condition Number of a Matrix}
%\usage{
%kappa(z, \dots)
%\method{kappa}{default}(z, exact = FALSE,
%      norm = NULL, method = c("qr", "direct"), \dots)
%\method{kappa}{lm}(z, \dots)
%\method{kappa}{qr}(z, \dots)
%
%.kappa_tri(z, exact = FALSE, LINPACK = TRUE, norm = NULL, \dots)
%
%rcond(x, norm = c("O","I","1"), triangular = FALSE, \dots)
%}
%\arguments{
%  \item{z, x}{A matrix or a the result of \code{\link{qr}} or a fit from
%    a class inheriting from \code{"lm"}.}
%  \item{exact}{logical.  Should the result be exact?}
%  \item{norm}{character string, specifying the matrix norm with respect
%    to which the condition number is to be computed, see also
%    \code{\link{norm}}.  For \code{rcond}, the default is \code{"O"},
%    meaning the \bold{O}ne- or 1-norm.  The (currently only) other
%    possible value is \code{"I"} for the infinity norm.}
%  \item{method}{a partially matched character string specifying the method to be used;
%    \code{"qr"} is the default for back-compatibility, mainly.}
%  \item{triangular}{logical.  If true, the matrix used is just the lower
%    triangular part of \code{z}.}
%  \item{LINPACK}{logical.  If true and \code{z} is not complex, the
%    LINPACK routine \code{dtrco()} is called; otherwise the relevant
%    LAPACK routine is.}
%  \item{\dots}{further arguments passed to or from other methods;
%    for \code{kappa.*()}, notably \code{LINPACK} when \code{norm} is not
%    \code{"2"}.}
%}
%\description{
%  The condition number of a regular (square) matrix is the product of
%  the \emph{norm} of the matrix and the norm of its inverse (or
%  pseudo-inverse), and hence depends on the kind of matrix-norm.
%
%  \code{kappa()} computes by default (an estimate of) the 2-norm
%  condition number of a matrix or of the \eqn{R} matrix of a \eqn{QR}
%  decomposition, perhaps of a linear fit.  The 2-norm condition number
%  can be shown to be the ratio of the largest to the smallest
%  \emph{non-zero} singular value of the matrix.
%
%  \code{rcond()} computes an approximation of the \bold{r}eciprocal
%  \bold{cond}ition number, see the details.
%}
%\details{
%  For \code{kappa()}, if \code{exact = FALSE} (the default) the 2-norm
%  condition number is estimated by a cheap approximation.  However, the
%  exact calculation (via \code{\link{svd}}) is also likely to be quick
%  enough.
%
%  Note that the 1- and Inf-norm condition numbers are much faster to
%  calculate, and \code{rcond()} computes these \emph{\bold{r}eciprocal}
%  condition numbers, also for complex matrices, using standard Lapack
%  routines.
%
%  \code{kappa} and \code{rcond} are different interfaces to
%  \emph{partly} identical functionality.
%
%  \code{.kappa_tri} is an internal function called by \code{kappa.qr} and
%  \code{kappa.default}.
%
%  Unsuccessful results from the underlying LAPACK code will result in an
%  error giving a positive error code: these can only be interpreted by
%  detailed study of the FORTRAN code.
%}
%\value{
%  The condition number, \eqn{kappa}, or an approximation if
%  \code{exact = FALSE}.
%}
%\source{
%  The LAPACK routines \code{DTRCON} and \code{ZTRCON} and the LINPACK
%  routine \code{DTRCO}.
%
%  LAPACK and LINPACK are from \url{http://www.netlib.org/lapack} and
%  \url{http://www.netlib.org/linpack} and their guides are listed
%  in the references.
%}
%\references{
%  Anderson. E. and ten others (1999)
%  \emph{LAPACK Users' Guide}. Third Edition. SIAM.\cr
%  Available on-line at
%  \url{http://www.netlib.org/lapack/lug/lapack_lug.html}.
%
% Chambers, J. M. (1992)
%  \emph{Linear models.}
%  Chapter 4 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%
%  Dongarra, J. J., Bunch, J. R., Moler, C. B. and Stewart, G. W. (1978)
%  \emph{LINPACK Users Guide.}  Philadelphia: SIAM Publications.
%}
%\author{
%  The design was inspired by (but differs considerably from)
%  the S function of the same name described in Chambers (1992).
%}
%
%\seealso{
%  \code{\link{norm}};
%  \code{\link{svd}} for the singular value decomposition and
%  \code{\link{qr}} for the \eqn{QR} one.
%}
%\examples{
%kappa(x1 <- cbind(1, 1:10)) # 15.71
%kappa(x1, exact = TRUE)        # 13.68
%kappa(x2 <- cbind(x1, 2:11)) # high! [x2 is singular!]
%
%hilbert <- function(n) { i <- 1:n; 1 / outer(i - 1, i, "+") }
%sv9 <- svd(h9 <- hilbert(9))$ d
%kappa(h9)  # pretty high!
%kappa(h9, exact = TRUE) == max(sv9) / min(sv9)
%kappa(h9, exact = TRUE) / kappa(h9)  # 0.677 (i.e., rel.error = 32\%)
%}
%\keyword{math}
%
\encoding{UTF8}
