% File src/library/base/man/length.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{length}
\alias{length}
\alias{length<-}
\alias{length<-.factor}
\title{Length of an Object}
\description{
  ベクトル(リストを含む)と因子，そしてメソッドが定義されている他の \R オブジェクト
  の長さを得る・設定する．
}
\usage{
length(x)
length(x) <- value
}
\arguments{
  \item{x}{\R オブジェクト．置き換えにはベクトルか因子．}
  \item{value}{非負整数か倍精度実数(整数に刈り詰められる)．}
}
\details{
  どちらも総称的関数である：特殊なクラスのオブジェクトを
  処理するメソッドを書くことが出来る，
  \link{InternalMethods} を見よ．\code{length<-} は
  因子メソッドを持つ．

  置き換え形式はベクトルの長さをリセットするのに使われる．
  もしベクトルが短くなれば余分の値は捨て去られ，ベクトルの長さが長くなれば 
  \code{\link{NA}} (バイトベクトルには \code{nul})で新しい長さになるまで
  埋められる．

  どちらもプリミティブな関数である．
}
\value{
  \code{length} に対する既定値メソッドは現在長さ1の非負整数を返す．
  \eqn{2^{31}-1}{2^31 - 1} を超える要素があれば倍精度実数を返す．

  ベクトル(リストを含む)と因子に対しては長さは要素の数である．
  環境に対してはそれは環境中のオブジェクトの数である．
  \code{NULL} は長さ0を持つ．表現式と対リスト
  (言語オブジェクトとドットリストを含む)に対してはそれは対リストのチェインの長さである，
  他のすべてのオブジェクト(関数を含む)は長さを持つ：
  関数のそれは S とは異なることを注意しよう．

  置き換え形式は \code{x} のあらゆる属性を取り去るが，名前だけは例外で修正される
  (必要なら \code{""} で拡張される)．
}

\section{警告}{
  パッケージの作者は1以外の長さの結果(\CRANpkg{Formula})や，
  倍精度型のベクトルを返す(\CRANpkg{Matrix})メソッドを書いてきた．
  整数でない値を返すものすらある(\CRANpkg{sets} の初期バージョン)．
  整数として表現可能な一つの倍精度実数値が返されるときはそれは
  長さ1の整数ベクトルとして返される．

  \R 3.0.0 から長さは基本 \R 中で倍精度実数として返される．
}

\seealso{文字列ベクトル中の文字数を数えるには \code{nchar}，
  リスト中のすべての要素の長さを得るには \code{\link{lengths}}．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\examples{
length(diag(4))  # = 16 (4 x 4)
length(options())  # 12 またはそれ以上
length(y ~ x1 + x2 + x3)  # 3
length(expression(x, {y <- x^2; y+2}, x^y))  # 3

## example(warpbreaks) から
require(stats)

fm1 <- lm(breaks ~ wool * tension, data = warpbreaks)
length(fm1$call)      # 3, lm() そして二つの引数．
length(formula(fm1))  # 3, ~ lhs rhs
}
\keyword{attribute}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/length.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{length}
%\alias{length}
%\alias{length<-}
%\alias{length<-.factor}
%\title{Length of an Object}
%\description{
%  Get or set the length of vectors (including lists) and factors, and of
%  any other \R object for which a method has been defined.
%}
%\usage{
%length(x)
%length(x) <- value
%}
%\arguments{
%  \item{x}{an \R object.  For replacement, a vector or factor.}
%  \item{value}{a non-negative integer or double (which will be rounded down).}
%}
%\details{
%  Both functions are generic: you can write methods to handle specific
%  classes of objects, see \link{InternalMethods}.  \code{length<-} has a
%  \code{"factor"} method.
%
%  The replacement form can be used to reset the length of a vector.  If
%  a vector is shortened, extra values are discarded and when a vector is
%  lengthened, it is padded out to its new length with \code{\link{NA}}s
%  (\code{nul} for raw vectors).
%
%  Both are \link{primitive} functions.
%}
%
%\value{
%  The default method for \code{length} currently returns a non-negative
%  \code{\link{integer}} of length 1, except for vectors of more than
%  \eqn{2^{31}-1}{2^31 - 1} elements, when it returns a double.
%
%  For vectors (including lists) and factors the length is the number of
%  elements.  For an environment it is the number of objects in the
%  environment, and \code{NULL} has length 0.  For expressions and
%  pairlists (including \link{language objects} and dotlists) it is the
%  length of the pairlist chain.  All other objects (including functions)
%  have length one: note that for functions this differs from S.
%
%  The replacement form removes all the attributes of \code{x} except its
%  names, which are adjusted (and if necessary extended by \code{""}).
%}
%
%\section{Warning}{
%  Package authors have written methods that return a result of length
%  other than one (\CRANpkg{Formula}) and that return a vector of type
%  \code{\link{double}} (\CRANpkg{Matrix}), even with non-integer values
%  (earlier versions of \CRANpkg{sets}). Where a single double value is
%  returned that can be represented as an integer it is returned as a
%  length-one integer vector.
%
%  As from \R 3.0.0, lengths can be returned as double in base \R.
%}
%
%\seealso{\code{nchar} for counting the number of characters in character
%  vectors, \code{\link{lengths}} for getting the length of every element
%  in a list.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%length(diag(4))  # = 16 (4 x 4)
%length(options())  # 12 or more
%length(y ~ x1 + x2 + x3)  # 3
%length(expression(x, {y <- x^2; y+2}, x^y))  # 3
%
%## from example(warpbreaks)
%require(stats)
%
%fm1 <- lm(breaks ~ wool * tension, data = warpbreaks)
%length(fm1$call)      # 3, lm() and two arguments.
%length(formula(fm1))  # 3, ~ lhs rhs
%}
%\keyword{attribute}
%
%
\encoding{UTF8}
