% File src/library/base/man/nchar.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{nchar}
\alias{nchar}
\alias{nzchar}
\title{Count the Number of Characters (or Bytes or Width)}
\usage{
nchar(x, type = "chars", allowNA = FALSE, keepNA = FALSE)

nzchar(x, keepNA = FALSE)
}
\description{
  \code{nchar} は引数として文字列ベクトルを取り，\code{x} の対応する
  要素のサイズを含むベクトルを返す．

  \code{nzchar} は文字列ベクトルの要素が空でない文字列かどうかを
  見つける高速な方法である．
}
\arguments{
  \item{x}{文字列ベクトル，又は文字列ベクトルに変換できるベクトル．
    因子を与えるとエラーになる．}
  \item{type}{文字列：\code{c("bytes", "chars", "width")} のどれかと部分
    マッチングされる．\sQuote{詳細}を見よ．}
  \item{allowNA}{論理値：不正な多バイト文字列や \code{"bytes"} で
    エンコードされた文字列に対しては \code{NA} を返すべきか
    (エラーにするよりは)?}
  \item{keepNA}{論理値：\code{x} が \code{\link{NA}} なら \code{NA} を
    返すべきか?  もし偽ならば(暗黙又は明示的に) \code{nzchar()} に対する
    既定では，そして \R バージョン \eqn{\le}{<=} 3.2.x に対しては，
    \code{nchar()} は \code{2} を返す．なぜならこれは文字列が出力に書き込まれるときに
    使われるプリント文字数だからである．そして
    \code{nzchar()} は \code{TRUE} になる．
    \R バージョン 3.3.0 以降，\code{nchar()} に対してだけ，既定は
    \code{NA} に成り，これは \code{type} が \code{"width"} で無い限り
    \code{keepNA = TRUE} を使うことを意味する．
    \R バージョン \eqn{\le}{<=} 3.2.0.} では(暗黙のうちに)
    \code{FALSE} に固定されていた．
}
\details{
  文字列の\sQuote{サイズ}は(引数の型に応じて)次の三つの方法で計ることができる：
  \describe{
    \item{\code{bytes}}{文字列を保管するのに必要なバイト数
      (それと C ではカウントされない行終結子)．}
    \item{\code{chars}}{人間が読み取れる文字数．}
    \item{\code{width}}{\code{\link{cat}} が文字列を等幅フォントで
      プリントする時に使われる列数．もしこれが計算できなければ
      \code{chars} と同じ．}
  }
  これらはしばしば同じで，単バイトロケールではほとんど常に
  同じになる(しかしながら \code{type} は \code{keepNA = NA} に
  対する \code{NA} の扱いに影響するかもしれないことを注意する)．
  多バイト文字系列では最初の二つには差があるかもしれない，
  例えば UTF-8 ロケール中．

  \code{\link{as.character}} の既定メソッドの内部的同値物は
  \code{x} に関して操作される(従ってメソッドの選択適用は無い)．
  もしベクトルでないオブジェクトを操作したければそれらを
  \code{\link{deparse}} を通じて渡すことが必要になる．
}
\value{
  \code{nchar} に対しては各要素のサイズを与える整数ベクトル．
  欠損値(つまり \code{NA}，言い換えれば \code{\link{NA_character_}})
  に対しては \code{nchar()} はもし \code{keepNA} が真なら
  \code{\link{NA_integer_}} を返す．そして偽ならば
  文字のプリント数である \code{2} を返す．

  \code{type = "width"} は(近似的な)ターミナルのフォントを使い
  各要素をプリントする際に使われる列数を与える．
  倍幅，ゼロ幅，そして\sQuote{複合}文字が考慮される．
  
  もし \code{allowNA = TRUE} で UTF-8 のような多バイト文字中で
  不正な要素が検出されると，その文字数と幅は \code{NA} になる．
  さもなければ文字数は非負であるので
  \code{!is.na(nchar(x, "chars", TRUE))} を使って適正さの検査が
  行える．

  \code{"bytes"} エンコーディングでマークされた文字列
  (\code{\link{Encoding}} を見よ)はバイト数を持つが，
  文字数も幅も持たないので，後者の二つのタイプはもし \code{allowNA = TRUE}
  なら \code{NA} で，さもなければエラーになる．

  \code{nzchar} に対しては \code{x} と同じ長さの論理値ベクトルで，
  要素がゼロでない長さを持つ時そしてその時だけ真になる；
  もし要素が \code{NA} なら，\code{keepNA} が既定値であるように偽の時
  \code{nzchar()} は 真になる．さもなければ \code{NA} である．
}
\note{
  これは既定では文字列をプリントする時に使われる文字数を与えない．
  \code{\link{encodeString}} を使えばそれを知ることが出来る．
#ifdef windows
  これは Windows で現在のエンコーディングでは表現不可能な Unicode
  文字列を入力するのに \samp{\\uxxxx} 系列が使われる時特に重要になる．
  従って \code{nchar("\\u2642")} は \code{1} で
  \code{Rgui} では一つの文字として表示されるが，
  \code{Rterm} では \code{<U+2642>} とされ，これは
  \code{encodeString} が与えるものである．
#endif
#ifdef unix
  文字列が UTF-8 としてマークされている箇所では，
  プリントに於いては UTF-8 でないロケールでは \samp{<U+2642>} のように
  エスケープを使うかもしれないが，文字数と幅は UTF-8 で計算される．
#endif
  
  \sQuote{幅}の概念は等幅フォントに於いてすら曖昧である．
  ある種の自然言語は\emph{結合}文字の概念を持っており，
  二つもしくはそれ以上の文字が結合される：一つの例は
  \code{"y\u306"} で，これは幅が一つの二文字である：
  連結する文字の幅はゼロとされ，ゼロ幅空白 \code{"\u200b"} のような
  幅がゼロの他の文字もある．

  幾つかの東アジア言語は\sQuote{幅広}文字を持つ．
  表意文字であり，これらの言語では ASCII や幅狭文字と一緒にされると
  便宜的に二つの列を跨ってプリントされる．
  問題は計算機が幅広文字を二列でプリントするか一列でプリントするかが
  フォントに依存し，
  それに対して西アジアユーザ向けのフォントには二列を，\sQuote{ヨーロッパ系}
  フォントには一列を使うことが普通ではないことである．
  Unicode は ASCII 文字の \sQuote{全角} バージョンと，
  カタカナ(日本語)とハングル(韓国)文字に対する\sQuote{半角}バージョンを持つ．
  それから\sQuote{西アジアの曖昧なクラス} (ギリシャ文字，キリル文字，符号，
  幾つかのアクセント付きのラテン文字等)がある．これらに対しては歴史的な
  用法は西アジアでは二列，それ以外では一列というものである．
  そのクラス(そして他のもの)中の文字に対する \code{nchar} が見積もる幅は
  ロケールに依存し，ある種の OS (特に Windows)に関しては幾つかの西アジアロケール
  を除いて1である．

  制御文字は幅がゼロとされる．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
  
  Unicode Standard Annex #11: \emph{East Asian Width.}
  \url{http://www.unicode.org/reports/tr11/}
}
\seealso{
  プロット用に文字列の幅を与えるには \code{\link{strwidth}}；
  \code{\link{paste}}, \code{\link{substr}}, \code{\link{strsplit}}
}
\examples{
x <- c("asfef", "qwerty", "yuiop[", "b", "stuff.blah.yech")
nchar(x)
# 5  6  6  1 15

nchar(deparse(mean))
# 18 17  <-- mean が base::mean と異ならない限り

x[3] <- NA; x
nchar(x, keepNA= TRUE) #  5  6 NA  1 15
nchar(x, keepNA=FALSE) #  5  6  2  1 15
stopifnot(identical(nchar(x, "w", keepNA = NA),
                    nchar(x,      keepNA = FALSE)),
          identical(is.na(x), is.na(nchar(x, keepNA=NA))))
}
\keyword{character}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/nchar.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{nchar}
%\alias{nchar}
%\alias{nzchar}
%\title{Count the Number of Characters (or Bytes or Width)}
%\usage{
%nchar(x, type = "chars", allowNA = FALSE, keepNA = FALSE)
%
%nzchar(x, keepNA = FALSE)
%}
%\description{
%  \code{nchar} takes a character vector as an argument and
%  returns a vector whose elements contain the sizes of
%  the corresponding elements of \code{x}.
%
%  \code{nzchar} is a fast way to find out if elements of a character
%  vector are non-empty strings.
%}
%\arguments{
%  \item{x}{character vector, or a vector to be coerced to a character
%    vector.  Giving a factor is an error.}
%  \item{type}{character string: partial matching to one of
%    \code{c("bytes", "chars", "width")}.  See \sQuote{Details}.}
%  \item{allowNA}{logical: should \code{NA} be returned for invalid
%    multibyte strings or \code{"bytes"}-encoded strings (rather than
%    throwing an error)?}
%  \item{keepNA}{logical: should \code{NA} be returned where ever
%    \code{x} is \code{\link{NA}}?  If false, the (implicit or explicit)
%    default for \code{nzchar()} and for \R versions \eqn{\le}{<=} 3.2.x,
%    \code{nchar()} returns \code{2}, as that is the number of printing
%    characters used when strings are written to output, and
%    \code{nzchar()} is \code{TRUE}.
%    From \R version 3.3.0 on, for \code{nchar()} only, the default will
%    be \code{NA}, which means to use \code{keepNA = TRUE} unless
%    \code{type} is \code{"width"}.  Used to be (implicitly) hard coded
%    to \code{FALSE} in \R versions \eqn{\le}{<=} 3.2.0.}
%}
%\details{
%  The \sQuote{size} of a character string can be measured in one of
%  three ways (corresponding to the \code{type} argument):
%  \describe{
%    \item{\code{bytes}}{The number of bytes needed to store the string
%      (plus in C a final terminator which is not counted).}
%    \item{\code{chars}}{The number of human-readable characters.}
%    \item{\code{width}}{The number of columns \code{\link{cat}} will use to
%      print the string in a monospaced font.  The same as \code{chars}
%      if this cannot be calculated.}
%  }
%  These will often be the same, and almost always will be in single-byte
%  locales (but note how \code{type} may influence \code{NA} treatment
%  for \code{keepNA = NA}).  There will be differences between the first two with
%  multibyte character sequences, e.g.\sspace{}in UTF-8 locales.
%
%  The internal equivalent of the default method of
%  \code{\link{as.character}} is performed on \code{x} (so there is no
%  method dispatch).  If you want to operate on non-vector objects
%  passing them through \code{\link{deparse}} first will be required.
%}
%\value{
%  For \code{nchar}, an integer vector giving the sizes of each element.
%  For missing values (i.e., \code{NA}, i.e., \code{\link{NA_character_}}),
%  \code{nchar()} returns \code{\link{NA_integer_}} if \code{keepNA} is
%  true, and \code{2}, the number of printing characters, if false.
%
%  \code{type = "width"} gives (an approximation to) the number of
%  columns used in printing each element in a terminal font, taking into
%  account double-width, zero-width and \sQuote{composing} characters.
%  
%  If \code{allowNA = TRUE} and an element is detected as invalid in a
%  multi-byte character set such as UTF-8, its number of characters and
%  the width will be \code{NA}.  Otherwise the number of characters will
%  be non-negative, so \code{!is.na(nchar(x, "chars", TRUE))} is a test
%  of validity.
%
%  A character string marked with \code{"bytes"} encoding (see
%  \code{\link{Encoding}}) has a number of bytes, but neither a known
%  number of characters nor a width, so the latter two types are
%  \code{NA} if \code{allowNA = TRUE}, otherwise an error.
%
%  Names, dims and dimnames are copied from the input.
%
%  For \code{nzchar}, a logical vector of the same length as \code{x},
%  true if and only if the element has non-zero length; if the element is
%  \code{NA}, \code{nzchar()} is true when \code{keepNA} is false, as by
%  default, and \code{NA} otherwise.
%}
%\note{
%  This does \strong{not} by default give the number of characters that
%  will be used to \code{print()} the string.  Use
%  \code{\link{encodeString}} to find that.
%#ifdef windows
%  This is particularly important on Windows when \samp{\\uxxxx}
%  sequences have been used to enter Unicode characters not representable
%  in the current encoding.  Thus \code{nchar("\\u2642")} is \code{1},
%  and it is printed in \code{Rgui} as one character, but it will be
%  printed in \code{Rterm} as \code{<U+2642>}, which is what
%  \code{encodeString} gives.
%#endif
%#ifdef unix
%  Where character strings have been marked as UTF-8, the number of
%  characters and widths will be computed in UTF-8, even though printing
%  may use escapes such as \samp{<U+2642>} in a non-UTF-8 locale.
%#endif
%  
%  The concept of \sQuote{width} is a slippery one even in a monospaced
%  font. Some human languages have the concept of \emph{combining}
%  characters, in which two or more characters are rendered together: an
%  example would be \code{"y\u306"}, which is two characters of width
%  one: combining characters are given width zero, and there are other
%  zero-width characters such as the zero-width space \code{"\u200b"}.
%
%  Some East Asian languages have \sQuote{wide} characters, ideographs
%  which are conventionally printed across two columns when mixed with
%  ASCII and other \sQuote{narrow} characters in those languages.  The
%  problem is that whether a computer prints wide characters over two or
%  one columns depends on the font, with it not being uncommon to use two
%  columns in a font intended for East Asian users and a single column in
%  a \sQuote{Western} font.  Unicode has encodings for \sQuote{fullwidth}
%  versions of ASCII characters and \sQuote{halfwidth} versions of
%  Katakana (Japanese) and Hangul (Korean) characters.  Then there is the
%  \sQuote{East Asian Ambiguous class} (Greek, Cyrillic, signs, some
%  accented Latin chars, etc), for which the historical practice was to
%  use two columns in East Asia and one elsewhere.  The width quoted by
%  \code{nchar} for characters in that class (and some others) depends on
%  the locale, being one except in some East Asian locales on some OSes
%  (notably Windows).
%
%  Control characters are given width zero.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%  
%  Unicode Standard Annex #11: \emph{East Asian Width.}
%  \url{http://www.unicode.org/reports/tr11/}
%}
%\seealso{
%  \code{\link{strwidth}} giving width of strings for plotting;
%  \code{\link{paste}}, \code{\link{substr}}, \code{\link{strsplit}}
%}
%\examples{
%x <- c("asfef", "qwerty", "yuiop[", "b", "stuff.blah.yech")
%nchar(x)
%# 5  6  6  1 15
%
%nchar(deparse(mean))
%# 18 17  <-- unless mean differs from base::mean
%
%x[3] <- NA; x
%nchar(x, keepNA= TRUE) #  5  6 NA  1 15
%nchar(x, keepNA=FALSE) #  5  6  2  1 15
%stopifnot(identical(nchar(x, "w", keepNA = NA),
%                    nchar(x,      keepNA = FALSE)),
%          identical(is.na(x), is.na(nchar(x, keepNA=NA))))
%}
%\keyword{character}
%
\encoding{UTF8}
