% File src/library/base/man/ns-dblcolon.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{ns-dblcolon}
\title{Double Colon and Triple Colon Operators}
\alias{::}
\alias{:::}
\description{
  名前空間中の移出された変数や内部変数にアクセスする．
}
\usage{
pkg::name
pkg:::name
}
\arguments{
  \item{pkg}{パッケージ名：シンボルか文字通りの文字列．}
  \item{name}{変数名：シンボルか文字通りの文字列．}
}
\details{
  パッケージ \pkg{pkg} に対して \code{pkg::name} は
  名前空間 \code{pkg} 中の移出された変数
  \code{name} の値を返す．一方
  \code{pkg:::name} は内部変数 \code{name} の値を返す．
  名前空間はまだロードされていなければ呼び出し前にロードされるが，
  パッケージは検索パスに付加されない．

  存在しない変数やパッケージを指定するとエラーになる．

  \code{pkg::name} は環境 \code{package:pkg} 中のオブジェクトに
  アクセスしないことを注意しよう(それはパッケージの名前空間が付加
  されるまで存在しない)：後者は名前空間から移出されていないオブジェクトを
  含むかもしれない．それは遅延ロードで利用可能にされているデータセットに
  アクセスできる．
}

\note{
  自分のコード中で \code{:::} を使用することは典型的にはデザイン上の
  ミスである．なぜなら対応するオブジェクトは恐らく何らかの理由があって
  内部的にされているからである．
  もし単なる吟味以上の理由でオブジェクトにアクセスする必要を感じたならば
  パッケージの保守者に連絡しよう．
}
\seealso{
  別の同じ名前のものでマスクされたオブジェクトにアクセス
  するには \code{\link{get}}．
}
\examples{
base::log
base::"+"

## 注意 --  ':::' は自己責任で使うこと! ("詳細"を見よ)
stats:::coef.default
}
\keyword{programming}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/ns-dblcolon.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ns-dblcolon}
%\title{Double Colon and Triple Colon Operators}
%\alias{::}
%\alias{:::}
%\description{
%  Accessing exported and internal variables in a namespace.
%}
%\usage{
%pkg::name
%pkg:::name
%}
%\arguments{
%  \item{pkg}{package name: symbol or literal character string.}
%  \item{name}{variable name: symbol or literal character string.}
%}
%\details{
%  For a package \pkg{pkg}, \code{pkg::name} returns the value of
%  the exported variable \code{name} in namespace \code{pkg}, whereas
%  \code{pkg:::name} returns the value of the internal variable
%  \code{name}. The namespace will be loaded if it was not loaded
%  before the call, but the package will not be attached to the
%  search path.
%
%  Specifying a variable or package that does not exist is an error.
%
%  Note that \code{pkg::name} does \strong{not} access the objects in the
%  environment \code{package:pkg} (which does not exist until the
%  package's namespace is attached): the latter may contain objects not
%  exported from the namespace.  It can access datasets made available by
%  lazy-loading.
%}
%
%\note{
%  It is typically a design mistake to use \code{:::}
%  in your code since the corresponding object has probably been kept
%  internal for a good reason.  Consider contacting the package
%  maintainer if you feel the need to access the object for anything but
%  mere inspection.
%}
%\seealso{
%  \code{\link{get}} to access an object masked by another of the same name.
%}
%\examples{
%base::log
%base::"+"
%
%## Beware --  use ':::' at your own risk! (see "Details")
%stats:::coef.default
%}
%\keyword{programming}
%
\encoding{UTF8}
