% File src/library/base/man/options.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{options}
\alias{options}
\alias{.Options}
\alias{getOption}
\alias{option} % so help files can do 'set \link{} \code{"foo"}'

\alias{MC_CORES}
\alias{R_C_BOUNDS_CHECK}
\alias{R_DEFAULT_DEVICE}
\alias{R_KEEP_PKG_SOURCE}
\alias{R_INTERACTIVE_DEVICE}

\title{Options Settings}
\description{
  \R が計算やその結果の表示をする仕方に影響する多くの大局的\emph{オプション}を
  設定したり調べたり出来るようにする．
}
\usage{
options(\dots)

getOption(x, default = NULL)

.Options
}
%%-- NOTE : Keep the list up-to-date,
%%-- ====   Consider also the leading comments in ../../../main/options.c
\arguments{
  \item{\dots}{\code{name = value} を使い任意のオプションを定義できる．
    しかしながら下にあるものだけが基本 \R で使われている．

    オプションはまた名前付きリストである単一の名前無し引数を与えることで渡すことが出来る．
  }
  \item{x}{オプション名を保持する文字列．}

  \item{default}{もし指定したオプションがオプションのリスト中で
    設定されなければこの値が返される．
    これはオプションの検索，それが設定されているかどうかのチェック，
    そしてもしされていなければそれを個別に設定することを容易にする．}
}
\details{
  \code{options()} を引数なしに起動すると現在のオプションの値のリストが
  返される．下に羅列された全てのオプションが最初から設定されているわけではない
  ことを注意する．一つのオプションの値にアクセスするには，
  長さ1のリストである \code{options("width")} ではなく，むしろ
  例えば \code{getOption("width")} を使うべきである．
}

\note{
  S との互換性のため目に見えるオブジェクト \code{.Options} がある．
  その値は現在の \code{options()} の値を含む対リストである(決まった順序は
  無い)．これに付値すれば局所的なコピーが出来，オリジナルを変更しない．
}
\value{
  \code{getOption} に対してはオプション \code{x} の現在の値，もしくは
  オプションが未設定ならば \code{NULL}．

  \code{options()} に対しては名前でソートされた全ての設定オプションのリスト．
  \code{options(name)} に対しては設定値を含む長さ1のリスト，もしくは
  未設定ならば \code{NULL}．
  一つ又はそれ以上のオプションの設定に使えば,
  変更されたオプションの直前の値を持つリスト(不可視で返される)．
}
\section{基本 \R で使われるオプション}{
  \describe{
    \item{\code{add.smooth}:}{典型的には論理値，既定値は \code{TRUE}．
      またどれくらい(シミュレーションした)平滑性を加えるかを指定する
      整数に設定することが出来る．これは現在 \code{\link{plot.lm}}
      だけで使われる．}

    \item{\code{browserNLdisabled}:}{論理値：ブラウザ中で
      新行を \code{"n"} の同義語として使うのを無効にする．}

    \item{\code{checkPackageLicense}:}{論理値，既定では設定されない．
      もし真なら \code{\link{library}} は任意の非標準的ライセンスを
      最初の使用時に受け入れるかどうかを尋ねられる．}

    \item{\code{check.bounds}:}{論理値，既定値は \code{FALSE}．
    もし真なら code{x <- 1:3; x[5] <- 6} のようにベクトル
    (原子的かリスト)が拡大されるたびに警告が出る．}
    
    \item{\code{CBoundsCheck}:}{論理値，
      \code{\link{.C}} と \code{\link{.Fortran}} が原子的ベクトル引数に対して
      配列のはみ出しをチェックするためにコピーを作るかどうかを制御する．

      環境変数 \env{R_C_BOUNDS_CHECK} の値で初期化される
      (有効にするには \code{yes} にする)．}

    \item{\code{continue}:}{一行を超える行に対して使われるプロンプトを
      設定する空でない文字列．}

    %%  default is set in ../../profile/Common.R :
    \item{\code{defaultPackages}:}{\R の起動時に既定で付加される
      パッケージ．
      環境変数 \env{R_DEFAULT_PACKAGES} の値で初期化される．
      もしくはそれが未設定なら\cr
      \code{c("datasets", "utils", "grDevices", "graphics", "stats", "methods")}
      とされる．(\env{R_DEFAULT_PACKAGES} を \code{NULL} か
      コンマで分離されたパッケージ名のリストに設定する．)  これを
      ファイル \file{.Rprofile} 中で設定することは出来ない．なぜなら
      その値はファイルが読まれる前に参照されるから．}

    \item{\code{deparse.cutoff}:}{逆構文解析された言語構成のプリントを
      制御する整数値．既定値は \code{60}．
    }

    \item{\code{deparse.max.lines}:}{
      \code{\link{traceback}}, \code{\link{browser}} 中の逆構文解析，そして
      デバッグフラグが設定された関数に入った時に使われる
      行数を制御する．初期状態では未設定で，正整数に設定された時だけ使用される．}

    \item{\code{digits}:}{数値をプリントする際に使われる桁数を制御する．
      これは示唆だけである．適正な値は
      1\dots{}22 で，既定値は 7．15より大きな値については
      \code{\link{print.default}} 中のノートを見よ．}

    \item{\code{digits.secs}:}{時刻値の秒数をプリントする際の整形に使われる
      最大桁数を制御する．適正な値は 0\dots6 で，既定値は 0．
      \code{\link{strftime}} を見よ．}

    \item{\code{download.file.extra}:}{既定でないメソッドに対する
      特別なコマンドライン引数．
      \code{\link{download.file}} を見よ．}

    \item{\code{download.file.method}:}{
      \code{download.file} に使われる既定メソッド．現在ダウンロード用メソッドには
      \code{"internal"}, \code{"wininet"} (Windows のみ),
      \code{"libcurl"}, \code{"wget"} そして \code{"curl"} が利用できる．
      未設定なら \code{method = "auto"} が選ばれる：
      \code{\link{download.file}} を見よ．}

    \item{\code{echo}:}{論理値．非対話的モードだけで使われ，
      入力をエコーするかどうかを制御する．コマンドラインオプション
      \option{--slave} はこれを \code{FALSE} に設定するが，さもなければ
      セッションは \code{TRUE} で開始される．}

    \item{\code{encoding}:}{エンコーディング名，既定では \code{"native.enc"}．
      \code{\link{connections}} を見よ．}

    \item{\code{error}:}{
      \code{\link{stop}} によって作りだされた破滅的でない
      エラー，そしてやシグナルや内部的に検出されたエラー
      等の処理を管理する関数か表現式．
      もしこのオプションが関数なら，引数なしのこの関数への呼び出しが
      表現式として創りだされる．既定値は \code{NULL} である：
      この場合の挙動については \code{\link{stop}} を見よ．
      関数 \code{\link{dump.frames}} と \code{\link{recover}} は
      検死デバッグを許す別の方法を与える．
      これらは，例えば
      \code{options(error = utils::recover)} のように
      \file{\link{.Rprofile}} 等のスタートアップファイルの中で
      指定される必要があることを注意する．}

    \item{\code{expressions}:}{評価されるべき入れ子の表現式の限界を設定する．
      適正な値は 25\dots500000 で既定値は 5000．もし増加したければ
      \R をより大きなプロテクションスタックで開始したくなるかもしれない；
      \code{\link{Memory}} 中の \option{--max-ppsize} を見よ．また
      C スタックのオーバーフローからセグメンテーションフォールトを
      起こす可能性があることも注意しよう．
      そしてそれが可能な OS ではそれを増やしたくなるかもしれない．
      一旦限界に達するとエラーが起きる．
      現在の評価中の数は \code{\link{Cstack_info}} の呼び出しで分かる．}

    \item{\code{keep.source}:}{\code{TRUE} の時，関数のソースコード
      (新規に定義されたものやロードされたもの)はコメント付きで内部的に
      正しい場所に保存される．ソースは
      プリントや\cr
      \code{deparse(fn, control = "useSource")} を使って見ることが出来る．

      既定値は \code{\link{interactive}()}，つまり対話的な使用では
      \code{TRUE}．}

    %% used by tools::makeLazyLoading
    \item{\code{keep.source.pkgs}:}{\code{keep.source} と同様であるが，
    パッケージがインストールされた時だけ使われる．
    環境変数 \env{R_KEEP_PKG_SOURCE} が \code{yes} に設定されていない限り
    既定値は \code{FALSE}．}

    \item{\code{max.print}:}{整数で既定値は \code{99999}．
      \code{\link{print}} や \code{\link{show}} メソッドはこの
      オプションを使うことができ，プリントされる情報の量を
      \code{max.print} の大きさ程度(典型的には少し小さく)に制限する．}

    \item{\code{OutDec}:}{一つの文字を含む文字列．
      出力変換で小数点として使われることが好ましい文字．
      つまりプリント，プロット，書式，そして \code{\link{as.character}}
      で使われるが，逆構文解析，\code{\link{sprintf}}，そして
      \code{\link{formatC}} では使われない(これらは時折プリント以前に使われる)．

      \R 3.2.0 以前では1バイト文字だけがサポートされていた．
      \R 3.2.1 及びそれ以前では多(またはゼロ)バイト文字の \code{OutDec}
      が受け入れられたが，常に部分的にしか動作しなかった．
    }

    \item{\code{pager}:}{\code{\link{file.show}} によりテキストの表示に
      使われる命令．
#ifdef unix
      既定は \file{\var{\link{R_HOME}}/bin/pager} で，これは環境変数
      \env{PAGER} で指定されるコマンドライン実行のシェルスクリプト
      であり，その既定値はコンフィギュレーション時に設定される．
      普通 \command{less} である．
#endif
#ifdef windows
      既定値は \code{"internal"} で，GUI コンソールと類似のページャを
      使う．もうひとつの可能性はコンソール自体を使う \code{"console"} である．
#endif
      文字列や \R 関数で良く，その場合 \code{\link{file.show}} の最初の
      四つの引数に対応する次の引数を受け入れる必要がある
      \code{(files, header, title, delete.file)} ．}

    \item{\code{papersize}:}{\code{\link{postscript}} が使う既定の
      ページの書式；\R が起動するときに環境変数 \env{R_PAPERSIZE} で
      設定される：もしそれが未設定か不正なら既定値は
#ifdef unix
      \code{LC_PAPER} の局所カテゴリーから導かれる値か，
      もしそれが利用できなければ \R が構築された時に
      設定される既定値．
#endif
#ifdef windows
      米国とカナダのロケール中では \code{"a4"} か \code{"letter"}．
#endif
    }

    \item{\code{pdfviewer}:}{既定の PDF ビューア．
      既定値は環境変数 \env{R_PDFVIEWER} から設定され，
#ifdef unix
      その既定値は \R のコンフィギュレーション時に設定される．
#endif
#ifdef windows
      その既定値は \R と共に提供されるユーティリティである
      \command{open.exe} へのフルパス．
#endif
    }

    \item{\code{printcmd}:}{\code{\link{postscript}} がプリントに
      使う命令；\R が起動する時環境変数 \env{R_PRINTCMD} によって
      設定される．これは入力を \file{stdin} にパイプするか，一つの
      ファイル名の引数が与えられることが
      期待されている命令でなければならない．
      普通 Unix 風システムでは \code{"lpr"} に設定される．}

    \item{\code{prompt}:}{\R のプロンプトに使われる空でない文字列；
      普通空白 (\code{" "}) で終わるべきである．}

      % verbatim, for checking " \t\n\"\\'`><=%;,|&{()}"
#ifdef unix
    \item{\code{rl_word_breaks}:}{リードラインベースのターミナル
      インタフェイスで使われる．既定は\cr
      \code{" \\t\\n\\"\\\\'`><=\%;,|&{()}"}%"
      ．
      
      これは入力ラインをオブジェクトとファイル名の補完のために
      トークンに分割するために使われる文字のセットである．
      演算子の周囲に空白を使わない人物は次を好むかもしれない，
      \code{" \\t\\n\\"\\\\'`><=+-*\%;,|&{()}"}%"
      ．
      }
#endif

    \item{\code{save.defaults}, \code{save.image.defaults}:}{
      \code{\link{save}} を見よ．}

    \item{\code{scipen}:}{整数．数値を固定表記にするか指数表記にするか
      決定する際に使われるペナルティ．
      正の値は固定表示に，府の値は科学的表記にバイアスをかける：
      \code{scipen} 桁幅より広くない限り固定表記が好まれる．}

    \item{\code{showWarnCalls}, \code{showErrorCalls}:}{論理値．
      警告とエラーメッセージはコールスタックの要約を示すべきか?
      既定では非対話的なセッションではエラー呼び出しが示される．}

    \item{\code{showNCalls}:}{整数．楕円が使われる前に
      呼び出しの系列がどれだけ長く(バイト単位)あるべきかを制御する．
      既定は 40 で少なくとも 30 で 500 を超えるべきではない．}

    \item{\code{show.error.locations}:}{エラーのソース位置をプリント
      すべきか?  もし \code{TRUE} か \code{"top"} に設定すると，
      スタックで最上位(最も最近の呼び出し)のソース位置がプリントされる．
      \code{"bottom"} はスタック上に見つかる最も前の呼び出しの
      位置をプリントする．

      整数値は他の項目を選択できる．値 \code{0} は
      \code{"top"} に対応し，整数値はそこからスタックを下がっていく．
      値 \code{-1} は \code{"bottom"} に対応し，負の値はそこから
      昇っていく．
      }

    \item{\code{show.error.messages}:}{論理値．エラーメッセージをプリントするか?
      \code{\link{try}} かユーザがインストールしたエラーハンドラー
      と共に使うことを意図している．}

    \item{\code{stringsAsFactors}:}{
      \code{\link{data.frame}} と \code{\link{read.table}} の
      引数に対する既定設定．}

    \item{\code{texi2dvi}:}{
      パッケージ \pkg{tools} 中の関数 \code{\link{texi2dvi}} と
      \code{\link{texi2pdf}} が使う．
#ifdef unix
      起動時に環境変数 \env{R_TEXI2DVICMD} により設定される．
#endif
    }

    \item{\code{timeout}:}{整数．秒単位のある種のインターネット操作の
      タイムアウト時間．既定値は 60 秒．
      \code{\link{download.file}} と \code{\link{connections}}
      を見よ．}

    \item{\code{topLevelEnvironment}:}{\code{\link{topenv}} と
      \code{\link{sys.source}} を見よ．}

    \item{\code{url.method}:}{文字列：\code{\link{url}} に対する既定メソッド．
      普通未設定で \code{"default"} に等しく，Windows を除けば
      \code{"internal"}．}

    \item{\code{useFancyQuotes}:}{
      \code{\link{sQuote}}, \code{dQuote} そして
      パッケージ \pkg{tools} 中のテキストヘルプの整形
      (\code{\link{Rd2txt}} を見よ)における向き付き引用符の
      使用を制御する．\code{"UTF-8"} が可能．}

    \item{\code{verbose}:}{論理値．\R は進行度に関する余分の情報を報告すべきか?
      コマンドラインオプション \option{--verbose} により \code{TRUE} に
      設定される．}

    \item{\code{warn}:}{警告メッセージの処理を設定する．
      もし \code{warn} が負なら全ての警告は無視される．
      もし \code{warn} がゼロならば警告はトップレベルの関数が返るまで蓄積される．
      もし 10 かそれより少ない警告が出るとそれらはプリントされ，
      さもなければ幾つ警告が出たかというメッセージがプリントされる．
      \code{last.warning} と呼ばれるオブジェクトが作られ関数
      \code{\link{warnings}} を使ってプリントできる．
      もし \code{warn} が1ならば，警告は出るたびにプリントされる．
      もし \code{warn} が2かそれ以上なら全ての警告はエラーに
      転換される．}

    \item{\code{warnPartialMatchArgs}:}{論理値．もし真なら，引数のマッチング
      で部分マッチングが使われると警告する．}

    \item{\code{warnPartialMatchAttr}:}{論理値．もし真なら，
      属性を \code{\link{attr}} を使って取り出す際に部分マッチングが
      使われると警告する．}

    \item{\code{warnPartialMatchDollar}:}{論理値．もし真なら，
      \code{$} を使った抽出に対し部分マッチングが使われると警告する．}

    \item{\code{warning.expression}:}{警告が出ると呼び出される
      \R cコードの表現式で，標準メッセージを置き換える．もし
      ヌルでなければオプション \code{warn} の値にかかわらず
      これが呼び出される．}

    \item{\code{warning.length}:}{警告とエラーに対する打ち切り限界を
      設定する．100\dots8170 の範囲の非負の整数で，既定値は 1000．}

    \item{\code{nwarnings}:}{\code{warn = 0} の時に保存する警告の数で，
      既定値は 50．これはそれらが集められている間に呼び出されると
      メッセージを捨て去る．}

    \item{\code{width}:}{ベクトル，行列そして配列をプリントする際と，
      \code{\link{cat}} で埋める際に
      使われる一行あたりの列数の最大値．

      東アジアの言語を除き，列は普通文字と同じである．

      \R が稼働しているウィンドウのサイズを変えた時これを変更したくなる
      かもしれない．適正な値は 10\dots10000 で，既定値は普通 80．
      (適正値の限界はファイル\file{Print.h} 中にあり，\R を
      再コンパイルすることで変更できる．)
      ある種の \R コンソールはサイズを変更されると自動的に値を変更する．

      \R が起動した時の端末の幅からこれを自動的に設定する一つの方法
      に付いては \link{Startup} の例を見よ．}
    }

  これらのオプションの幾つかの\sQuote{工場出荷時}既定設定は
  \tabular{ll}{
    \code{add.smooth} \tab \code{TRUE}\cr
    \code{check.bounds} \tab \code{FALSE}\cr
    \code{continue} \tab \code{"+ "}\cr
    \code{digits} \tab \code{7}\cr
    \code{echo} \tab \code{TRUE}\cr
    \code{encoding} \tab \code{"native.enc"}\cr
    \code{error} \tab \code{NULL}\cr
    \code{expressions} \tab \code{5000}\cr
    \code{keep.source} \tab \code{interactive()}\cr
    \code{keep.source.pkgs} \tab \code{FALSE}\cr
    \code{max.print} \tab \code{99999}\cr
    \code{OutDec} \tab \code{"."}\cr
    \code{prompt} \tab \code{"> "}\cr
    \code{scipen} \tab \code{0} \cr
    \code{show.error.messages} \tab \code{TRUE}\cr
    \code{timeout} \tab \code{60}\cr
    \code{verbose} \tab \code{FALSE}\cr
    \code{warn} \tab \code{0}\cr
    \code{warning.length} \tab \code{1000}\cr
    \code{width}  \tab \code{80}\cr
  }
  他のものは環境変数で設定されたり，プラットフォーム依存である．
}

\section{パッケージ grDevices 中のオプション設定}{
  これらはパッケージ \pkg{grDevices} (又はその名前空間)がロードされた時に
  まだ設定されていなければ設定される．
  \describe{
#ifdef unix
    \item{\code{bitmapType}:}{(Unix のみ)文字．\code{\link{png}}
      のようなビットマップデバイスに対する既定タイプ．
      利用できる場合は既定値は \code{"cairo"} か，又は
      OS X では利用できれば \code{"quartz"}．}
#endif

    \item{\code{device}:}{関数の名前を与える文字列か関数オブジェクト自体で，
      呼び出されるとそのセッションの既定タイプの
      新しいグラフィックスデバイスを作り出す．
      このオプションの値の既定値は対話的なセッションに対しては通常の
      スクリーンデバイス(例えば \code{X11}, \code{windows} 又は
      \code{quartz})で，バッチしようかスクリーンが利用できなければ \code{pdf}
      である．もしデバイスの名前に設定されれば，デバイスは最初
      大局的環境(通常の検索パスの下)，そしてそれから
      パッケージ \pkg{grDevices} の名前空間から探される．

      対話的と非対話的セッション中の既定値はそれぞれ環境変数
      \env{R_INTERACTIVE_DEVICE} と \env{R_DEFAULT_DEVICE}
      を使ってで設定できる．

      \sQuote{通常のスクリーンデバイス}に対する
      検索のロジックは，
      Windows では \code{windows}，そして OS X では利用できれば \code{quartz}
      (コンソールで実行し，構築時にコンパイルできる)．
      さもなければもし環境変数 \env{DISPLAY} が設定されていれば \code{X11} が
      使われる．
    }

    \item{\code{device.ask.default}:}{論理値．デバイスがオープン
    された時の \code{\link{devAskNewPage}("ask")} に対する既定値．}

    \item{\code{locatorBell}:}{論理値．\code{locator} と 
      \code{identify} 中の選択ベルで確認すべきか?
      既定値は \code{TRUE}．少なくとも \code{X11} と \code{windows}
      デバイスでは尊重される．}

#ifdef windows
    \item{\code{windowsTimeout}:}{(Windows のみ)長さ 2 の整数ベクトルで
      ミリ秒単位の時間を表現する．これらはそれが有効にされた時
      \code{\link{windows}} のダブルバッファリングを制御する：
      最初はプロットが終了した後の遅延(既定値 100)で，二番目は連続するプロット
      の間の更新期間(既定 500)である．デバイスがオープンした時の値が
      使われる．}
#endif
  }
}
\section{パッケージ graphics で使われる他のオプション}{
  \describe{
    \item{\code{max.contour.segments}:}{正整数で，もし未設定ならば既定値は
      \code{25000}．\code{\link{contourLines}} や \code{\link{contour}} の
      一つの等高線中の線分の数の上限．}
  }
}
\section{パッケージ stats 中のオプション設定}{
  これらはパッケージ \pkg{stats} (またはその名前空間)がロードされた時
  まだ未設定ならば設定される．
  \describe{
    \item{\code{contrasts}:}{既定の \code{\link{contrasts}} が
       \code{\link{aov}} や \code{\link{lm}} 等を用いたモデル当てはめで
       使われる．長さ 2 の文字列ベクトルで，最初は順序無しの因子とともに使われる
       関数，二つ目は順序付き因子と共に使われる関数を与える．
       既定では要素は名前 \code{c("unordered", "ordered")} を
       持つが，名前は使われない．}

    \item{\code{na.action}:}{ある種の状況で欠損値
      (\code{\link{NA}})の処理用に使われる関数名．}

    \item{\code{show.coef.Pvalues}:}{論理値，P 値が係数の要約表中に
      印刷されるかどうかに影響する．
      \code{\link{printCoefmat}} を見よ．}

    \item{\code{show.nls.convergence}:}{論理値，\code{\link{nls}} の
      成功した当てはめに対して収束メッセージをプリントするか?}

    \item{\code{show.signif.stars}:}{論理値，係数の要約表に星印をプリントする
      べきか? \code{\link{printCoefmat}} を見よ．}

    \item{\code{ts.eps}:}{ある種の時系列(\code{\link{ts}})計算に対する
       相対許容度．既定値は \code{1e-05}．}

    \item{\code{ts.S.compat}:}{論理値．時系列スペクトラムの
      プロットを S 互換にするため使われる．
      \code{\link{plot.spec}} 中の引数 \code{log} の説明を見よ．}
    }
}
\section{パッケージ utils 中のオプション設定}{
  これらはパッケージ \pkg{utils} (又はその名前空間)がロードされた時に
  まだ未設定ならば設定される．
  \describe{
    \item{\code{BioC_mirror}:}{
      \code{\link{setRepositories}} が使う Bioconductor のミラーの URL．
      例えば既定値の \samp{"http://bioconductor.org"} 又は
      ヨーロッパのミラー\cr
      \samp{"http://bioconductor.statistik.tu-dortmund.de"}．
      \code{\link{chooseBioCmirror}} で設定できる．}

    \item{\code{browser}:}{
      \code{\link{browseURL}} が使う HTML ブラウザ．
      これは UNIX では既定のブラウザを，また Windows では
      既定でないブラウザを設定する．
      URL を引数に持ち呼び出される \R 関数でも良い．
      より詳細は \code{\link{browseURL}} を見よ．}

    \item{\code{ccaddress}:}{既定値は
      \code{\link{create.post}} (そして \code{\link{bug.report}}が
      使用する Cc: アドレスと\cr
      \code{\link{help.request}})．
      \code{FALSE} や \code{""} でも良い．}

    \item{\code{citation.bibtex.max}:}{既定値は 1； \code{\link{citation}}
      中の文献項目(\code{\link{bibentry}})の最大数で，
      テキストと並んで bibtex バージョンがプリントされる．}

    \item{\code{de.cellwidth}:}{整数：データエディタ \code{\link{dataentry}}
      中で使われるセル幅(文字数単位)．
      もし未設定(既定), 0, 負，又は \code{NA} ならば可変セル幅が使われる．}

    \item{\code{demo.ask}:}{\code{\link{demo}} 関数の \code{ask} 引数に対する
      既定値．}

    \item{\code{editor}:}{例えば \code{\link{edit}} 用の既定のテキストエディタ
      を設定する空でない文字列化関数．UNIX では環境変数
      \env{EDITOR} から設定される．又はもし未設定なら
      \env{VISUAL} か \command{vi}．}

    \item{\code{example.ask}:}{
      \code{\link{example}} 関数の \code{ask} 引数に対する既定値．}

    \item{\code{help.ports}:}{内部 HTTP サーバーのポートを設定する
      オプションの整数ベクトル，\cr
      \code{\link{startDynamicHelp}} を見よ．}

    \item{\code{help.search.types}:}{
      \code{\link{help.search}} と \code{\link{??}} によって探される
      ドキュメントの既定タイプ．}

    \item{\code{help.try.all.packages}:}{
      \code{\link{help}} のある引数に対する既定値．}

    \item{\code{help_type}:}{
      \code{\link{help}} のある引数に対する既定値で，
      また \code{\link{?}} によるヘルプのタイプとして使われる．}

    \item{\code{HTTPUserAgent}:}{
      HTTP(S) リクエスト中でユーザエージェントとして使われる文字列．
      もし \code{NULL} ならリクエストはユーザエージェントのヘッダ無しで
      行われる．
      既定値は\cr
      \code{R (<version> <platform> <arch> <os>)}．}
      
    \item{\code{install.lock}:}{論理値：
      \code{\link{install.packages}} がディレクトリ毎の
      パッケージのロックを使うべきか? OS X と Windows で
      最も役に立つが，\command{R CMD \link{INSTALL}} による
      ソースのインストールに対してスタートアップファイル中でも
      使うことができる．
      バイナリのインストールに対しては文字列 \code{"pkgloack"}
      でも良い．}

    \item{\code{internet.info}:}{URL からのダウンロード時に
      プリントされる情報の最小レベル．\code{"internal"} と
      \code{"libcurl"} メソッドが使われる．
      既定値は 2 で失敗用．より詳細な情報を得るには 1 か
      0 に設定する(the \code{"internal"} メソッドでは 0 は
      1 よりも多くの情報を与える)．
    }

    \item{\code{install.packages.check.source}:}{
      バイナリパッケージをサポートするプラットフォーム上で
      \code{\link{install.packages}} (そして間接的に
      \code{\link{update.packages}})により使われる．
      可能な値は \code{"yes"} と \code{"no"} で，
      未設定は \code{"yes"} と同値である．}

    \item{\code{install.packages.compile.from.source}:}{
      バイナリパッケージをサポートするプラットフォーム上で
      \code{\link{install.packages}(type = "both")} (そして間接的に
      \code{\link{update.packages}})により使われる．
      可能な値は \code{"never"}, \code{"interactive"}
      (これは対話的使用では問い合わせを
      バッチ使用では \code{"never"} を意味する)，そして \code{"always"}
      である．既定値は環境変数
      \env{R_COMPILE_AND_INSTALL_PACKAGES} から取られ，もし未設定ならば
      既定値は，環境変数 \env{MAKE} を参照して \command{make} プログラム
      が見つからない限り \code{"never"} を使う．}

    \item{\code{mailer}:}{
      \code{\link{create.post}} そして，従って \code{\link{bug.report}} と
      \code{\link{help.request}} によって使われる既定の電子メイルメソッド．}

    \item{\code{menu.graphics}:}{論理値：もし利用可能ならグラフィカルな
      メニューを使うべきか．既定値は \code{TRUE}．現在
      \code{\link{select.list}}, \code{\link{chooseCRANmirror}},
      \code{\link{setRepositories}} そして \code{\link{help}} 中で
      複数の(テキスト)ヘルプファイルからの選択に使われる．}

    \item{\code{pkgType}:}{ダウンロードしインストールされる
      パッケージの既定タイプ 
      -- \code{\link{install.packages}} を見よ．
#ifdef windows
      可能な値は \code{"win.binary"}, \code{"source"} そして
      \code{"both"} (既定値)．ある種の OS X 用の構築は
      \code{"mac.binary"} と \code{"mac.binary.mavericks"} を使う．
#endif
#ifdef unix
      可能な値は \code{"source"} (CRAN の OS X 構築下を除き既定値),
      \code{"mac.binary."}, \code{"mac.binary.mavericks"} そして
      \code{"both"} (CRAN の OS X 構築に対する既定値)．
      Windows は \code{"win.binary"}． (\code{"mac.binary.leopard"} そして
      \code{"mac.binary.universal"} は最早使われない．)
#endif
      値 \code{"binary"} はネイティブのバイナリタイプの同義語である
      (もしそうしたものがあれば)；
      \code{"both"} は \code{\link{install.packages}} により
      ソースとバイナリインストールのどちらかを選択するために使われる．
    }

    \item{\code{repos}:}{
      \code{\link{update.packages}} が使うためのレポジトリの URL．
      既定は \code{c(CRAN="@CRAN@")} で，幾つかのユーティリティが
      CRAN ミラーの選択を促す．これを避けるには CRAN ミラーを
      次のようなもので設定する\cr
      \code{local({r <- getOption("repos"); r["CRAN"] <- "http://my.local.cran";
                   options(repos = r)})}．

      \code{\link{setRepositories}} を使ってより多くのレポジトリ
      (Bioconductor と Omegahat, R-Forge, Rforge.net \dots)
      を付け加えられることを注意する．
    }
    \item{\code{SweaveHooks}, \code{SweaveSyntax}:}{
      \code{\link{Sweave}} を見よ．
    }

    \item{\code{unzip}:}{\code{\link{unzip}} によって使われる文字列：
      外部プログラム \command{unzip} や \code{"internal"} へのパス．
#ifdef unix
      既定値は \env{R_UNZIPCMD} の値で，これは
      \code{unzip} 命令がコンフィギュレーションの間に見つかれば
      \file{etc/Renviron} 中に設定される．
#endif
#ifdef windows
      内部的な unzip コードが使われる時既定値は \code{"internal"}．
#endif
    }
      
    \item{\code{useHTTPS}:}{論理値．\code{\link{chooseCRANmirror}} が
      使う：安全なミラーが好ましいか?  もし未設定ならば \code{TRUE} が仮定される．}
  }
}
\section{パッケージ parallel 中のオプション設定}{
  これらはパッケージ \pkg{parallel} (またはその名前空間)が
  ロードされた時にまだ未設定なら設定される．
  \describe{
    \item{\code{mc.cores}:}{現在の \R プロセスと並列に実行が許される
      \emph{追加の} \R プロセスの最大許容数を与える整数．
      既定値はもし設定されていれば環境変数 \env{MC_CORES} の設定．
      これを使う殆どのアプリケーションは，もし未設定ならば
      制限 \code{2} を使う．
    }
  }
}
\section{Unix だけで使われるオプション}{
  \describe{
    \item{\code{dvipscmd}:}{ポストスクリプトを使って
    ヘルプページをオフラインでプリントする(廃止された)のに使われる命令を与える
    文字列．既定値は \command{"dvips"}．}
  }
}
\section{Windows だけで使われるオプション}{
  \describe{
    \item{\code{warn.FPU}:}{論理値，既定では定義されていない．もし真なら
      \link{dyn.load} がバグのある DLL でダメージを受けた制御ワードを
      修復するたびに警告が出される．}
  }
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\examples{
op <- options(); utils::str(op) # op は名前付きリスト

getOption("width") == options()$width # 後者はより多くのメモリを必要とする
options(digits = 15)
pi

# エディタをセットし，前の値を保存
old.o <- options(editor = "nedit")
old.o

options(check.bounds = TRUE, warn = 1)
x <- NULL; x[4] <- "yes" # 警告を与える

options(digits = 5)
print(1e5)
options(scipen = 3); print(1e5)

options(op)     # (全ての)初期オプションをリセット
options("digits")

\dontrun{## コントラスト処理を S のように設定
options(contrasts = c("contr.helmert", "contr.poly"))
}

\dontrun{## エラー時に R セッションをエラー状態 66 で停止
options(error = quote(q("no", status = 66, runLast = FALSE)))
stop("test it")
}

\dontrun{## デバッグ用にエラー時の挙動を設定
## エラー時にブラウザを開く，?recover を見よ：
options(error = recover)
## 後で debugger() を呼び出せる用意をする，?debugger を見よ：
options(error = dump.frames)
## 非対話的なセッションのための可能な設定
options(error = quote({dump.frames(to.file = TRUE); q()}))
}

  # オプションを得る二つの方法を比較し，それを
  # 未設定の可能性を考慮し使う．
if(as.logical(getOption("performCleanp", TRUE)))
   cat("do cleanup\n")

\dontrun{
  # 上を既定値無しに表現するよりぎこちない方法
tmp <- getOption("performCleanup")
if(is.null(tmp))
  tmp <- TRUE
if(tmp)
   cat("do cleanup\n")
}

}
\keyword{environment}
\keyword{error}
\keyword{print}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/options.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{options}
%\alias{options}
%\alias{.Options}
%\alias{getOption}
%\alias{option} % so help files can do 'set \link{} \code{"foo"}'
%
%\alias{MC_CORES}
%\alias{R_C_BOUNDS_CHECK}
%\alias{R_DEFAULT_DEVICE}
%\alias{R_KEEP_PKG_SOURCE}
%\alias{R_INTERACTIVE_DEVICE}
%
%\title{Options Settings}
%\description{
%  Allow the user to set and examine a variety of global \emph{options}
%  which affect the way in which \R computes and displays its results.
%}
%\usage{
%options(\dots)
%
%getOption(x, default = NULL)
%
%.Options
%}
%%%-- NOTE : Keep the list up-to-date,
%%%-- ====   Consider also the leading comments in ../../../main/options.c
%\arguments{
%  \item{\dots}{any options can be defined, using \code{name = value}.
%    However, only the ones below are used in base \R.
%
%    Options can also be passed by giving a single unnamed argument which
%    is a named list.
%  }
%  \item{x}{a character string holding an option name.}
%
%  \item{default}{if the specified option is not set in the options list,
%    this value is returned.  This facilitates retrieving an option and
%    checking whether it is set and setting it separately if not.}
%}
%\details{
%  Invoking \code{options()} with no arguments returns a list with the
%  current values of the options.  Note that not all options listed below
%  are set initially.  To access the value of a single option, one should
%  use, e.g., \code{getOption("width")} rather than
%  \code{options("width")} which is a \emph{list} of length one.
%}
%
%\note{
%  For compatibility with S there is a visible object \code{.Options} whose
%  value is a pairlist containing  the current \code{options()} (in no
%  particular order).  Assigning to it will make a local copy and not
%  change the original.
%}
%\value{
%  For \code{getOption}, the current value set for option \code{x}, or
%  \code{NULL} if the option is unset.
%
%  For \code{options()}, a list of all set options sorted by name.  For
%  \code{options(name)}, a list of length one containing the set value,
%  or \code{NULL} if it is unset.  For uses setting one or more options,
%  a list with the previous values of the options changed (returned
%  invisibly).
%}
%\section{Options used in base \R}{
%  \describe{
%    \item{\code{add.smooth}:}{typically logical, defaulting to
%      \code{TRUE}.  Could also be set to an integer for specifying how
%      many (simulated) smooths should be added.  This is currently only
%      used by \code{\link{plot.lm}}.}
%
%    \item{\code{browserNLdisabled}:}{logical: whether newline is
%      disabled as a synonym for \code{"n"} in the browser.}
%
%    \item{\code{checkPackageLicense}:}{logical, not set by default.  If
%      true, \code{\link{library}} asks a user to accept any non-standard
%      license at first use.
%    }
%
%    \item{\code{check.bounds}:}{logical, defaulting to \code{FALSE}.  If
%      true, a \link{warning} is produced whenever a
%      vector (atomic or \code{\link{list}}) is extended, by something
%      like \code{x <- 1:3; x[5] <- 6}.}
%
%    \item{\code{CBoundsCheck}:}{logical, controlling whether
%      \code{\link{.C}} and \code{\link{.Fortran}} make copies to check for
%      array over-runs on the atomic vector arguments.
%
%      Initially set from value of the environment variable
%      \env{R_C_BOUNDS_CHECK} (set to \code{yes} to enable).}
%
%    \item{\code{continue}:}{a non-empty string setting the prompt used
%      for lines which continue over one line.}
%
%    %%  default is set in ../../profile/Common.R :
%    \item{\code{defaultPackages}:}{the packages that are attached by
%      default when \R starts up.  Initially set from value of the
%      environment variable \env{R_DEFAULT_PACKAGES}, or if that is unset
%      to \code{c("datasets", "utils", "grDevices", "graphics", "stats",
%        "methods")}.  (Set \env{R_DEFAULT_PACKAGES} to \code{NULL} or
%      a comma-separated list of package names.)  It will not work to set
%      this in a \file{.Rprofile} file, as its value is consulted before
%      that file is read.}
%
%    \item{\code{deparse.cutoff}:}{integer value controlling the
%      printing of language constructs which are \code{\link{deparse}}d.
%      Default \code{60}.
%    }
%
%    \item{\code{deparse.max.lines}:}{controls the number of lines used
%      when deparsing in \code{\link{traceback}}, \code{\link{browser}},
%      and upon entry to a function whose debugging flag is set.
%      Initially unset, and only used if set to a positive integer.}
%
%    \item{\code{digits}:}{controls the number of digits to print when
%      printing numeric values.  It is a suggestion only.  Valid values
%      are 1\dots{}22 with default 7.  See the note in
%      \code{\link{print.default}} about values greater than 15.}
%
%    \item{\code{digits.secs}:}{controls the maximum number of digits to
%      print when formatting time values in seconds.  Valid values
%      are 0\dots6 with default 0.  See \code{\link{strftime}}.}
%
%    \item{\code{download.file.extra}:}{Extra command-line argument(s) for
%      non-default methods: see \code{\link{download.file}}.}
%
%    \item{\code{download.file.method}:}{Method to be used for
%      \code{download.file}.  Currently download methods
%      \code{"internal"}, \code{"wininet"} (Windows only),
%      \code{"libcurl"}, \code{"wget"} and \code{"curl"} are available.
%      If not set, \code{method = "auto"}
%      is chosen: see \code{\link{download.file}}.}
%
%    \item{\code{echo}:}{logical.  Only used in non-interactive mode,
%      when it controls whether input is echoed.  Command-line option
%      \option{--slave} sets this to \code{FALSE}, but otherwise
%      it starts the session as \code{TRUE}.}
%
%    \item{\code{encoding}:}{The name of an encoding, default
%      \code{"native.enc"}.  See \code{\link{connections}}.}
%
%    \item{\code{error}:}{either a function or an expression governing
%      the handling of non-catastrophic errors such as those generated by
%      \code{\link{stop}} as well as by signals and internally detected
%      errors.  If the option is a function, a call to that function,
%      with no arguments, is generated as the expression.  The default
%      value is \code{NULL}: see \code{\link{stop}} for the behaviour in
%      that case.  The functions \code{\link{dump.frames}} and
%      \code{\link{recover}} provide alternatives that allow post-mortem
%      debugging.  Note that these need to specified as
%      e.g.\sspace{}\code{options(error = utils::recover)} in startup
%      files such as \file{\link{.Rprofile}}.}
%
%    \item{\code{expressions}:}{sets a limit on the number of nested
%      expressions that will be evaluated.  Valid values are
%      25\dots500000 with default 5000.  If you increase it, you may
%      also want to start \R with a larger protection stack;
%      see \option{--max-ppsize} in \code{\link{Memory}}.  Note too that
%      you may cause a segfault from overflow of the C stack, and on OSes
%      where it is possible you may want to increase that.  Once the
%      limit is reached an error is thrown.  The current number under
%      evaluation can be found by calling \code{\link{Cstack_info}}.}
%
%    \item{\code{keep.source}:}{When \code{TRUE}, the source code for
%      functions (newly defined or loaded) is stored internally
%      allowing comments to be kept in the right places.  Retrieve the
%      source by printing or using \code{deparse(fn, control =
%      "useSource")}.
%
%      The default is \code{\link{interactive}()}, i.e., \code{TRUE} for
%      interactive use.}
%
%    %% used by tools::makeLazyLoading
%    \item{\code{keep.source.pkgs}:}{As for \code{keep.source}, used only
%    when packages are installed.  Defaults to \code{FALSE} unless the
%    environment variable \env{R_KEEP_PKG_SOURCE} is set to \code{yes}.}
%
%    \item{\code{max.print}:}{integer, defaulting to \code{99999}.
%      \code{\link{print}} or \code{\link{show}} methods can make use of
%      this option, to limit the amount of information that is printed,
%      to something in the order of (and typically slightly less than)
%      \code{max.print} \emph{entries}.}
%
%    \item{\code{OutDec}:}{character string containing a single
%      character.  The preferred character to be used as the decimal
%      point in output conversions, that is in printing, plotting,
%      \code{\link{format}} and \code{\link{as.character}} but not when
%      deparsing nor by \code{\link{sprintf}} nor \code{\link{formatC}}
%      (which are sometimes used prior to printing.)
%
%      Only single-byte characters were supported prior to \R 3.2.0.
%      In \R 3.2.1 and earlier, multi- (or zero-) character \code{OutDec}
%      were accepted, but always worked only partially.
%    }
%
%    \item{\code{pager}:}{the command used for displaying text files by
%      \code{\link{file.show}}.
%#ifdef unix
%      Defaults to \file{\var{\link{R_HOME}}/bin/pager}, which is a shell
%      script running the command-line specified by the environment
%      variable \env{PAGER} whose default is set at configuration,
%      usually to \command{less}.
%#endif
%#ifdef windows
%      Defaults to \code{"internal"}, which uses a pager similar to the
%      GUI console.  Another possibility is \code{"console"} to use the
%      console itself.
%#endif
%      Can be a character string or an \R function, in which case it
%      needs to accept the arguments \code{(files, header,
%	title, delete.file)} corresponding to the first four arguments of
%      \code{\link{file.show}}.}
%
%    \item{\code{papersize}:}{the default paper format used by
%      \code{\link{postscript}};  set by environment variable
%      \env{R_PAPERSIZE} when \R is started: if that is unset or invalid
%      it defaults to
%#ifdef unix
%      a value derived from the locale category \code{LC_PAPER}, or
%      if that is unavailable to a default set when \R was built.
%#endif
%#ifdef windows
%      \code{"a4"}, or \code{"letter"} in US and Canadian locales.
%#endif
%    }
%
%    \item{\code{pdfviewer}:}{default PDF viewer.
%      The default is set from the environment variable \env{R_PDFVIEWER},
%#ifdef unix
%      the default value of which is set when \R is configured.
%#endif
%#ifdef windows
%      which defaults to the full path to \command{open.exe}, a utility
%      supplied with \R.
%#endif
%    }
%
%    \item{\code{printcmd}:}{the command used by \code{\link{postscript}}
%      for printing; set by environment variable \env{R_PRINTCMD} when
%      \R is started.  This should be a command that expects either input
%      to be piped to \file{stdin} or to be given a single filename
%      argument.  Usually set to \code{"lpr"} on a Unix-alike.}
%
%    \item{\code{prompt}:}{a non-empty string to be used for \R's prompt;
%      should usually end in a blank (\code{" "}).}
%
%      % verbatim, for checking " \t\n\"\\'`><=%;,|&{()}"
%#ifdef unix
%    \item{\code{rl_word_breaks}:}{Used for the readline-based terminal
%      interface.  Default value \code{" \\t\\n\\"\\\\'`><=\%;,|&{()}"}.%"
%
%      This is the set of characters use to break the input line into
%      tokens for object- and file-name completion.  Those who do not use
%      spaces around operators may prefer\cr
%      \code{" \\t\\n\\"\\\\'`><=+-*\%;,|&{()}"}%"
%      }
%#endif
%
%    \item{\code{save.defaults}, \code{save.image.defaults}:}{
%      see \code{\link{save}}.}
%
%    \item{\code{scipen}:}{integer.  A penalty to be applied
%      when deciding to print numeric values in fixed or exponential
%      notation.  Positive values bias towards fixed and negative towards
%      scientific notation: fixed notation will be preferred unless it is
%      more than \code{scipen} digits wider.}
%
%    \item{\code{showWarnCalls}, \code{showErrorCalls}:}{a logical.
%      Should warning and error messages show a summary of the call
%      stack?  By default error calls are shown in non-interactive
%      sessions.}
%
%    \item{\code{showNCalls}:}{integer.  Controls how long the sequence
%      of calls must be (in bytes) before ellipses are used.  Defaults to
%      40 and should be at least 30 and no more than 500.}
%
%    \item{\code{show.error.locations}:}{Should source locations of
%      errors be printed?  If set to \code{TRUE} or \code{"top"}, the
%      source location that is highest on the stack (the most recent
%      call) will be printed.  \code{"bottom"} will print the location
%      of the earliest call found on the stack.
%
%      Integer values can select other entries.  The value \code{0}
%      corresponds to \code{"top"} and positive values count down the
%      stack from there.  The value \code{-1} corresponds to
%      \code{"bottom"} and negative values count up from there.
%      }
%
%    \item{\code{show.error.messages}:}{a logical.  Should error messages
%      be printed?  Intended for use with \code{\link{try}} or a
%      user-installed error handler.}
%
%    \item{\code{stringsAsFactors}:}{The default setting for arguments of
%      \code{\link{data.frame}} and \code{\link{read.table}}.}
%
%    \item{\code{texi2dvi}:}{used by functions
%      \code{\link{texi2dvi}} and \code{\link{texi2pdf}} in package \pkg{tools}.
%#ifdef unix
%      Set at startup from the environment variable \env{R_TEXI2DVICMD}.
%#endif
%    }
%
%    \item{\code{timeout}:}{integer.  The timeout for some Internet
%      operations, in seconds.  Default 60 seconds.  See
%      \code{\link{download.file}} and \code{\link{connections}}.}
%
%    \item{\code{topLevelEnvironment}:}{see \code{\link{topenv}} and
%      \code{\link{sys.source}}.}
%
%    \item{\code{url.method}:}{character string: the default method for
%      \code{\link{url}}.  Normally unset, which is equivalent to
%      \code{"default"}, which is \code{"internal"} except on Windows.}
%
%    \item{\code{useFancyQuotes}:}{controls the use of
%      directional quotes in \code{\link{sQuote}}, \code{dQuote} and in
%      rendering text help (see \code{\link{Rd2txt}} in package
%      \pkg{tools}).  Can be \code{TRUE}, \code{FALSE}, \code{"TeX"} or
%      \code{"UTF-8"}.}
%
%    \item{\code{verbose}:}{logical.  Should \R report extra information
%      on progress?  Set to \code{TRUE} by the command-line option
%      \option{--verbose}.}
%
%    \item{\code{warn}:}{sets the handling of warning messages.  If
%      \code{warn} is negative all warnings are ignored.  If \code{warn}
%      is zero (the default) warnings are stored until the top--level
%      function returns.  If 10 or fewer warnings were signalled they
%      will be printed otherwise a message saying how many were
%      signalled.  An object called \code{last.warning} is
%      created and can be printed through the function
%      \code{\link{warnings}}.  If \code{warn} is one, warnings are
%      printed as they occur.  If \code{warn} is two or larger all
%      warnings are turned into errors.}
%
%    \item{\code{warnPartialMatchArgs}:}{logical.  If true, warns if
%      partial matching is used in argument matching.}
%
%    \item{\code{warnPartialMatchAttr}:}{logical.  If true, warns if
%      partial matching is used in extracting attributes via
%      \code{\link{attr}}.}
%
%    \item{\code{warnPartialMatchDollar}:}{logical.  If true, warns if
%      partial matching is used for extraction by \code{$}.}
%
%    \item{\code{warning.expression}:}{an \R code expression to be called
%      if a warning is generated, replacing the standard message.  If
%      non-null it is called irrespective of the value of option
%      \code{warn}.}
%
%    \item{\code{warning.length}:}{sets the truncation limit for error
%      and warning messages.  A non-negative integer, with allowed values
%      100\dots8170, default 1000.}
%
%    \item{\code{nwarnings}:}{the limit for the number of warnings kept
%      when \code{warn = 0}, default 50.  This will discard messages if
%      called whilst they are being collected.}
%
%    \item{\code{width}:}{controls the maximum number of columns on a
%      line used in printing vectors, matrices and arrays, and when
%      filling by \code{\link{cat}}.
%
%      Columns are normally the same as characters except in East Asian
%      languages.
%
%      You may want to change this if you re-size the window that \R is
%      running in.  Valid values are 10\dots10000 with default normally
%      80.  (The limits on valid values are in file \file{Print.h} and can be
%      changed by re-compiling \R.)  Some \R consoles automatically change
%      the value when they are resized.
%
%      See the examples on \link{Startup} for one way to set this
%      automatically from the terminal width when \R is started.
%    }
% }
%
%  The \sQuote{factory-fresh} default settings of some of these options are
%  \tabular{ll}{
%    \code{add.smooth} \tab \code{TRUE}\cr
%    \code{check.bounds} \tab \code{FALSE}\cr
%    \code{continue} \tab \code{"+ "}\cr
%    \code{digits} \tab \code{7}\cr
%    \code{echo} \tab \code{TRUE}\cr
%    \code{encoding} \tab \code{"native.enc"}\cr
%    \code{error} \tab \code{NULL}\cr
%    \code{expressions} \tab \code{5000}\cr
%    \code{keep.source} \tab \code{interactive()}\cr
%    \code{keep.source.pkgs} \tab \code{FALSE}\cr
%    \code{max.print} \tab \code{99999}\cr
%    \code{OutDec} \tab \code{"."}\cr
%    \code{prompt} \tab \code{"> "}\cr
%    \code{scipen} \tab \code{0} \cr
%    \code{show.error.messages} \tab \code{TRUE}\cr
%    \code{timeout} \tab \code{60}\cr
%    \code{verbose} \tab \code{FALSE}\cr
%    \code{warn} \tab \code{0}\cr
%    \code{warning.length} \tab \code{1000}\cr
%    \code{width}  \tab \code{80}\cr
%  }
%  Others are set from environment variables or are platform-dependent.
%}
%\section{Options set in package grDevices}{
%  These will be set when package \pkg{grDevices} (or its namespace)
%  is loaded if not already set.
%  \describe{
%#ifdef unix
%    \item{\code{bitmapType}:}{(Unix-only) character.  The default type for the
%      bitmap devices such as \code{\link{png}}.  Defaults to
%      \code{"cairo"} on systems where that is available, or to
%      \code{"quartz"} on OS X where that is available.}
%#endif
%
%    \item{\code{device}:}{a character string giving
%      the name of a function, or the function object itself,
%      which when called creates a new graphics device of the default
%      type for that session.  The value of this option defaults to the
%      normal screen device (例えば  \code{X11}, \code{windows} or
%      \code{quartz}) for an interactive session, and \code{pdf}
%      in batch use or if a screen is not available.  If set to the name
%      of a device, the device is looked for first from the global
%      environment (that is down the usual search path) and then in the
%      \pkg{grDevices} namespace.
%
%      The default values in interactive and non-interactive sessions are
%      configurable via environment variables
%      \env{R_INTERACTIVE_DEVICE} and \env{R_DEFAULT_DEVICE}
%      respectively.
%
%      The search logic for \sQuote{the normal screen device} is that
%      this is \code{windows} on Windows, and \code{quartz} if available
%      on OS X (running at the console, and compiled into the build).
%      Otherwise \code{X11} is used if environment variable \env{DISPLAY}
%      is set.
%    }
%
%    \item{\code{device.ask.default}:}{logical.  The default for
%      \code{\link{devAskNewPage}("ask")} when a device is opened.}
%
%    \item{\code{locatorBell}:}{logical.  Should selection in \code{locator}
%      and \code{identify} be confirmed by a bell?  Default \code{TRUE}.
%      Honoured at least on \code{X11} and \code{windows} devices.}
%
%#ifdef windows
%    \item{\code{windowsTimeout}:}{(Windows-only) integer vector of length 2
%      representing two times in milliseconds.  These control the
%      double-buffering of \code{\link{windows}} devices when that is
%      enabled: the first is the delay after plotting finishes
%      (default 100) and the second is the update interval during
%      continuous plotting (default 500).  The values at the time the
%      device is opened are used.}
%#endif
%  }
%}
%\section{Other options used by package graphics}{
%  \describe{
%    \item{\code{max.contour.segments}:}{positive integer, defaulting to
%      \code{25000} if not set.  A limit on the number of
%      segments in a single contour line in \code{\link{contour}} or
%      \code{\link{contourLines}}.}
%  }
%}
%\section{Options set in package stats}{
%  These will be set when package \pkg{stats} (or its namespace)
%  is loaded if not already set.
%  \describe{
%    \item{\code{contrasts}:}{the default \code{\link{contrasts}} used in
%      model fitting such as with \code{\link{aov}} or \code{\link{lm}}.
%      A character vector of length two, the first giving the function to
%      be used with unordered factors and the second the function to be
%      used with ordered factors.  By default the elements are named
%      \code{c("unordered", "ordered")}, but the names are unused.}
%
%    \item{\code{na.action}:}{the name of a function for treating missing
%      values (\code{\link{NA}}'s) for certain situations.}
%
%    \item{\code{show.coef.Pvalues}:}{logical, affecting whether P
%      values are printed in summary tables of coefficients.  See
%      \code{\link{printCoefmat}}.}
%
%    \item{\code{show.nls.convergence}:}{logical, should \code{\link{nls}}
%      convergence messages be printed for successful fits?}
%
%    \item{\code{show.signif.stars}:}{logical, should stars be printed on
%      summary tables of coefficients?  See \code{\link{printCoefmat}}.}
%
%    \item{\code{ts.eps}:}{the relative tolerance for certain time series
%      (\code{\link{ts}}) computations.  Default \code{1e-05}.}
%
%    \item{\code{ts.S.compat}:}{logical.  Used to select S compatibility
%      for plotting time-series spectra.  See the description of argument
%      \code{log} in \code{\link{plot.spec}}.}
%  }
%}
%\section{Options set in package utils}{
%  These will be set when package \pkg{utils} (or its namespace)
%  is loaded if not already set.
%  \describe{
%    \item{\code{BioC_mirror}:}{The URL of a Bioconductor mirror
%      for use by \code{\link{setRepositories}},
%      e.g.\sspace{}the default \samp{"http://bioconductor.org"}
%      or the European mirror
%      \samp{"http://bioconductor.statistik.tu-dortmund.de"}.  Can be set
%      by \code{\link{chooseBioCmirror}}.}
%
%    \item{\code{browser}:}{The HTML browser to be used by
%      \code{\link{browseURL}}.  This sets the default browser on UNIX or
%      a non-default browser on Windows.  Alternatively, an \R function
%      that is called with a URL as its argument.  See
%      \code{\link{browseURL}} for further details.}
%
%    \item{\code{ccaddress}:}{default Cc: address used by
%      \code{\link{create.post}} (and hence\code{\link{bug.report}} and
%      \code{\link{help.request}}).  Can be \code{FALSE} or \code{""}.}
%
%    \item{\code{citation.bibtex.max}:}{default 1; the maximal number of
%      bibentries (\code{\link{bibentry}}) in a \code{\link{citation}} for
%      which the bibtex version is printed in addition to the text one.}
%
%    \item{\code{de.cellwidth}:}{integer: the cell widths (number of
%      characters) to be used in the data editor \code{\link{dataentry}}.
%      If this is unset (the default), 0, negative or \code{NA}, variable
%      cell widths are used.}
%
%    \item{\code{demo.ask}:}{default for the \code{ask} argument of
%      \code{\link{demo}}.}
%
%    \item{\code{editor}:}{a non-empty string or a function that sets the
%      default text editor, e.g., for \code{\link{edit}}.  Set from the
%      environment variable \env{EDITOR} on UNIX, or if unset
%      \env{VISUAL} or \command{vi}.}
%
%    \item{\code{example.ask}:}{default for the \code{ask} argument of
%      \code{\link{example}}.}
%
%    \item{\code{help.ports}:}{optional integer vector for setting ports
%      of the internal HTTP server, see \code{\link{startDynamicHelp}}.}
%
%    \item{\code{help.search.types}:}{default types of documentation
%      to be searched by \code{\link{help.search}} and \code{\link{??}}.}
%
%    \item{\code{help.try.all.packages}:}{default for an argument of
%      \code{\link{help}}.}
%
%    \item{\code{help_type}:}{default for an argument of
%    \code{\link{help}}, used also as the help type by \code{\link{?}}.}
%
%    \item{\code{HTTPUserAgent}:}{string used as the user agent in HTTP(S)
%      requests.  If \code{NULL}, requests will be made without a
%      user agent header.
%      The default is \code{R (<version> <platform> <arch> <os>)} .}
%    
%    \item{\code{install.lock}:}{logical: should per-directory package
%      locking be used by \code{\link{install.packages}}?  Most useful
%      for binary installs on OS X and Windows, but can be used in a
%      startup file for source installs \emph{via}
%      \command{R CMD \link{INSTALL}}.  For binary installs, can also be
%      the character string \code{"pkgloack"}.}
%
%    \item{\code{internet.info}:}{The minimum level of information to be
%      printed on URL downloads etc, using the \code{"internal"} and
%      \code{"libcurl"} methods.
%      Default is 2, for failure causes.  Set to 1 or 0 to get more
%      detailed information (for the \code{"internal"} method 0 provides
%      more information than 1).
%    }
%
%    \item{\code{install.packages.check.source}:}{Used by
%      \code{\link{install.packages}} (and indirectly
%      \code{\link{update.packages}}) on platforms which support binary
%      packages.  Possible values \code{"yes"} and \code{"no"}, with
%      unset being equivalent to \code{"yes"}.}
%
%    \item{\code{install.packages.compile.from.source}:}{Used by
%      \code{\link{install.packages}(type = "both")} (and indirectly
%      \code{\link{update.packages}}) on platforms which
%      support binary packages.  Possible values are \code{"never"},
%      \code{"interactive"} (which means ask in interactive use and
%      \code{"never"} in batch use) and \code{"always"}.  The default is
%      taken from environment variable
%      \env{R_COMPILE_AND_INSTALL_PACKAGES}, with default
%      \code{"interactive"} if unset.  However, \code{install.packages}
%      uses \code{"never"} unless a \command{make} program is found,
%      consulting the environment variable \env{MAKE}.}
%
%    \item{\code{mailer}:}{default emailing method used by
%      \code{\link{create.post}} and hence \code{\link{bug.report}} and
%      \code{\link{help.request}}.}
%
%    \item{\code{menu.graphics}:}{Logical: should graphical menus be used
%      if available?.  Defaults to \code{TRUE}.  Currently applies to
%      \code{\link{select.list}}, \code{\link{chooseCRANmirror}},
%      \code{\link{setRepositories}} and to select from multiple (text)
%      help files in \code{\link{help}}.}
%
%    \item{\code{pkgType}:}{The default type of packages to be downloaded
%      and installed -- see \code{\link{install.packages}}.
%#ifdef windows
%      Possible values are \code{"win.binary"}, \code{"source"} and
%      \code{"both"} (the default).  Some OS X builds use
%      \code{"mac.binary"} and \code{"mac.binary.mavericks"}.
%#endif
%#ifdef unix
%      Possible values are \code{"source"} (the default except under a
%      CRAN OS X build), \code{"mac.binary."},
%      \code{"mac.binary.mavericks"} and \code{"both"} (the default for
%      CRAN OS X builds).  Windows uses
%      \code{"win.binary"}. (\code{"mac.binary.leopard"} and
%      \code{"mac.binary.universal"} are no longer in use.)
%#endif
%      Value \code{"binary"} is a synonym for the native binary type (if
%      there is one); \code{"both"} is used by
%      \code{\link{install.packages}} to choose between source and binary
%      installs.
%    }
%
%    \item{\code{repos}:}{URLs of the repositories for use by
%      \code{\link{update.packages}}.  Defaults to
%      \code{c(CRAN="@CRAN@")}, a value that causes some utilities to
%      prompt for a CRAN mirror.  To avoid this do set the CRAN mirror,
%      by something like
%      \code{local({r <- getOption("repos"); r["CRAN"] <- "http://my.local.cran";
%                   options(repos = r)})}.
%
%      Note that you can add more repositories (Bioconductor and
%      Omegahat, R-Forge, Rforge.net \dots)
%      using \code{\link{setRepositories}}.
%    }
%    \item{\code{SweaveHooks}, \code{SweaveSyntax}:}{
%      see \code{\link{Sweave}}.
%    }
%
%    \item{\code{unzip}:}{a character string used by \code{\link{unzip}}:
%      the path of the external program \command{unzip} or \code{"internal"}.
%#ifdef unix
%      Defaults to the value of \env{R_UNZIPCMD}, which is set in
%      \file{etc/Renviron} if an \code{unzip} command was found during
%      configuration.
%#endif
%#ifdef windows
%      Defaults to \code{"internal"} when the internal unzip code is
%      used.
%#endif
%    }
%      
%    \item{\code{useHTTPS}:}{logical.  Used by \code{\link{chooseCRANmirror}}:
%      are secure mirrors preferred?  If not set, \code{TRUE} is assumed.}
%  }
%}
%\section{Options set in package parallel}{
%  These will be set when package \pkg{parallel} (or its namespace)
%  is loaded if not already set.
%  \describe{
%    \item{\code{mc.cores}:}{a integer giving the maximum allowed number
%      of \emph{additional} \R processes allowed to be run in parallel to
%      the current \R process.  Defaults to the setting of the
%      environment variable \env{MC_CORES} if set.  Most applications
%      which use this assume a limit of \code{2} if it is unset.
%    }
%  }
%}
%\section{Options used on Unix only}{
%  \describe{
%    \item{\code{dvipscmd}:}{character string giving a command to be used in
%    the (deprecated) off-line printing of help pages \emph{via}
%    PostScript.  Defaults to \command{"dvips"}.}
%  }
%}
%\section{Options used on Windows only}{
%  \describe{
%    \item{\code{warn.FPU}:}{logical, by default undefined.  If true,
%      a \link{warning} is produced whenever \link{dyn.load} repairs the
%      control word damaged by a buggy DLL.}
%  }
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%op <- options(); utils::str(op) # op is a named list
%
%getOption("width") == options()$width # the latter needs more memory
%options(digits = 15)
%pi
%
%# set the editor, and save previous value
%old.o <- options(editor = "nedit")
%old.o
%
%options(check.bounds = TRUE, warn = 1)
%x <- NULL; x[4] <- "yes" # gives a warning
%
%options(digits = 5)
%print(1e5)
%options(scipen = 3); print(1e5)
%
%options(op)     # reset (all) initial options
%options("digits")
%
%\dontrun{## set contrast handling to be like S
%options(contrasts = c("contr.helmert", "contr.poly"))
%}
%
%\dontrun{## on error, terminate the R session with error status 66
%options(error = quote(q("no", status = 66, runLast = FALSE)))
%stop("test it")
%}
%
%\dontrun{## Set error actions for debugging:
%## enter browser on error, see ?recover:
%options(error = recover)
%## allows to call debugger() afterwards, see ?debugger:
%options(error = dump.frames)
%## A possible setting for non-interactive sessions
%options(error = quote({dump.frames(to.file = TRUE); q()}))
%}
%
%  # Compare the two ways to get an option and use it
%  # acconting for the possibility it might not be set.
%if(as.logical(getOption("performCleanp", TRUE)))
%   cat("do cleanup\n")
%
%\dontrun{
%  # a clumsier way of expressing the above w/o the default.
%tmp <- getOption("performCleanup")
%if(is.null(tmp))
%  tmp <- TRUE
%if(tmp)
%   cat("do cleanup\n")
%}
%
%}
%\keyword{environment}
%\keyword{error}
%\keyword{print}
%
\encoding{UTF8}
