% File src/library/base/man/regex.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{regex}
\alias{regex}
\alias{regexp}
\alias{regular expression}
\concept{regular expression}
\title{Regular Expressions as used in R}
\description{
  このヘルプページは
  \code{\link{grep}} と関連する関数 \code{grepl}, \code{regexpr},
  \code{gregexpr}, \code{sub} and \code{gsub}，同じく
  \code{\link{strsplit}} によってサポートされている正規表現を
  解説する．
}
\details{
  \sQuote{正規表現}は文字列のセットを記述するパターンである．
  \R では二つのタイプの正規表現が使われる．
  \emph{拡張}正規表現(既定)と
  \code{perl = TRUE} で使われる\emph{Perl風} 正規表現である．
  \emph{文字どおり}の正規表現を使うと考えられる \code{fixed = TRUE} もある．
  
  正規表現を使う他の関数(しばしば \code{grep} 経由で)には
  \code{apropos}, \code{browseEnv}, \code{help.search}, \code{list.files}
  そして \code{ls} がある．
  これらは全て\emph{拡張}正規表現を使う．
  
  パターンはそれらが \code{cat} でプリントされるように記述される：
  (例えばキーボードから\emph{\R の文字列を入力する際はバックスラッシュは
  二重にする必要があることを忘れない})．

  長い正規表現は受け入れられるかもしれないし受け入れられないかもしれない：
  POSIX 標準は 256 \emph{バイト}までしか受け入れない．
}
\section{拡張正規表現}{
  この節は
  \code{grep}, \code{regexpr}, \code{gregexpr}, \code{sub},
  \code{gsub} そして \code{strsplit} の既定モードで許される
  正規表現をカバーする．
  これらは POSIX 1003.2 標準を使う：それは
  解釈に対するある種のスコープを許し，ここでの解釈は
  \R で現在使われているものである．
  この実装は標準に対する幾つかの拡張をサポートする．

  正規表現は算術表現のように
  より小さな表現へ様々な操作を使って構成される，
  表現の全体はゼロかそれ以上の文字とマッチする
  (もし \code{useBytes = TRUE} なら\sQuote{文字}を\sQuote{バイト}として
  読み込む)．

  基本的な構成ブロックは単一の文字とマッチする正規表現である．
  文字と数字を含む殆どの文字は自分自身にマッチする正規表現である．
  特別な意味を持つメタ文字は先頭にバックスラッシュを付けて引用化する．
  拡張正規表現に於けるメタ文字は
  \samp{. \\ | ( ) [ \{ ^ $ * + ?} であるが，これらが特殊な意味を持つかどうかは
  文脈によることを注意しよう．

  非メタ文字をバックスラッシュでエスケープすることは実装依存である．
  現在の実装は
  \samp{\\a} を \samp{BEL}, \samp{\\e} を \samp{ESC}, \samp{\\f} を
  \samp{FF}, \samp{\\n} を \samp{LF}, \samp{\\r} を \samp{CR} そして
  \samp{\\t} を \samp{TAB} として解釈する．(これらは \R の構文解析器
  により文字通りの文字列中で解釈されることを注意しよう．)

  \emph{文字クラス}は \samp{[} と \samp{]} で挟まれた文字のリストで，
  このリスト中の任意の単一の文字にマッチする；
  リスト中の最初の文字がカレット \samp{^} の時は例外で，
  リスト中にない任意の文字にマッチする．例えば
  正規表現 \samp{[0123456789]} は任意の一つの数字にマッチし，
  \samp{[^abc]} はもじ \samp{a}, \samp{b} 又は \samp{c} 以外と
  マッチする．文字範囲は最初と最後の文字をハイフンで分離することで
  指定できる．(これらの解釈はロケールと実装に依存するため，文字範囲は
  避けるのが好ましい．) 全てのアスキー文字を指定する可搬性のある方法は
  それら全てを文字クラスとして羅列れるすることである
  \samp{[ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz]}．
  (現在の実装はエンコーディングの数値的順序を使う．)

  幾つかの名前付き文字クラスが予め定義されている．
  それらの解釈は\emph{ロケール}に依存する(\link{locales} を見よ)；以下の
  解釈は POSIX ロケールのそれである．

  \describe{
    \item{\samp{[:alnum:]}}{英数字文字：\samp{[:alpha:]}
      と \samp{[:digit:]}．}

    \item{\samp{[:alpha:]}}{アルファベット文字：\samp{[:lower:]} と
      \samp{[:upper:]}．}

    \item{\samp{[:blank:]}}{空白文字：スペースとタブ，そして可能性として
      ロケール依存の non-breaking space のような文字．}

    \item{\samp{[:cntrl:]}}{
      制御文字．アスキーではこれらの文字は8進法コード
      000 から 037 そして 177 (\code{DEL}) を持つ．別の文字セットでは
      これらはもしあれば同値な文字である．}

    \item{\samp{[:digit:]}}{数字: \samp{0 1 2 3 4 5 6 7 8 9}.}

    \item{\samp{[:graph:]}}{グラフィカルな文字： \samp{[:alnum:]} と
      \samp{[:punct:]}．}

    \item{\samp{[:lower:]}}{現在のロケールでの小文字．}

    \item{\samp{[:print:]}}{
      プリント可能な文字：\samp{[:alnum:]}, \samp{[:punct:]} そしてスペース．}

    \item{\samp{[:punct:]}}{句読点文字:\cr
      \samp{! " # $ \% & ' ( ) * + , - . / : ; < = > ? @ [ \\ ] ^ _ ` \{ | \} ~}．}
%'"`  keep Emacs Rd mode happy

    \item{\samp{[:space:]}}{
      スペース文字：タブ，新行，垂直タブ，フォームフィード，キャリッジリターン，
      スペース，そして可能性として他のロケール依存文字．}

    \item{\samp{[:upper:]}}{現在のロケールでの大文字．}

    \item{\samp{[:xdigit:]}}{16進数:\cr
      \samp{0 1 2 3 4 5 6 7 8 9 A B C D E F a b c d e f}．}
  }

  例えば \samp{[[:alnum:]]} は \samp{[0-9A-Za-z]} を意味する．
  但し，後者はロケールと文字エンコーディングに依存する一方，
  前者はロケールと文字エンコーディングに依存しない．
  (これらのクラス名の鍵括弧はシンボリックな名前の一部であり，
  鍵括弧リストを区切る鈎括弧に加えて含める必要があることを注意しよう．)
  殆どのメタ文字は文字クラス中ではそれらの特殊意味を失う．
  文字通りの \samp{]} を含めるには，それをリストの最初に置く．
  同様に，文字通りの \samp{^} を含めるには，それを最初以外のどこかに置く．
  最後に，文字通りの \samp{-} を含めるには，それを最初か最後に置く
  (もしくは，\code{perl = TRUE} に限るが，バックスラッシュを前に置く)．
  (文字クラス中では \samp{^ - \\ ]} だけが特殊である．)

  ピリオッド \samp{.} は任意の一つの文字にマッチする．シンボル
  \samp{\\w} は{単語}文字(\samp{[[:alnum:]_]} の同義語)そして
  \samp{\\W} はその否定 (\samp{[^[:alnum:]_]}，拡張)にマッチする．
  シンボル \samp{\\d}, \samp{\\s}, \samp{\\D} そして
  \samp{\\S} は数字とスペースクラス並びにそれらの否定
  (これらは全て拡張である)を表す．

  カレット \samp{^} とドル記号 \samp{$} は
  それぞれ一行の先頭と末尾の空文字列にマッチする．
  シンボル \samp{\\<} と \samp{\\>} は単語の先頭と末尾の
  空文字列にマッチする．シンボル \samp{\\b} は単語のどちらかの
  端の空文字列にマッチし，そして \samp{\\B} は単語の端にはない
  空文字列にマッチする．(
  \sQuote{単語}の解釈はロケールと実装に依存する：
  これらは全て拡張である．)

  正規表現の後には幾つかの繰り返し指定子の一つが続くことが出来る：
  \describe{
    \item{\samp{?}}{先立つ項目はオプションで高々一回マッチされる．}

    \item{\samp{*}}{先立つ項目はゼロもしくはそれ以上の回数マッチされる．}

    \item{\samp{+}}{先立つ項目は一回もしくはそれ以上の回数マッチされる．}

    \item{\samp{{n}}}{先立つ項目は丁度 \code{n} 回マッチされる．}

    \item{\samp{{n,}}}{先立つ項目は \code{n} 回もしくはそれ以上の回数マッチされる．}

    \item{\samp{{n,m}}}{先立つ項目は少なくとも \code{n} 回，しかし
      \code{m} 回以下マッチされる．}
  }
  既定では繰り返しは貪欲であり，可能な最大の繰り返しが使われる．
  これは指定子に \code{?} を加えることで\sQuote{最少}に変更することが出来る． 
  (近似的なマッチを許す更なる指定子がある：TRE のドキュメントを見よ．)

  正規表現は連結できる；結果の正規表現は連結された副表現にマッチする部分
  文字列を連結した任意の文字列にマッチする．

  二つの正規表現は演算子 \samp{|} を間に挟んで連結できる；
  結果の正規表現はどちらかの副表現にマッチした任意の文字列にマッチする．
  例えば \samp{abba|cde} は文字列 \code{abba} 又は \code{cde} にマッチする．
  変更は文字クラス中では動作せず，\samp{|} はその文字通りの意味を持つ．

  繰り返しは連結に優先し，連結は変更に優先する．これらの優先度規則を
  打ち消すために，副表現の全体を括弧で括ることが出来る．

  後方参照 \samp{\\N}, \samp{N = 1 ... 9}, は N 番目の
  括弧で括られた正規表現の副表現にマッチされた副文字列に
  マッチする．(これは拡張正規表現に対する拡張である：POSIX は
  それらを基本的なものについてだけ定義している．)
}
\section{Perl 風正規表現}{
  \code{grep}, \code{regexpr},
  \code{gregexpr}, \code{sub}, \code{gsub} そして \code{strsplit}
  に対する  \code{perl = TRUE} 引数は Perl 5.x と同じ
  構文と語義を持つ正規表現パターンマッチングを実装する 
  PCRE ライブラリ，僅かな違いがある，に切り替える．

  完全な詳細は自分のシステムか \url{http://www.pcre.org} にあるソースの
  PCRE (PCRE2 ではなく) のマンページ，特に
  \command{man pcrepattern} と \command{manpcreapi}，を参照されたい．
  もし PCRE のサポートがソースから \R 内部にコンパイルされていれば(既定)，
  PCRE のバージョンはここで説明されたように 8.37 である．
  (使用中のバージョンは \code{\link{extSoftVersion}} の呼び出しで分かる．)

  Perl の正規表現はバイト単位又は(UTF-8)文字単位で行うことが出来る：
  後者は全ての多バイトロケールか，入力のどれかが UTF-8 と
  マークされていれば使われる(\code{\link{Encoding}} を見よ)．

  拡張正規表現に対して説明された全ての正規表現は \samp{\\<} と \samp{\\>}
  を除けば受け入れられる：Perl では全てのバックスラッシュ付きの
  メタ文字は英数字でありバックスラッシュ付きの
  シンボルは常に文字通りの文字と解釈される．
  \samp{\{} はもしそれが不正な区間指定の始点になるならば特殊ではない．
  9 以上の後方参照があっても良い(しかしながら \code{\link{sub}} 中の
  置き換えは最初の 9 個だけを参照できる)．

  文字範囲は単バイトロケールではバイトとして，
  または UTF-8 モード中の Unicode point として文字の数値的順序で解釈される．
  従ってどちらのケースでも \samp{[A-Za-z]} はアスキー文字を指定する．

  UTF-8 モードでは名前付き文字クラスはアスキー文字とだけマッチする：
  別法については下の \samp{\\p} を見よ．

  Perl 拡張では構成 \samp{(?...)} は \samp{?} の直後に続くものに
  依存して様々なやり方で使われる．

  Perl 風のマッチングは幾つかのモードで動作可能である，モードは次のオプションで
  設定される：
  \samp{(?i)} (大・小文字を区別しない，Perl の \samp{/i} に同値)，
  \samp{(?m)} (複数行，Perl の \samp{/m} に同値)，
  \samp{(?s)} (単一行，従ってドットは全ての文字，新行にすらマッチする：
               Perl の \samp{/s} に同値) そして
  \samp{(?x)} (拡張，空白データ文字はエスケープされない限り無視され，
               コメントが許される：Perl の \samp{/x} に同値)．
  これらは連結でき，従って例えば \samp{(?im)} は大・小文字を区別しない複数行
  マッチングを設定する．またこれらのオプションを文字の先頭にハイフンを付けて
  無効にでき，そして \samp{(?im-sx)} の様に設定と無効化を連結することも出来る．
  これらの設定はパターンの内部で適用でき，そうするとパターンの残りの部分に
  適用できる．Perl には無い追加のオプションは\sQuote{貪欲でない}モードを
  設定する \samp{(?U)} がある(従ってマッチングは \samp{?} が繰り返し指定子
  の一部として使われない限り最少になり，そして使われれば貪欲になる)．
  最初これらのオプションのどれもが設定されていない．

  もし文字の列から特別な意味を取り除きたければ，それらを \samp{\\Q} と
  \samp{\\E} の間に置けば良い．これは PCRE では \samp{$} と \samp{@} は
  \samp{\\Q...\\E} 列中で字義通りの文字として扱われる一方，Perl では
  \samp{$} と \samp{@} は複数の解釈を招く点で Perl と異なる．

  エスケープ列 \samp{\\d}, \samp{\\s} そして \samp{\\w} はそれぞれ
  任意の小数点，スペース文字，そして\sQuote{ワード}文字
  (現在のロケールでの文字，数字又はアンダスコア: UTF-8 モードでは
  アスキー文字と数字だけが考慮される)を表し，それらの大文字バージョンは
  それらの否定を表す．垂直タブは PCRE 8.34 (\R 3.0.3 に含まれている)以前では
  \code{C} ロケールではスペース文字とは見做されなかった．
  列 \samp{\\h}, \samp{\\v}, \samp{\\H} そして \samp{\\V} は水平と垂直スペース
  又はそれらの否定とマッチする．
  (UTF-8 モードではこれらは非アスキーの Unicode code point にマッチする．)

  追加のエスケープ列がある：\samp{\\cx} は任意の \samp{x} に対して
  \samp{cntrl-x} を，\samp{\\ddd} は8進法数字
  (\samp{\\1} から \samp{\\7} が常にそうであるように後方参照と解釈できない限り
  常に最大3桁)，そして \samp{\\xhh} は二つの16進法数字を指定する．
  UTF-8 ロケールでは \samp{\\x\{h...\}} は一つもしくはそれ以上の
  16進法数で Unicode code point を指定する．
  (これらの幾つかは \R の構文解析器により字義通りの文字列と
  解釈される)．

  文字クラスの範囲外では，\samp{\\A} は対象の始点にマッチし
  (\samp{^} とは異なり複数行モードでも)，\samp{\\Z} は対象の
  終わり又は最後の新行の前までマッチする．
  \samp{\\z} は対象の終わりだけにマッチし，\samp{\\G} は
  対象中の最初のマッチング位置にマッチする
  (これは Perl の直前のマッチの終わりとは微妙に異なる)．
  \samp{\\C} は単一のバイトとマッチする．
  新行ともマッチするがその時は警告が出る．UTF-8 モードでは
  \samp{\\R} は任意の Unicode 新行文字(単に CR だけではなく)に
  マッチし，そして \samp{\\X} は拡張 Unicode 列を形作る任意個数の
  Unicode 文字とマッチする．

  UTF-8 モードではある種の Unicode の特性は
  \samp{\p{xx}} と \samp{\P{xx}} によってサポートされるかもしれない．
  これはそれぞれ特性 \samp{xx} を持つ文字と持たない文字にマッチする．
  サポートされている特性のリストについては PCRE のドキュメントを見よ．
  例えば \samp{Lu} は\sQuote{大文字}で \samp{Sc} は\sQuote{通貨シンボル}
  である．
  (このサポートは\sQuote{Unicode 特性サポート}と共にコンパイルされた
  PCRE ライブラリに依存する：外部ライブラリはしていないかもしれない．
  これは \code{\link{pcre_config}} でチェックできる．)

  列 \samp{(?#} は次の閉じ括弧まで続くコメントの始まりをマークする．
  入れ子の括弧は許されない．コメントを形作る文字はパターンマッチングでは
  何の役割も果たさない．

  もし拡張オプションが設定されると，文字クラスの範囲外のエスケープされていない
  \samp{#} 文字は，パターン中の次の新行直前まで続くコメントをもたらす．

  パターン \samp{(?:...)} は括弧と同様に文字をグループ化するが，
  後方参照は出来ない．

  パターン \samp{(?=...)} と \samp{(?!...)} は幅がゼロの正と負の
  先読み\emph{表明}である：これらはもし
  現在の位置から前方の \code{\dots} をマッチしようとする試みが
  成功(または失敗)するとマッチするが，処理中の文字列中のどの文字も使い果たさない．
  パターン \samp{(?<=...)} と \samp{(?<!...)} は後方への同値物である：
  これらは \code{\dots} 中の繰り返し修飾子や \samp{\\C} を認めない．

  \code{regexpr} と \code{gregexpr} は\sQuote{名前付きの捕捉}をサポートする.
  もしグループが名前付き，例えば \code{"(?<first>[A-Z][a-z]+)"}，ならば，
  名前によりマッチした位置も返される．(名前を用いた後方参照は
  \code{sub} ではサポートされていない．)

  アトミックなグループ化，所有修飾子，そして条件付きと再帰的パターンは
  ここではカバーされない．
}
\author{
  このヘルプページは TRE のドキュメントと POSIX
  標準，そして PCRE 8.36 の \code{pcrepattern} のマンページに
  に基づく．
}
\seealso{
  \code{\link{grep}}, \code{\link{apropos}}, \code{\link{browseEnv}},
  \code{\link{glob2rx}}, \code{\link{help.search}}, \code{\link{list.files}},
  \code{\link{ls}} そして \code{\link{strsplit}}．

  TRE のドキュメントは
  \url{http://laurikari.net/tre/documentation/regex-syntax/})．

  POSIX 1003.2 標準は
  \url{http://pubs.opengroup.org/onlinepubs/9699919799/basedefs/V1_chap09.html}

  \code{pcrepattern} の \command{man} ページ (
  \url{http://www.pcre.org/original/pcre.txt} の一部分)，そして
  Perl 自体の実装は \url{http://perldoc.perl.org/perlre.html}．
}
\keyword{character}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/regex.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{regex}
%\alias{regex}
%\alias{regexp}
%\alias{regular expression}
%\concept{regular expression}
%\title{Regular Expressions as used in R}
%\description{
%  This help page documents the regular expression patterns supported by
%  \code{\link{grep}} and related functions \code{grepl}, \code{regexpr},
%  \code{gregexpr}, \code{sub} and \code{gsub}, as well as by
%  \code{\link{strsplit}}.
%}
%\details{
%  A \sQuote{regular expression} is a pattern that describes a set of
%  strings.  Two types of regular expressions are used in \R,
%  \emph{extended} regular expressions (the default) and
%  \emph{Perl-like} regular expressions used by \code{perl = TRUE}.
%  There is a also \code{fixed = TRUE} which can be considered to use a
%  \emph{literal} regular expression.
%
%  Other functions which use regular expressions (often via the use of
%  \code{grep}) include \code{apropos}, \code{browseEnv},
%  \code{help.search}, \code{list.files} and \code{ls}.
%  These will all use \emph{extended} regular expressions.
%
%  Patterns are described here as they would be printed by \code{cat}:
%  (\emph{do remember that backslashes need to be doubled when entering \R
%    character strings}, e.g.\sspace{}from the keyboard).
%
%  Long regular expressions may or may not be accepted: the POSIX
%  standard only requires up to 256 \emph{bytes}.
%}
%\section{Extended Regular Expressions}{
%  This section covers the regular expressions allowed in the default
%  mode of \code{grep}, \code{regexpr}, \code{gregexpr}, \code{sub},
%  \code{gsub} and \code{strsplit}.  They use an implementation of the
%  POSIX 1003.2 standard: that allows some scope for interpretation and
%  the interpretations here are those currently used by \R.  The
%  implementation supports some extensions to the standard.
%
%  Regular expressions are constructed analogously to arithmetic
%  expressions, by using various operators to combine smaller
%  expressions.  The whole expression matches zero or more characters
%  (read \sQuote{character} as \sQuote{byte} if \code{useBytes = TRUE}).
%
%  The fundamental building blocks are the regular expressions that match
%  a single character.  Most characters, including all letters and
%  digits, are regular expressions that match themselves.  Any
%  metacharacter with special meaning may be quoted by preceding it with
%  a backslash.  The metacharacters in extended regular expressions are
%  \samp{. \\ | ( ) [ \{ ^ $ * + ?}, but note that whether these have a
%  special meaning depends on the context.
%
%  Escaping non-metacharacters with a backslash is
%  implementation-dependent.  The current implementation interprets
%  \samp{\\a} as \samp{BEL}, \samp{\\e} as \samp{ESC}, \samp{\\f} as
%  \samp{FF}, \samp{\\n} as \samp{LF}, \samp{\\r} as \samp{CR} and
%  \samp{\\t} as \samp{TAB}.  (Note that these will be interpreted by
%  \R's parser in literal character strings.)
%
%  A \emph{character class} is a list of characters enclosed between
%  \samp{[} and \samp{]} which matches any single character in that list;
%  unless the first character of the list is the caret \samp{^}, when it
%  matches any character \emph{not} in the list.  For example, the
%  regular expression \samp{[0123456789]} matches any single digit, and
%  \samp{[^abc]} matches anything except the characters \samp{a},
%  \samp{b} or \samp{c}.  A range of characters may be specified by
%  giving the first and last characters, separated by a hyphen.  (Because
%  their interpretation is locale- and implementation-dependent,
%  character ranges are best avoided.)  The only portable way to specify
%  all ASCII letters is to list them all as the character class\cr
%  \samp{[ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz]}.\cr (The
%  current implementation uses numerical order of the encoding.)
%
%  Certain named classes of characters are predefined.  Their
%  interpretation depends on the \emph{locale} (see \link{locales}); the
%  interpretation below is that of the POSIX locale.
%
%  \describe{
%    \item{\samp{[:alnum:]}}{Alphanumeric characters: \samp{[:alpha:]}
%      and \samp{[:digit:]}.}
%
%    \item{\samp{[:alpha:]}}{Alphabetic characters: \samp{[:lower:]} and
%      \samp{[:upper:]}.}
%
%    \item{\samp{[:blank:]}}{Blank characters: space and tab, and
%      possibly other locale-dependent characters such as non-breaking
%      space.}
%
%    \item{\samp{[:cntrl:]}}{
%      Control characters.  In ASCII, these characters have octal codes
%      000 through 037, and 177 (\code{DEL}).  In another character set,
%      these are the equivalent characters, if any.}
%
%    \item{\samp{[:digit:]}}{Digits: \samp{0 1 2 3 4 5 6 7 8 9}.}
%
%    \item{\samp{[:graph:]}}{Graphical characters: \samp{[:alnum:]} and
%      \samp{[:punct:]}.}
%
%    \item{\samp{[:lower:]}}{Lower-case letters in the current locale.}
%
%    \item{\samp{[:print:]}}{
%      Printable characters: \samp{[:alnum:]}, \samp{[:punct:]} and space.}
%
%    \item{\samp{[:punct:]}}{Punctuation characters:\cr
%      \samp{! " # $ \% & ' ( ) * + , - . / : ; < = > ? @ [ \\ ] ^ _ ` \{ | \} ~}.}
%%'"`  keep Emacs Rd mode happy
%
%    \item{\samp{[:space:]}}{
%      Space characters: tab, newline, vertical tab, form feed, carriage
%      return, space and possibly other locale-dependent characters.}
%
%    \item{\samp{[:upper:]}}{Upper-case letters in the current locale.}
%
%    \item{\samp{[:xdigit:]}}{Hexadecimal digits:\cr
%      \samp{0 1 2 3 4 5 6 7 8 9 A B C D E F a b c d e f}.}
%  }
%
%  For example, \samp{[[:alnum:]]} means \samp{[0-9A-Za-z]}, except the
%  latter depends upon the locale and the character encoding, whereas the
%  former is independent of locale and character set.  (Note that the
%  brackets in these class names are part of the symbolic names, and must
%  be included in addition to the brackets delimiting the bracket list.)
%  Most metacharacters lose their special meaning inside a character
%  class.  To include a literal \samp{]}, place it first in the list.
%  Similarly, to include a literal \samp{^}, place it anywhere but first.
%  Finally, to include a literal \samp{-}, place it first or last (or,
%  for \code{perl = TRUE} only, precede it by a backslash).  (Only
%  \samp{^ - \\ ]} are special inside character classes.)
%
%  The period \samp{.} matches any single character.  The symbol
%  \samp{\\w} matches a \sQuote{word} character (a synonym for
%  \samp{[[:alnum:]_]}, an extension) and \samp{\\W} is its negation
%  (\samp{[^[:alnum:]_]}).  Symbols \samp{\\d}, \samp{\\s}, \samp{\\D}
%  and \samp{\\S} denote the digit and space classes and their negations
%  (these are all extensions).
%
%  The caret \samp{^} and the dollar sign \samp{$} are metacharacters
%  that respectively match the empty string at the beginning and end of a
%  line.  The symbols \samp{\\<} and \samp{\\>} match the empty string at
%  the beginning and end of a word.  The symbol \samp{\\b} matches the
%  empty string at either edge of a word, and \samp{\\B} matches the
%  empty string provided it is not at an edge of a word.  (The
%  interpretation of \sQuote{word} depends on the locale and
%  implementation: these are all extensions.)
%
%  A regular expression may be followed by one of several repetition
%  quantifiers:
%  \describe{
%    \item{\samp{?}}{The preceding item is optional and will be matched
%      at most once.}
%
%    \item{\samp{*}}{The preceding item will be matched zero or more
%      times.}
%
%    \item{\samp{+}}{The preceding item will be matched one or more
%      times.}
%
%    \item{\samp{{n}}}{The preceding item is matched exactly \code{n}
%      times.}
%
%    \item{\samp{{n,}}}{The preceding item is matched \code{n} or more
%      times.}
%
%    \item{\samp{{n,m}}}{The preceding item is matched at least \code{n}
%      times, but not more than \code{m} times.}
%  }
%  By default repetition is greedy, so the maximal possible number of
%  repeats is used.  This can be changed to \sQuote{minimal} by appending
%  \code{?} to the quantifier.  (There are further quantifiers that allow
%  approximate matching: see the TRE documentation.)
%
%  Regular expressions may be concatenated; the resulting regular
%  expression matches any string formed by concatenating the substrings
%  that match the concatenated subexpressions.
%
%  Two regular expressions may be joined by the infix operator \samp{|};
%  the resulting regular expression matches any string matching either
%  subexpression.   For example, \samp{abba|cde} matches either the
%  string \code{abba} or the string \code{cde}.  Note that alternation
%  does not work inside character classes, where \samp{|} has its literal
%  meaning.
%
%  Repetition takes precedence over concatenation, which in turn takes
%  precedence over alternation.  A whole subexpression may be enclosed in
%  parentheses to override these precedence rules.
%
%  The backreference \samp{\\N}, where \samp{N = 1 ... 9}, matches
%  the substring previously matched by the Nth parenthesized
%  subexpression of the regular expression.  (This is an
%  extension for extended regular expressions: POSIX defines them only
%  for basic ones.)
%}
%\section{Perl-like Regular Expressions}{
%  The \code{perl = TRUE} argument to \code{grep}, \code{regexpr},
%  \code{gregexpr}, \code{sub}, \code{gsub} and \code{strsplit} switches
%  to the PCRE library that implements regular expression pattern
%  matching using the same syntax and semantics as Perl 5.x,
%  with just a few differences.
%
%  For complete details please consult the man pages for PCRE (and not
%  PCRE2), especially \command{man pcrepattern} and \command{man
%  pcreapi}), on your system or from the sources at
%  \url{http://www.pcre.org}. If PCRE support was compiled from the
%  sources within \R (the default), the PCRE version is 8.37 as described
%  here.  (The version in use can be found by calling
%  \code{\link{extSoftVersion}}.)
%
%  Perl regular expressions can be computed byte-by-byte or
%  (UTF-8) character-by-character: the latter is used in all multibyte
%  locales and if any of the inputs are marked as UTF-8 (see
%  \code{\link{Encoding}}).
%
%  All the regular expressions described for extended regular expressions
%  are accepted except \samp{\\<} and \samp{\\>}: in Perl all backslashed
%  metacharacters are alphanumeric and backslashed symbols always are
%  interpreted as a literal character. \samp{\{} is not special if it
%  would be the start of an invalid interval specification.  There can be
%  more than 9 backreferences (but the replacement in \code{\link{sub}}
%  can only refer to the first 9).
%
%  Character ranges are interpreted in the numerical order of the
%  characters, either as bytes in a single-byte locale or as Unicode code
%  points in UTF-8 mode.  So in either case \samp{[A-Za-z]} specifies the
%  set of ASCII letters.
%
%  In UTF-8 mode the named character classes only match ASCII characters:
%  see \samp{\\p} below for an alternative.
%
%  The construct \samp{(?...)} is used for Perl extensions in a variety
%  of ways depending on what immediately follows the \samp{?}.
%
%  Perl-like matching can work in several modes, set by the options
%  \samp{(?i)} (caseless, equivalent to Perl's \samp{/i}), \samp{(?m)}
%  (multiline, equivalent to Perl's \samp{/m}), \samp{(?s)} (single line,
%  so a dot matches all characters, even new lines: equivalent to Perl's
%  \samp{/s}) and \samp{(?x)} (extended, whitespace data characters are
%  ignored unless escaped and comments are allowed: equivalent to Perl's
%  \samp{/x}).  These can be concatenated, so for example, \samp{(?im)}
%  sets caseless multiline matching.  It is also possible to unset these
%  options by preceding the letter with a hyphen, and to combine setting
%  and unsetting such as \samp{(?im-sx)}.  These settings can be applied
%  within patterns, and then apply to the remainder of the pattern.
%  Additional options not in Perl include \samp{(?U)} to set
%  \sQuote{ungreedy} mode (so matching is minimal unless \samp{?} is used
%  as part of the repetition quantifier, when it is greedy).  Initially
%  none of these options are set.
%
%  If you want to remove the special meaning from a sequence of
%  characters, you can do so by putting them between \samp{\\Q} and
%  \samp{\\E}. This is different from Perl in that \samp{$} and \samp{@} are
%  handled as literals in \samp{\\Q...\\E} sequences in PCRE, whereas in
%  Perl, \samp{$} and \samp{@} cause variable interpolation.
%
%  The escape sequences \samp{\\d}, \samp{\\s} and \samp{\\w} represent
%  any decimal digit, space character and \sQuote{word} character
%  (letter, digit or underscore in the current locale: in UTF-8 mode only
%  ASCII letters and digits are considered) respectively, and their
%  upper-case versions represent their negation.  Vertical tab was not
%  regarded as a space character in a \code{C} locale before PCRE 8.34
%  (included in \R 3.0.3).  Sequences \samp{\\h}, \samp{\\v}, \samp{\\H}
%  and \samp{\\V} match horizontal and vertical space or the negation.
%  (In UTF-8 mode, these do match non-ASCII Unicode code points.)
%
%  There are additional escape sequences: \samp{\\cx} is
%  \samp{cntrl-x} for any \samp{x}, \samp{\\ddd} is the
%  octal character (for up to three digits unless
%  interpretable as a backreference, as \samp{\\1} to \samp{\\7} always
%  are), and \samp{\\xhh} specifies a character by two hex digits.
%  In a UTF-8 locale, \samp{\\x\{h...\}} specifies a Unicode code point
%  by one or more hex digits.  (Note that some of these will be
%  interpreted by \R's parser in literal character strings.)
%
%  Outside a character class, \samp{\\A} matches at the start of a
%  subject (even in multiline mode, unlike \samp{^}), \samp{\\Z} matches
%  at the end of a subject or before a newline at the end, \samp{\\z}
%  matches only at end of a subject. and \samp{\\G} matches at first
%  matching position in a subject (which is subtly different from Perl's
%  end of the previous match).  \samp{\\C} matches a single
%  byte, including a newline, but its use is warned against.  In UTF-8
%  mode, \samp{\\R} matches any Unicode newline character (not just CR),
%  and \samp{\\X} matches any number of Unicode characters that form an
%  extended Unicode sequence.
%
%  In UTF-8 mode, some Unicode properties may be supported via
%  \samp{\p{xx}} and \samp{\P{xx}} which match characters with and
%  without property \samp{xx} respectively.  For a list of supported
%  properties see the PCRE documentation, but for example \samp{Lu} is
%  \sQuote{upper case letter} and \samp{Sc} is \sQuote{currency symbol}.
%  (This support depends on the PCRE library being compiled with
%  \sQuote{Unicode property support}: an external library might not be.
%  It can be checked \emph{via} \code{\link{pcre_config}}.)
%
%  The sequence \samp{(?#} marks the start of a comment which continues
%  up to the next closing parenthesis.  Nested parentheses are not
%  permitted.  The characters that make up a comment play no part at all in
%  the pattern matching.
%
%  If the extended option is set, an unescaped \samp{#} character outside
%  a character class introduces a comment that continues up to the next
%  newline character in the pattern.
%
%  The pattern \samp{(?:...)} groups characters just as parentheses do
%  but does not make a backreference.
%
%  Patterns \samp{(?=...)} and \samp{(?!...)} are zero-width positive and
%  negative lookahead \emph{assertions}: they match if an attempt to
%  match the \code{\dots} forward from the current position would succeed
%  (or not), but use up no characters in the string being processed.
%  Patterns \samp{(?<=...)} and \samp{(?<!...)} are the lookbehind
%  equivalents: they do not allow repetition quantifiers nor \samp{\\C}
%  in \code{\dots}.
%
%  \code{regexpr} and \code{gregexpr} support \sQuote{named capture}.  If
%  groups are named, e.g., \code{"(?<first>[A-Z][a-z]+)"} then the
%  positions of the matches are also returned by name.  (Named
%  backreferences are not supported by \code{sub}.)
%
%  Atomic grouping, possessive qualifiers and conditional
%  and recursive patterns are not covered here.
%}
%\author{
%  This help page is based on the TRE documentation and the POSIX
%  standard, and the \code{pcrepattern} man page from PCRE 8.36.
%}
%\seealso{
%  \code{\link{grep}}, \code{\link{apropos}}, \code{\link{browseEnv}},
%  \code{\link{glob2rx}}, \code{\link{help.search}}, \code{\link{list.files}},
%  \code{\link{ls}} and \code{\link{strsplit}}.
%
%  The TRE documentation at
%  \url{http://laurikari.net/tre/documentation/regex-syntax/}).
%
%  The POSIX 1003.2 standard at
%  \url{http://pubs.opengroup.org/onlinepubs/9699919799/basedefs/V1_chap09.html}
%
%  The \code{pcrepattern} \command{man} page (found as part of
%  \url{http://www.pcre.org/original/pcre.txt}), and details of Perl's own
%  implementation at \url{http://perldoc.perl.org/perlre.html}.
%}
%\keyword{character}
%
\encoding{UTF8}
