% File src/library/base/man/showConnections.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{showConnections}
\alias{showConnections}
\alias{getConnection}
\alias{getAllConnections}
\alias{closeAllConnections}
\alias{stdin}
\alias{stdout}
\alias{stderr}
\alias{isatty}
\title{Display Connections}
\description{
  コネクションの様相の表示．
}
\usage{
showConnections(all = FALSE)
getConnection(what)
closeAllConnections()

stdin()
stdout()
stderr()

isatty(con)
}
\arguments{
  \item{all}{論理値：もし真なら閉じられたものや標準のものを含む全てのコネクションが
    返される．もし偽なら開かれたユーザが作ったコネクションだけが含まれる．}

  \item{what}{整数：\code{showConnections} が与えるテーブルの行番号．}

  \item{con}{コネクション．}
}
\details{
  \code{stdin()}, \code{stdout()} そして \code{stderr()} はコンソール上の
  入力，出力そしてエラーに対応する標準コネクション(そして必ずしもファイル
  ストリームに対するものでなく)である．これらはクラス \code{"terminal"} の
  テキストモードコネクションで，開いたり閉じたりすることは出来ず，
  それぞれ読み込みオンリー，書き込みオンリー，そして書き込みオンリーである．
  \code{stdout()} と \code{stderr()} コネクションは
  \code{\link{sink}} によってリダイレクトすることが出来る
  (そしてある種の状況では\code{stdout()} からの出力は分割できる：ヘルプページ
  を見よ)．

  \code{\link{stdin}()} に対するエンコーディングはコマンドラインのフラグ
  \option{--encoding} で設定できる．

  \code{showConnections} は情報の行列を返す．もしコネクションオブジェクトが
  失われたか忘れられたら，\code{getConnection} はテーブルの行番号から
  取られそのコネクションに対するコネクションオブジェクトを返す．
  これは例えばコネクションを閉じるのに使うことが出来る．
  しかしながら，もしコネクションを参照する \R レベルのオブジェクトが無ければ
  それは次のガベージコレクションの際に自動的に閉じられる
  (\code{\link{gzcon}} コネクションを除く)．

  \code{closeAllConnections} は全てのユーザのコネクションを閉じ(そして破壊し)，
  全ての \code{\link{sink}} ダイバージョンをそれがそうあるべきように回復する．

  \code{isatty} はもしコネクションがクラス \code{"terminal"} のコネクション
  の一つでそれが見かけ上端末に接続されていれば真を返し，さもなければ偽を返す．
  これは GUI コンソールを含む埋め込みのアプリケーションでは信頼できないかもしれない．
}
\note{
  \code{stdin()} は\sQuote{コンソール}を参照し，プロセスの C レベルの
  \file{stdin} ではない．この違いは GUI コンソールでは重要であり
  (これはアクティブな \file{stdin} を持たないかもしれず，そしてもし
  アクティブならコンソール入力に接続されていないかもしれない)，そし
  また埋め込みアプリケーションでもそうである．
  もし C レベルのファイルストリーム \file{stdin} にアクセスしたければ
  \code{\link{file}("stdin")} を使う．

  \R がファイルからスクリプトを読み取っている時は \emph{file} は
  \sQuote{コンソール}である：これはインラインデータを許すための伝統的な
  用法である(例えば \sQuote{An Introduction to R} を見よ)．
}
\value{
  \code{stdin()}, \code{stdout()} そして \code{stderr()} はコネクション
  オブジェクトを返す．

  \code{showConnections} は各コネクションに対する行を持つ情報の文字列の行列を
  返す．既定では開かれている非標準のものだけ．

  \code{getConnection} はコネクションオブジェクト，又は \code{NULL} を返す．
}
\seealso{\code{\link{connections}}}

\examples{
showConnections(all = TRUE)
\dontrun{
textConnection(letters)
# おやおや，それを記録するのを忘れてしまった
showConnections()
#  class     description      mode text   isopen   can read can write
#3 "letters" "textConnection" "r"  "text" "opened" "yes"    "no"
mycon <- getConnection(3)
}

c(isatty(stdin()), isatty(stdout()), isatty(stderr()))
}
\keyword{connection}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/showConnections.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{showConnections}
%\alias{showConnections}
%\alias{getConnection}
%\alias{getAllConnections}
%\alias{closeAllConnections}
%\alias{stdin}
%\alias{stdout}
%\alias{stderr}
%\alias{isatty}
%\title{Display Connections}
%\description{
%  Display aspects of \link{connections}.
%}
%\usage{
%showConnections(all = FALSE)
%getConnection(what)
%closeAllConnections()
%
%stdin()
%stdout()
%stderr()
%
%isatty(con)
%}
%\arguments{
%  \item{all}{logical: if true all connections, including closed ones
%    and the standard ones are displayed.  If false only open user-created
%    connections are included.}
%
%  \item{what}{integer: a row number of the table given by
%    \code{showConnections}.}
%
%  \item{con}{a connection.}
%}
%\details{
%  \code{stdin()}, \code{stdout()} and \code{stderr()} are standard
%  connections corresponding to input, output and error on the console
%  respectively (and not necessarily to file streams).  They are text-mode
%  connections of class \code{"terminal"} which cannot be opened or
%  closed, and are read-only, write-only and write-only respectively.
%  The \code{stdout()} and \code{stderr()} connections can be
%  re-directed by \code{\link{sink}} (and in some circumstances the
%  output from \code{stdout()} can be split: see the help page).
%
%  The encoding for \code{\link{stdin}()} when redirected can
%  be set by the command-line flag \option{--encoding}.
%
%  \code{showConnections} returns a matrix of information.  If a
%  connection object has been lost or forgotten, \code{getConnection}
%  will take a row number from the table and return a connection object
%  for that connection, which can be used to close the connection,
%  for example.  However, if there is no \R level object referring to the
%  connection it will be closed automatically at the next garbage
%  collection (except for \code{\link{gzcon}} connections).
%
%  \code{closeAllConnections} closes (and destroys) all user
%  connections, restoring all \code{\link{sink}} diversions as it does
%  so.
%
%  \code{isatty} returns true if the connection is one of the class
%  \code{"terminal"} connections and it is apparently connected to a
%  terminal, otherwise false.  This may not be reliable in embedded
%  applications, including GUI consoles.
%}
%\note{
%  \code{stdin()} refers to the \sQuote{console} and not to the C-level
%  \file{stdin} of the process.  The distinction matters in GUI consoles
%  (which may not have an active \file{stdin}, and if they do it may not
%  be connected to console input), and also in embedded applications.
%  If you want access to the C-level file stream \file{stdin}, use
%  \code{\link{file}("stdin")}.
%
%  When \R is reading a script from a file, the \emph{file} is the
%  \sQuote{console}: this is traditional usage to allow in-line data (see
%  \sQuote{An Introduction to R} for an example).
%}
%\value{
%  \code{stdin()}, \code{stdout()} and \code{stderr()} return connection
%  objects.
%
%  \code{showConnections} returns a character matrix of information with
%  a row for each connection, by default only for open non-standard connections.
%
%  \code{getConnection} returns a connection object, or \code{NULL}.
%}
%\seealso{\code{\link{connections}}}
%
%\examples{
%showConnections(all = TRUE)
%\dontrun{
%textConnection(letters)
%# oops, I forgot to record that one
%showConnections()
%#  class     description      mode text   isopen   can read can write
%#3 "letters" "textConnection" "r"  "text" "opened" "yes"    "no"
%mycon <- getConnection(3)
%}
%
%c(isatty(stdin()), isatty(stdout()), isatty(stderr()))
%}
%\keyword{connection}
%
\encoding{UTF8}
