% File src/library/base/man/sprintf.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{sprintf}
\alias{sprintf}
\alias{gettextf}
\title{Use C-style String Formatting Commands}
\description{
  C 関数 \code{sprintf} のラッパであり，テキストと変数の値の
  整形化されたコンビネーションを含む文字列ベクトルを返す．
}
\usage{
sprintf(fmt, \dots)
gettextf(fmt, \dots, domain = NULL)
}
\arguments{
  \item{fmt}{整形文字列の文字列ベクトルで，各々は最大 8192 バイト．}
  \item{\dots}{\code{fmt} 中に渡される値．論理値，整数，実数そして
    文字列ベクトルだけがサポートされるが，ある種の変換が
    行われる：\sQuote{詳細}節を見よ．最大 100．}
  \item{domain}{\code{\link{gettext}} を見よ．}
}
\details{
  \code{sprintf} はシステムの \code{sprintf} C ライブラリのラッパである．
  渡された値のモードが与えられた形式的引数にマッチするかどうかチェックがされ，
   \R の特殊値 (\code{NA}, \code{Inf}, \code{-Inf} そして \code{NaN}) が
   正確に処理される．

  \code{gettextf} は整形文字列の翻訳を伴う C 風の文字列整形を
  提供する便利な関数である．

  引数(\code{fmt} を含む)は可能なら最長のものの長さの全倍数回リサイクルされ，
  それから整形が並列で行われる．長さがゼロの引数が許され長さがゼロの結果を与える．
  全ての引数は使われなくても評価され，従って幾つかのタイプ
  (例えば \code{"symbol"} や \code{"language"}，\code{\link{typeof}} を見よ)
  は許されない．

  以下は Kernighan and Ritchie から取った(参考文献を見よ)：しかしながら
  実際の移植は C99 標準に倣っており，詳細
  (特にユーザーエラーの際の)はプラットフォームに依存するかもしれない．

  文字列 \code{fmt} は出力文字列を通して渡される普通の文字列と，
  また \code{\dots} を通じて提供される引数に作用する変換指定を含む．
  許される変換指定は \code{\%} で始まりセット \code{aAdifeEgGosxX\%}
  中の文字の一つで終わる．文字は次のタイプを表す：

  \describe{
    \item{\code{d}, \code{i}, \code{o}, \code{x}, \code{X}}{整数値，
      \code{o} は8進数，\code{x} と \code{X} は16進数(\code{a-f} に対しては
      コードと文字の大小を使う)．正確に整数な数値は整数に変換される．
      書式 \code{d} と \code{i} は論理変数にも使われ，
      \code{0}, \code{1} 又は \code{NA} に変換される．
    }
    \item{\code{f}}{"[-]mmm.ddd" の形式の
      \dQuote{固定小数点}10進数表記の倍精度値．
      小数部分の数("d")は精度で指定される：既定は 6；
      精度 0 は小数部分を抑制する．有限でない値は
      \code{NA}, \code{NaN} 又は(恐らく符号に続く) \code{Inf}．
    }
    \item{\code{e}, \code{E}}{
      \code{[-]m.ddde[+-]xx} または \code{[-]m.dddE[+-]xx} の形式の
      \dQuote{指数表記の}10進数表記の倍精度値，
    }
    \item{\code{g}, \code{G}}{倍精度値．\code{\%e} 又は \code{\%E} 書式で
      もし指数部が -4 以下か精度に等しいか大きい時
      , さもなければ \code{\%f} 書式．
      (精度(既定値 6)はここでは\emph{有効桁}数を指定する一方，
      \code{\%f, \%e} ではそれは小数点以下の数字の数である．)
    }
    \item{\code{a}, \code{A}}{倍精度値．\code{[-]0xh.hhhp[+-]d}
      の形式のバイナリ表記．これは16進数で表されたバイナリ小数で
      2の(10進)巾乗が掛かっている．小数点の後の16進数の数は精度で
      指定される：既定値は内部表現を正確に表現するのに十分な数である．
      有限でない値は \code{NA}, \code{NaN} または
      (恐らく符号のあとに続く) \code{Inf} に変換される．書式
      \code{\%a} は \code{x}, \code{p} そして 16 進値に対して
      小文字を使い，書式 \code{\%A} は大文字を使う．

      これは C99 の特性であるから全てのプラットフォームでサポート
      されているべきである．
      書式はユニークには定義されない：先頭の \code{h} を常に0や1に
      することは可能ではあるが，これは常にはされない．
      殆どシステムは末尾のゼロは抑制されるが，しないものも少しある．
      良く書かれたプラットフォームでは，正規の数に対しては
      小数点の前に先頭の1プラス(既定で)13の 16 進数で
      従って 53 ビットになる．非正規数(もしくは \sQuote{副正規})
      の扱いは非常にプラットフォーム依存である．
    }
    \item{\code{s}}{文字列．\code{NA} は \code{"NA"} に変換される．
    }
    \item{\code{\%}}{文字通りの \code{\%} (このケースでは以下に与えられる
      余分な整形文字は許されない．
    }
  } 
  \code{\link{as.character}} による変換は \code{s} と共に
  文字でない引数に対して使われ，そして
  倍精度でない引数に対しては \code{f, e, E, g, G} とともに
  \code{\link{as.double}} が使われる．
  NB：長さは変換前に決められるので，もしそれが長さを変更するならば
  内部変換を信用しない．
  変換は一度だけ行われるので，もし \code{length(fmt) > 1} ならば
  全ての要素は同じ引数の型を期待すべきである．

  加えて，最初の \code{\%} と最後の変換文字の間には
  以下が任意の順序で現れて良い：

  \describe{
    \item{\code{m.n}}{ピリオッドで分離された二つの数で，
      欄幅 (\code{m}) と精度 (\code{n}) を表す．}
    \item{\code{-}}{変換された引数をその欄内で左揃え．}
    \item{\code{+}}{常に符号付きで数をプリントする：既定では
      負の数が符号付きでプリントされる．}
    \item{スペース}{もし最初の文字が符号でなければスペースを先に置く．}
    \item{\code{0}}{数に対して，欄幅を先頭のゼロで埋める．
      文字列に対してはある種のプラットフォームではこのゼロ補填が行われ，
      他では無視される．}
    \item{\code{#}}{数に対する\dQuote{別種の出力}を指定する．
      その動作はタイプに依存する：
      \code{x} や \code{X} に対しては \code{0x} や \code{0X} が
      ゼロでない結果の前に付けられる．
      \code{e}, \code{e}, \code{f}, \code{g} そして \code{G} に
      対しては出力は常に小数点を持つ；
      \code{g} と \code{G} に対しては末尾のゼロは取り除かれる．
    }
  }
  更に， \code{\%} の直後に名前付き引数を参照する \code{1$} から \code{99$}
  が来るかもしれない：これは引数を順番を無視して参照することを許し，
  主にエラーメッセージの翻訳を念頭に置いている．
  もしこれを行うなら全ての書式に番号がついていれば最良である：
  さもなければ番号がついていないものが引数を
  その順で処理する．
  例を見よ．この表記は引数を一度以上使うことを許す．
  その場合それらは同じタイプ(整数，倍精度，そして文字列)として使われる.

  欄幅や精度(しかし双方ではない)はアステリスク \code{*} で指示される：
  この場合引数の一つは希望の数を指定する．
  負の欄幅は '-' フラグの後に正の欄幅が続く．
  負の精度は精度が省略されているかのように扱われる．
  引数は整数でなければならないが，倍精度の引数は整数に
  変換される．

  \code{fmt} の要素に付いては 8192 バイトの制限があり，文字列については
  一つの \code{\%} \emph{文字}変換指定から含められる．

  C 標準順で述べられているように，欄幅と精度の \code{\%s} 変換は
  バイトとして解釈され，文字としてではない．
  
  \R の数値ベクトルで使われる C 倍精度は符号付きのゼロを持ち，
  これは \code{sprintf} は \code{-0}, \code{-0.000} \dots の様に
  出力するかもしれない．
}
%% (for #) This is from Kernighan & Ritchie, p. 243:
%% For \code{o}, the first digit will be zero.


\value{
  最長の入力のそれに等しい長さの文字列ベクトル．
  もし \code{fmt} の任意の要素又は文字列引数が UTF-8 と宣言されていると，
  結果の要素は UTF-8 になり，エンコーディングが
  UTF-8 として宣言される．さもなければそれは現在のロケール中にある．
}

\section{警告}{
  整形文字は OS の \code{sprintf} 関数に下げ渡され，そして不正確な
  書式は後者に \R プロセスをクラッシュさせる．
  \R は書式の健全さをチェックするが，可能なユーザーエラーの全てが
  全てのプラットフォームで検査されているわけではなく，幾つかは
  破滅的かもしれない．

  ここで文章化されていない入力に関する挙動は\sQuote{未定義}であり，
  プラットフォームにより異なることが認められていることを意味する．
}

\references{
  Kernighan, B. W. and Ritchie, D. M. (1988)
  \emph{The C Programming Language.} Second edition, Prentice Hall.
  Describes the format options in table B-1 in the Appendix.

  C 標準，特に \sQuote{C99} に対しては ISO/IEC 9899:1999．
  リンクは \url{http://developer.r-project.org/Portability.html} にある．

  Unix 風システムでは \command{man sprintf}．
}

\author{
  Jonathan Rougier によるオリジナルコード．
}

\seealso{
  数値のベクトルを同じような方法で整形するには \code{\link{formatC}}．

  テキストと値を結びつけたベクトルを作る別の方法は \code{\link{paste}}．

  テキストの自動翻訳については \code{\link{gettext}}．
}

% Escape all the '%' here !
\examples{
## 整形に注意する：R で最も問題になるのは実数である
## 整数値の実数だけが整数に変換される．

sprintf("\%s is \%f feet tall\n", "Sven", 7.1)      # OK
try(sprintf("\%s is \%i feet tall\n", "Sven", 7.1)) # not OK
    sprintf("\%s is \%i feet tall\n", "Sven", 7  )  # OK

## \% を文字通りに使う：

sprintf("\%.0f\%\% said yes (out of a sample of size \%.0f)", 66.666, 3)

## pi の様々な整形：

sprintf("\%f", pi)
sprintf("\%.3f", pi)
sprintf("\%1.0f", pi)
sprintf("\%5.1f", pi)
sprintf("\%05.1f", pi)
sprintf("\%+f", pi)
sprintf("\% f", pi)
sprintf("\%-10f", pi) # 左揃え
sprintf("\%e", pi)
sprintf("\%E", pi)
sprintf("\%g", pi)
sprintf("\%g",   1e6 * pi) # -> 指数
sprintf("\%.9g", 1e6 * pi) # -> "固定"
sprintf("\%G", 1e-6 * pi)

## 切り詰め無し：
sprintf("\%1.f", 101)

## 一つの引数を再利用，\%x と \%X の差を示す
xx <- sprintf("\%1$d \%1$x \%1$X", 0:15)
xx <- matrix(xx, dimnames = list(rep("", 16), "\%d\%x\%X"))
noquote(format(xx, justify = "right"))

## より洗練されたもの：

sprintf("min 10-char string '\%10s'",
        c("a", "ABC", "and an even longer one"))

\donttest{## qdapTools 1.0.0 からのプラットフォーム依存の悪い例：
## 空白やゼロで埋められるかもしれない
sprintf("\%09s", month.name)}

n <- 1:18
sprintf(paste0("e with \%2d digits = \%.", n, "g"), n, exp(1))

## 引数を秩序無しに使う
sprintf("second \%2$1.0f, first \%1$5.2f, third \%3$1.0f", pi, 2, 3)

## 幅や精度に対しアステリスクを使う
sprintf("precision \%.*f, width '\%*.3f'", 3, pi, 8, pi)

## アステリスクと引数の再利用，'e' example reiterated:
sprintf("e with \%1$2d digits = \%2$.*1$g", n, exp(1))

## リサイクル引数
sprintf("\%s \%d", "test", 1:3)

## 丸め/表現エラーを示すバイナリ出力
x <- seq(0, 1.0, 0.1); y <- c(0,.1,.2,.3,.4,.5,.6,.7,.8,.9,1)
cbind(x, sprintf("\%a", x), sprintf("\%a", y))
}
\keyword{print}
\keyword{character}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/sprintf.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{sprintf}
%\alias{sprintf}
%\alias{gettextf}
%\title{Use C-style String Formatting Commands}
%\description{
%  A wrapper for the C function \code{sprintf}, that returns a character
%  vector containing a formatted combination of text and variable values.
%}
%\usage{
%sprintf(fmt, \dots)
%gettextf(fmt, \dots, domain = NULL)
%}
%\arguments{
%  \item{fmt}{a character vector of format strings, each of up to 8192 bytes.}
%  \item{\dots}{values to be passed into \code{fmt}.  Only logical,
%    integer, real and character vectors are supported, but some coercion
%    will be done: see the \sQuote{Details} section. Up to 100.}
%  \item{domain}{see \code{\link{gettext}}.}
%}
%\details{
%  \code{sprintf} is a wrapper for the system \code{sprintf} C-library
%  function.  Attempts are made to check that the mode of the values
%  passed match the format supplied, and \R's special values (\code{NA},
%  \code{Inf}, \code{-Inf} and \code{NaN}) are handled correctly.
%
%  \code{gettextf} is a convenience function which provides C-style
%  string formatting with possible translation of the format string.
%
%  The arguments (including \code{fmt}) are recycled if possible a whole
%  number of times to the length of the longest, and then the formatting
%  is done in parallel.  Zero-length arguments are allowed and will give
%  a zero-length result.  All arguments are evaluated even if unused, and
%  hence some types (e.g., \code{"symbol"} or \code{"language"}, see
%  \code{\link{typeof}}) are not allowed.
%
%  The following is abstracted from Kernighan and Ritchie (see
%  References): however the actual implementation will follow the C99
%  standard and fine details (especially the behaviour under user error)
%  may depend on the platform.
%
%  The string \code{fmt} contains normal characters,
%  which are passed through to the output string, and also conversion
%  specifications which operate on the arguments provided through
%  \code{\dots}.  The allowed conversion specifications start with a
%  \code{\%} and end with one of the letters in the set
%  \code{aAdifeEgGosxX\%}.  These letters denote the following types:
%
%  \describe{
%    \item{\code{d}, \code{i}, \code{o}, \code{x}, \code{X}}{Integer
%      value, \code{o} being octal, 
%      \code{x} and \code{X} being hexadecimal (using the same case for
%      \code{a-f} as the code).  Numeric variables with exactly integer
%      values will be coerced to integer.  Formats \code{d} and \code{i}
%      can also be used for logical variables, which will be converted to
%      \code{0}, \code{1} or \code{NA}.
%    }
%    \item{\code{f}}{Double precision value, in \dQuote{\bold{f}ixed
%        point} decimal notation of the form "[-]mmm.ddd".  The number of
%      decimal places ("d") is specified by the precision: the default is 6;
%      a precision of 0 suppresses the decimal point.  Non-finite values
%      are converted to \code{NA}, \code{NaN} or (perhaps a sign followed
%      by) \code{Inf}.
%    }
%    \item{\code{e}, \code{E}}{Double precision value, in
%      \dQuote{\bold{e}xponential} decimal notation of the
%      form \code{[-]m.ddde[+-]xx} or \code{[-]m.dddE[+-]xx}.
%    }
%    \item{\code{g}, \code{G}}{Double precision value, in \code{\%e} or
%      \code{\%E} format if the exponent is less than -4 or greater than or
%      equal to the precision, and \code{\%f} format otherwise.
%      (The precision (default 6) specifies the number of
%      \emph{significant} digits here, whereas in \code{\%f, \%e}, it is
%      the number of digits after the decimal point.)
%    }
%    \item{\code{a}, \code{A}}{Double precision value, in binary notation
%      of the form \code{[-]0xh.hhhp[+-]d}.  This is a binary fraction
%      expressed in hex multiplied by a (decimal) power of 2.  The number
%      of hex digits after the decimal point is specified by the precision:
%      the default is enough digits to represent exactly the internal
%      binary representation.  Non-finite values are converted to \code{NA},
%      \code{NaN} or (perhaps a sign followed by) \code{Inf}.  Format
%      \code{\%a} uses lower-case for \code{x}, \code{p} and the hex
%      values: format \code{\%A} uses upper-case.
%
%      This should be supported on all platforms as it is a feature of C99.
%      The format is not uniquely defined: although it would be possible
%      to make the leading \code{h} always zero or one, this is not
%      always done.  Most systems will suppress trailing zeros, but a few
%      do not.  On a well-written platform, for normal numbers there will
%      be a leading one before the decimal point plus (by default) 13
%      hexadecimal digits, hence 53 bits.  The treatment of denormalized
%      (aka \sQuote{subnormal}) numbers is very platform-dependent.
%    }
%    \item{\code{s}}{Character string.  Character \code{NA}s are
%      converted to \code{"NA"}.
%    }
%    \item{\code{\%}}{Literal \code{\%} (none of the extra formatting
%      characters given below are permitted in this case).
%    }
%  }
%  Conversion by \code{\link{as.character}} is used for non-character
%  arguments with \code{s} and by \code{\link{as.double}} for
%  non-double arguments with \code{f, e, E, g, G}.  NB: the length is
%  determined before conversion, so do not rely on the internal
%  coercion if this would change the length.  The coercion is done only
%  once, so if \code{length(fmt) > 1} then all elements must expect the
%  same types of arguments.
%
%  In addition, between the initial \code{\%} and the terminating
%  conversion character there may be, in any order:
%
%  \describe{
%    \item{\code{m.n}}{Two numbers separated by a period, denoting the
%      field width (\code{m}) and the precision (\code{n}).}
%    \item{\code{-}}{Left adjustment of converted argument in its field.}
%    \item{\code{+}}{Always print number with sign: by default only
%      negative numbers are printed with a sign.}
%    \item{a space}{Prefix a space if the first character is not a sign.}
%    \item{\code{0}}{For numbers, pad to the field width with leading
%      zeros. For characters, this zero-pads on some platforms and is
%      ignored on others.}
%    \item{\code{#}}{specifies \dQuote{alternate output} for numbers, its
%      action depending on the type:
%      For \code{x} or \code{X}, \code{0x} or \code{0X} will be prefixed
%      to a non-zero result.  For \code{e}, \code{e}, \code{f}, \code{g}
%      and \code{G}, the output will always have a decimal point; for
%      \code{g} and \code{G}, trailing zeros will not be removed.
%    }
%  }
%  Further, immediately after \code{\%} may come \code{1$} to \code{99$}
%  to refer to a numbered argument: this allows arguments to be
%  referenced out of order and is mainly intended for translators of
%  error messages.  If this is done it is best if all formats are
%  numbered: if not the unnumbered ones process the arguments in order.
%  See the examples.  This notation allows arguments to be used more than
%  once, in which case they must be used as the same type (integer,
%  double or character).
%
%  A field width or precision (but not both) may be indicated by an
%  asterisk \code{*}: in this case an argument specifies the desired
%  number.  A negative field width is taken as a '-' flag followed by a
%  positive field width.  A negative precision is treated as if the
%  precision were omitted.  The argument should be integer, but a double
%  argument will be coerced to integer.
%
%  There is a limit of 8192 bytes on elements of \code{fmt}, and on
%  strings included from a single \code{\%}\emph{letter} conversion
%  specification.
%
%  Field widths and precisions of \code{\%s} conversions are interpreted
%  as bytes, not characters, as described in the C standard.
%  
%  The C doubles used for \R numerical vectors have signed zeros, which
%  \code{sprintf} may output as \code{-0}, \code{-0.000} \dots.
%}
%%% (for #) This is from Kernighan & Ritchie, p. 243:
%%% For \code{o}, the first digit will be zero.
%
%
%\value{
%  A character vector of length that of the longest input.  If any
%  element of \code{fmt} or any character argument is declared as UTF-8,
%  the element of the result will be in UTF-8 and have the encoding
%  declared as UTF-8.  Otherwise it will be in the current locale's
%  encoding.
%}
%
%\section{Warning}{
%  The format string is passed down the OS's \code{sprintf} function, and
%  incorrect formats can cause the latter to crash the \R process .  \R
%  does perform sanity checks on the format, but not all possible user
%  errors on all platforms have been tested, and some might be terminal.
%
%  The behaviour on inputs not documented here is \sQuote{undefined},
%  which means it is allowed to differ by platform.
%}
%
%\references{
%  Kernighan, B. W. and Ritchie, D. M. (1988)
%  \emph{The C Programming Language.} Second edition, Prentice Hall.
%  Describes the format options in table B-1 in the Appendix.
%
%  The C Standards, especially ISO/IEC 9899:1999 for \sQuote{C99}.  Links
%  can be found at \url{http://developer.r-project.org/Portability.html}.
%
%  \command{man sprintf} on a Unix-alike system.
%}
%
%\author{
%  Original code by Jonathan Rougier.
%}
%
%\seealso{
%  \code{\link{formatC}} for a way of formatting vectors of numbers in a
%  similar fashion.
%
%  \code{\link{paste}} for another way of creating a vector combining
%  text and values.
%
%  \code{\link{gettext}} for the mechanisms for the automated translation
%  of text.
%}
%
%% Escape all the '%' here !
%\examples{
%## be careful with the format: most things in R are floats
%## only integer-valued reals get coerced to integer.
%
%sprintf("\%s is \%f feet tall\n", "Sven", 7.1)      # OK
%try(sprintf("\%s is \%i feet tall\n", "Sven", 7.1)) # not OK
%    sprintf("\%s is \%i feet tall\n", "Sven", 7  )  # OK
%
%## use a literal \% :
%
%sprintf("\%.0f\%\% said yes (out of a sample of size \%.0f)", 66.666, 3)
%
%## various formats of pi :
%
%sprintf("\%f", pi)
%sprintf("\%.3f", pi)
%sprintf("\%1.0f", pi)
%sprintf("\%5.1f", pi)
%sprintf("\%05.1f", pi)
%sprintf("\%+f", pi)
%sprintf("\% f", pi)
%sprintf("\%-10f", pi) # left justified
%sprintf("\%e", pi)
%sprintf("\%E", pi)
%sprintf("\%g", pi)
%sprintf("\%g",   1e6 * pi) # -> exponential
%sprintf("\%.9g", 1e6 * pi) # -> "fixed"
%sprintf("\%G", 1e-6 * pi)
%
%## no truncation:
%sprintf("\%1.f", 101)
%
%## re-use one argument three times, show difference between \%x and \%X
%xx <- sprintf("\%1$d \%1$x \%1$X", 0:15)
%xx <- matrix(xx, dimnames = list(rep("", 16), "\%d\%x\%X"))
%noquote(format(xx, justify = "right"))
%
%## More sophisticated:
%
%sprintf("min 10-char string '\%10s'",
%        c("a", "ABC", "and an even longer one"))
%
%\donttest{## Platform-dependent bad example from qdapTools 1.0.0:
%## may pad with spaces or zeroes.
%sprintf("\%09s", month.name)}
%
%n <- 1:18
%sprintf(paste0("e with \%2d digits = \%.", n, "g"), n, exp(1))
%
%## Using arguments out of order
%sprintf("second \%2$1.0f, first \%1$5.2f, third \%3$1.0f", pi, 2, 3)
%
%## Using asterisk for width or precision
%sprintf("precision \%.*f, width '\%*.3f'", 3, pi, 8, pi)
%
%## Asterisk and argument re-use, 'e' example reiterated:
%sprintf("e with \%1$2d digits = \%2$.*1$g", n, exp(1))
%
%## re-cycle arguments
%sprintf("\%s \%d", "test", 1:3)
%
%## binary output showing rounding/representation errors
%x <- seq(0, 1.0, 0.1); y <- c(0,.1,.2,.3,.4,.5,.6,.7,.8,.9,1)
%cbind(x, sprintf("\%a", x), sprintf("\%a", y))
%}
%\keyword{print}
%\keyword{character}
%
\encoding{UTF8}
