% File src/library/base/man/taskCallback.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{taskCallback}
\alias{addTaskCallback}
\alias{removeTaskCallback}
\title{Add or Remove a Top-Level Task Callback}
\description{
  \code{addTaskCallback} はトップレベルの作業が完了するたびに
  呼び出される R 関数を登録する．

  \code{removeTaskCallback} は先に \code{addTaskCallback}
  で登録された関数の登録を解除する．

  これはタスク完了時の動作の処理に対する内部/ネイティブな
  機構への低水準なアクセスを提供する．
  各作業の完了時に呼び出される S 関数を管理する S 言語レベルの
  \code{\link{taskCallbackManager}} を使うことが出来る．
  これはより簡単でより直接的である．
}
\usage{
addTaskCallback(f, data = NULL, name = character())
removeTaskCallback(id)
}
\arguments{
  \item{f}{トップレベルの作業が成功裏に終了する度に起動される関数．
    これは \code{data} が指定されたかどうかでそれぞれ 5 又は 4 つの引数
    で呼び出される．
    返り値はコールバックをアクティブなコールバックのリスト中に
    保持するか捨て去るかを指示する論理値で無ければならない．}
  \item{data}{もし指定されると，これはコールバック関数 \code{f} への
    呼び出し中の 5 番目の引数である．}
  \item{id}{内部コールバックのリスト中の除去される要素を特定する文字列化整数．
    整数添字は 1 ベースである，つまり最初の要素は 1 である．
    現在登録されたハンドラーの名前は \code{\link{getTaskCallbackNames}} を
    使って得られ，また \code{\link{addTaskCallback}} への呼び出し中で
    返される．
  }
  \item{name}{文字列：使用する名前．}
}
\value{
  \code{addTaskCallback} はこの新しいコールバックが占める
  タスクコールバックのリスト中のポジションを与える整数値
  を返す．これはコールバックの現在の位置だけである．
  これはリスト中の先にある位置から他の値を除くこと無く
  項目を除くことに使うことが出来る．

  \code{removeTaskCallback} は指定された要素が除かれているかどうかを
  指示する論理値を返す．
  もしリスト中の要素の位置や名前に対応しない不正確な名前や添字が
  与えられると
  これは失敗することがある(つまり \code{FALSE} を返す)．
}
\details{
  トップレベルのタスクは入力の全部の行ではなく個別の表現式である．
  このように入力行が形式 \code{expression1 ; expression2} を持てば
  二つのトップレベルのタスクを与える．

  トップレベルのタスクコールバックはトップレベルのタスクに対する
  表現式，トップレベルのタスクの結果，それが成功裏に完了したかどうか
  指示する論理値，そして結果をプリントするかどうかを指示する論理値
  と共に呼びだされる．
  もし \code{data} 引数が \code{addTaskCallback} の呼び出し中で
  指定されていると，値は5番目の引数として与えられる．

  コールバック関数は一つの論理値を返すべきである．
  もし値が \code{FALSE} ならば，コールバックはタスクリストから除かれ，
  この機構により再び呼び出されることはない．
  もし関数が \code{TRUE} を返せば，それはリストに保持され
  次のトップレベルのタスクの完了時に呼び出される．
}
\note{
  \R 関数ではなく C ルーティンを許す
  C レベルのトップレベルのタスクコールバックへのアクセスがある．
}
\seealso{
  \code{\link{getTaskCallbackNames}},
  \code{\link{taskCallbackManager}},\cr
  \url{http://developer.r-project.org/TaskHandlers.pdf}.
}
\examples{
times <- function(total = 3, str = "Task a") {
   ctr <- 0

   function(expr, value, ok, visible) {
    ctr <<- ctr + 1
    cat(str, ctr, "\n")
    if(ctr == total) {
      cat("handler removing itself\n")
    }
    return(ctr < total)
   }
 }

 # 4 つのトップレベルのタスクに対して動作するコールバックを加え
 # それから自分自身を取り除く
 n <- addTaskCallback(times(4))

 # それが依然リストの先頭にあることを仮定し，取り除く
 removeTaskCallback(n)

\dontrun{
# これを次のように実行するのには意味がない
 addTaskCallback(times(4))

 sum(1:10)
 sum(1:10)
 sum(1:10)
 sum(1:10)
 sum(1:10)
}
}
\keyword{environment}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/taskCallback.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{taskCallback}
%\alias{addTaskCallback}
%\alias{removeTaskCallback}
%\title{Add or Remove a Top-Level Task Callback}
%\description{
%  \code{addTaskCallback} registers an R function
%  that is to be called each time a top-level task
%  is completed.
%
%  \code{removeTaskCallback} un-registers a function
%  that was registered earlier via \code{addTaskCallback}.
%
%  These provide low-level access to the internal/native
%  mechanism for managing task-completion actions.
%  One can use \code{\link{taskCallbackManager}}
%  at the S-language level to manage S functions
%  that are called at the completion of each task.
%  This is easier and more direct.
%}
%\usage{
%addTaskCallback(f, data = NULL, name = character())
%removeTaskCallback(id)
%}
%\arguments{
%  \item{f}{the function that is to be invoked each time a top-level task
%    is successfully completed.  This is called with 5 or 4 arguments
%    depending on whether \code{data} is specified or not, respectively.
%    The return value should be a logical value indicating whether to
%    keep the callback in the list of active callbacks or discard it.}
%  \item{data}{if specified, this is the 5-th argument in the call to the
%    callback function \code{f}.}
%  \item{id}{a string or an integer identifying the element in the
%    internal callback list to be removed.
%    Integer indices are 1-based, i.e the first element is 1.
%    The names of currently registered handlers is available
%    using \code{\link{getTaskCallbackNames}}
%    and is also returned in a call to \code{\link{addTaskCallback}}.
%  }
%  \item{name}{character: names to be used.}
%}
%\value{
%  \code{addTaskCallback} returns
%  an integer value giving  the position in the list
%  of task callbacks that this new callback occupies.
%  This is only the current position of the callback.
%  It can be used to remove the entry as long as
%  no other values are removed from earlier positions
%  in the list first.
%
%  \code{removeTaskCallback} returns a logical value
%  indicating whether the specified element was removed.
%  This can fail (i.e., return \code{FALSE})
%  if an incorrect name or index is given that does not
%  correspond to the name or position of an element in the list.
%}
%\details{
%Top-level tasks are individual expressions
%rather than entire lines of input.  Thus an input
%line of the form \code{expression1 ; expression2}
%will give rise to 2 top-level tasks.
%
%A top-level task callback is called with the expression for the
%top-level task, the result of the top-level task, a logical value
%indicating whether it was successfully completed or not (always TRUE
%at present), and a logical value indicating whether the result was
%printed or not.  If the \code{data} argument was specified in the call
%to \code{addTaskCallback}, that value is given as the fifth argument.
%
%The callback function should return a logical value.
%If the value is FALSE, the callback is removed from the task
%list and will not be called again by this mechanism.
%If the function returns TRUE, it is kept in the list and
%will be called on the completion of the next top-level task.
%}
%\note{
%  There is also C-level access to top-level task callbacks
%  to allow C routines rather than R functions be used.
%}
%\seealso{
%  \code{\link{getTaskCallbackNames}}
%  \code{\link{taskCallbackManager}}
%  \url{http://developer.r-project.org/TaskHandlers.pdf}
%}
%\examples{
%times <- function(total = 3, str = "Task a") {
%   ctr <- 0
%
%   function(expr, value, ok, visible) {
%    ctr <<- ctr + 1
%    cat(str, ctr, "\n")
%    if(ctr == total) {
%      cat("handler removing itself\n")
%    }
%    return(ctr < total)
%   }
% }
%
% # add the callback that will work for
% # 4 top-level tasks and then remove itself.
% n <- addTaskCallback(times(4))
%
% # now remove it, assuming it is still first in the list.
% removeTaskCallback(n)
%
%\dontrun{
%# There is no point in running this
%# as
% addTaskCallback(times(4))
%
% sum(1:10)
% sum(1:10)
% sum(1:10)
% sum(1:10)
% sum(1:10)
%}
%}
%\keyword{environment}
%