% File src/library/base/man/textconnections.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{textConnection}
\alias{textConnection}
\alias{textConnectionValue}
\title{Text Connections}
\description{
  入力と出力用テキストコネクション．
}
\usage{
textConnection(object, open = "r", local = FALSE,
               encoding = c("", "bytes", "UTF-8"))

textConnectionValue(con)
}
\arguments{
  \item{object}{文字列．コネクションの説明．
    入力に対してはこれは \R の文字列ベクトルオブジェクトで，
    出力コネクションに対しては出力を受け取る \R の文字列ベクトル
    に対する名前，もしくは \code{NULL} (何もない)．
  }
  \item{open}{文字列．入力コネクションに対しては\code{"r"} (又は同値な \code{""})
    又は出力コネクションに対しては \code{"w"} 又は \code{"a"}．}
  \item{local}{論理値．出力コネクションに対してだけ使われる．もし \code{TRUE} なら
    出力は呼び出し環境中の変数に付値される．さもなければ大局的環境が使われる．}
  \item{encoding}{文字列．部分マッチされる．入力コネクションに対してだけ
    使われる．\code{object} 中のマーク付き文字列がどのように処理されるか：
    現在のロケールに変換され，バイト毎に使われるか UTF-8 に
    翻訳される．}
  \item{con}{出力テキストコネクション．}
}
\details{
  入力テキストコネクションが開かれコネクションオブジェクトが
  作られる時に文字列ベクトルがコピーされる．
  そして \code{close} はコピーを破壊する．
  \code{object} は文字列ベクトルの名前でなければならない：
  しかしながら短い表現はそれらが 60 バイト以下に逆構文解析されるならば
  受け入れられる．

  出力テキストコネクションが開かれると，\code{local} 引数に応じて
  ユーザの作業空間か呼び出し環境中に与えられた名前の \R の文字列ベクトルが
  作られる．このオブジェクトは常にコネクションへの出力の完全な行を保持し，
  \code{\link{isIncomplete}} は不完全な最終行があるかどうかを指示する．
  コネクションを閉じると完全であろうとなかろうと最終行が出力される．
  (一つの行はそれが \R では \code{"\\n"} で表される end-of-line で
  終わっていると完全である)．
  出力文字列ベクトルはコネクションに対して \code{close} が呼び出されるまで
  ロックされたバインディング(\code{\link{lockBinding}} を見よ)を持つ．
  文字列ベクトルはまた \code{textConnectionValue} を使って
  回収でき，これは \code{object = NULL} ならばそれを行う唯一の方法である．
  もし現在のロケールが Latin-1 か UTF-8 であると検出されると，
  文字列ベクトルの非アスキー要素はそのようにマークされる
  (\code{Encoding} を見よ)．

  \code{mode = "a"} でテキストコネクションを開くと
  ユーザの作業空間か呼び出し環境中の与えられた名前を持つ既存の文字列
  ベクトルに付け加えようと試みる．もし見つからなければ
  (例え正しい名前だが間違った型のオブジェクトが存在しても)新しい文字列ベクトル
  が警告と共に作られる．

  テキストコネクションでは \code{seek} は出来ず，\code{seek} は常に
  位置としてゼロを返す．

  テキストコネクションは少々普通でないセマンティックスを持つ：
  それらは常に開かれており，入力テキストコネクションをそれを閉じることなしに
  捨て去っても(従ってガベージコレクションされる)警告は出ない．
}

\value{
  \code{textConnection} に対してはクラス
  \code{"textConnection"} のコネクションオブジェクトで，
  クラス \code{"connection"} を継承する．

  \code{textConnectionValue} に対しては文字列ベクトル．
}

\note{
  出力用としてのテキストコネクションは文字列ベクトルを行毎に更新するので
  使用は相対的に高く付き，出力を集めるにはしばしば匿名の
  \code{\link{file}()} コネクションを使うほうが好ましい．

  \code{vsnprintf} が必要な長さの出力を返さない(稀な)プラットフォームでは
  出力コネクションに対しては一行 100,000 文字の制限がある：
  それより長い行は警告と共に打ち切られる．
}

\references{
  Chambers, J. M. (1998)
  \emph{Programming with Data.  A Guide to the S Language.} Springer.\cr
[S は入力用のテキストコネクションだけを持つ．]
}

\seealso{
  \code{\link{connections}}, \code{\link{showConnections}},
  \code{\link{pushBack}}, \code{\link{capture.output}}.
}

\examples{
zz <- textConnection(LETTERS)
readLines(zz, 2)
scan(zz, "", 4)
pushBack(c("aa", "bb"), zz)
scan(zz, "", 4)
close(zz)

zz <- textConnection("foo", "w")
writeLines(c("testit1", "testit2"), zz)
cat("testit3 ", file = zz)
isIncomplete(zz)
cat("testit4\n", file = zz)
isIncomplete(zz)
close(zz)
foo

\donttest{# R の出力を捕捉：help(lm) の例の一部分を使用
zz <- textConnection("foo", "w")
ctl <- c(4.17, 5.58, 5.18, 6.11, 4.5, 4.61, 5.17, 4.53, 5.33, 5.14)
trt <- c(4.81, 4.17, 4.41, 3.59, 5.87, 3.83, 6.03, 4.89, 4.32, 4.69)
group <- gl(2, 10, 20, labels = c("Ctl", "Trt"))
weight <- c(ctl, trt)
sink(zz)
anova(lm.D9 <- lm(weight ~ group))
cat("\nSummary of Residuals:\n\n")
summary(resid(lm.D9))
sink()
close(zz)
cat(foo, sep = "\n")
}
}
\keyword{file}
\keyword{connection}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/textconnections.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{textConnection}
%\alias{textConnection}
%\alias{textConnectionValue}
%\title{Text Connections}
%\description{
%  Input and output text connections.
%}
%\usage{
%textConnection(object, open = "r", local = FALSE,
%               encoding = c("", "bytes", "UTF-8"))
%
%textConnectionValue(con)
%}
%\arguments{
%  \item{object}{character.  A description of the \link{connection}.
%    For an input this is an \R character vector object, and for an output
%    connection the name for the \R character vector to receive the
%    output, or \code{NULL} (for none).
%  }
%  \item{open}{character string.  Either \code{"r"} (or equivalently \code{""})
%    for an input connection or \code{"w"} or \code{"a"} for an output
%    connection.}
%  \item{local}{logical.  Used only for output connections.  If \code{TRUE},
%    output is assigned to a variable in the calling environment.  Otherwise
%    the global environment is used.}
%  \item{encoding}{character string, partially matched.  Used only for input connections.  How
%    marked strings in \code{object} should be handled: converted to the
%    current locale, used byte-by-byte or translated to UTF-8.}
%  \item{con}{An output text connection.}
%}
%\details{
%  An input text connection is opened and the character vector is copied
%  at time the connection object is created, and \code{close} destroys
%  the copy.  \code{object} should be the name of a character vector:
%  however, short expressions will be accepted provided they \link{deparse} to
%  less than 60 bytes.
%
%  An output text connection is opened and creates an \R character vector
%  of the given name in the user's workspace or in the calling environment,
%  depending on the value of the \code{local} argument.  This object will at all
%  times hold the completed lines of output to the connection, and
%  \code{\link{isIncomplete}} will indicate if there is an incomplete
%  final line.  Closing the connection will output the final line,
%  complete or not.  (A line is complete once it has been terminated by
%  end-of-line, represented by \code{"\\n"} in \R.)   The output character
%  vector has locked bindings (see \code{\link{lockBinding}}) until
%  \code{close} is called on the connection.  The character vector can
%  also be retrieved \emph{via} \code{textConnectionValue}, which is the
%  only way to do so if \code{object = NULL}.  If the current locale is
%  detected as Latin-1 or UTF-8, non-ASCII elements of the character vector
%  will be marked accordingly (see \code{Encoding}).
%
%  Opening a text connection with \code{mode = "a"} will attempt to
%  append to an existing character vector with the given name in the
%  user's workspace or the calling environment.  If none is found (even
%  if an object exists of the right name but the wrong type) a new
%  character vector will be created, with a warning.
%
%  You cannot \code{seek} on a text connection, and \code{seek} will
%  always return zero as the position.
%
%  Text connections have slightly unusual semantics: they are always
%  open, and throwing away an input text connection without closing it
%  (so it get garbage-collected) does not give a warning.
%}
%
%\value{
%  For \code{textConnection}, a connection object of class
%  \code{"textConnection"} which inherits from class \code{"connection"}.
%
%  For \code{textConnectionValue}, a character vector.
%}
%
%\note{
%  As output text connections keep the character vector up to date
%  line-by-line, they are relatively expensive to use, and it is often
%  better to use an anonymous \code{\link{file}()} connection to collect
%  output.
%
%  On (rare) platforms where \code{vsnprintf} does not return the needed
%  length of output there is a 100,000 character limit on the length of
%  line for output connections: longer lines will be truncated with a
%  warning.
%}
%
%\references{
%  Chambers, J. M. (1998)
%  \emph{Programming with Data.  A Guide to the S Language.} Springer.\cr
%[S has input text connections only.]
%}
%
%\seealso{
%  \code{\link{connections}}, \code{\link{showConnections}},
%  \code{\link{pushBack}}, \code{\link{capture.output}}.
%}
%
%\examples{
%zz <- textConnection(LETTERS)
%readLines(zz, 2)
%scan(zz, "", 4)
%pushBack(c("aa", "bb"), zz)
%scan(zz, "", 4)
%close(zz)
%
%zz <- textConnection("foo", "w")
%writeLines(c("testit1", "testit2"), zz)
%cat("testit3 ", file = zz)
%isIncomplete(zz)
%cat("testit4\n", file = zz)
%isIncomplete(zz)
%close(zz)
%foo
%
%\donttest{# capture R output: use part of example from help(lm)
%zz <- textConnection("foo", "w")
%ctl <- c(4.17, 5.58, 5.18, 6.11, 4.5, 4.61, 5.17, 4.53, 5.33, 5.14)
%trt <- c(4.81, 4.17, 4.41, 3.59, 5.87, 3.83, 6.03, 4.89, 4.32, 4.69)
%group <- gl(2, 10, 20, labels = c("Ctl", "Trt"))
%weight <- c(ctl, trt)
%sink(zz)
%anova(lm.D9 <- lm(weight ~ group))
%cat("\nSummary of Residuals:\n\n")
%summary(resid(lm.D9))
%sink()
%close(zz)
%cat(foo, sep = "\n")
%}
%}
%\keyword{file}
%\keyword{connection}
%