% File src/library/base/man/unlink.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{unlink}
\title{Delete Files and Directories}
\usage{unlink(x, recursive = FALSE, force = FALSE)}
\alias{unlink}
\arguments{
  \item{x}{削除されるファイルやディレクトリの名前を持つ文字列ベクトル．
    ワイルドカード(普通 \file{*} と \file{?})が許される．}
  \item{recursive}{論理値．ディレクトリを再帰的に削除するか?}
  \item{force}{論理値．ファイルやディレクトリの削除を許すためにパーミッションを
  変更するか(もし可能なら)?}
}
\description{
  \code{unlink} は \code{x} で指定されるファイルやディレクトリを削除する．
}
\details{
  チルド展開(\code{\link{path.expand}} を見よ)が \code{x} についてなされる．

  もし \code{recursive = FALSE} ならディレクトリはたとえ空であっても削除されない．

#ifdef unix
  殆どのプラットフォームでは\sQuote{ファイル}はシンボリックリンク，fifo そしてソケットを
  含む．\R 2.15.0 以前では \code{unlink(x, recursive = TRUE)} はシンボリックリンクの
  ターゲットであるディレクトリの中身を削除した：現在ではシンボリックリンクだけを
  削除する(\code{unlink(x, recursive = FALSE)} が常にそうするように)．

#endif
  ワイルドカード展開は \code{\link{Sys.glob}} の内部コードで行われる．
  ワイルドカードはファイル名の先頭の \file{.} にマッチせず，
  ファイル \file{.} と \file{..} は決して削除されない．
#ifdef unix
  ワイルドカードはシステムがそれをサポートする時だけ展開される．
  殆どのシステムは \file{*} と \file{?} だけでなくまた \file{[a-z]}
  のような文字クラスをサポートする(自分の OS のシステムコール \code{glob} の
  \command{man} ページを見よ)．メタ文字 \code{* ? [} は Unix のファイル名に
  登場することが出来，これがそうしたファイルを \code{unlink} で削除することを
  困難にする(\code{\link{file.remove}} を見よ)が，
  メタ文字をバックスラッシュでエスケープ化すれば普通上手くいく．
  もしメタ文字がどれともマッチしなければそれはあるがままの文字と見做される．

  \code{recursive = TRUE} は全てのプラットフォームでサポートされていないかもしれない．
  その時は警告付きで無視される：しかしながら現在知られている例はない．
#endif
#ifdef Windows
  \file{[a-z]} のような文字クラスがサポートされている．
  メタ文字 \code{[} は Windows のファイル名に登場でき，これはそうした
  ファイルを \code{unlink} を使って削除することを困難にする
  (\code{\link{file.remove}} を見よ)．もしワイルドカードがどれともマッチしなければ
  それはそのままの文字と考えられる．

  Windows は現在の作業ディレクトリを削除できないし，
  開かれている任意のファイルやそうしたファイルを含むディレクトリ
  も削除できない．

  現在のエンコーディングで不正な UTF-8 でエンコーディングされたパスを使うことが出来る．
#endif
}
\value{
  成功には \code{0}，失敗には \code{1} で不可視である．
  存在しないファイルを削除しないことや，
  もし \code{recursive = FALSE} ならばディレクトリを削除出来ないこと
  は失敗ではない．
  しかしながら \code{x} 中の欠損値は失敗と見做される．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{file.remove}}.
}
%Examples: tempfile has an 'unlink' example
\keyword{file}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/unlink.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{unlink}
%\title{Delete Files and Directories}
%\usage{unlink(x, recursive = FALSE, force = FALSE)}
%\alias{unlink}
%\arguments{
%  \item{x}{a character vector with the names of the file(s) or
%    directories to be deleted.
%    Wildcards (normally \file{*} and \file{?}) are allowed.}
%  \item{recursive}{logical.  Should directories be deleted recursively?}
%  \item{force}{logical.  Should permissions be changed (if possible) to
%    allow the file or directory to be removed?}
%}
%\description{
%  \code{unlink} deletes the file(s) or directories specified by \code{x}.
%}
%\details{
%  Tilde-expansion (see \code{\link{path.expand}}) is done on \code{x}.
%
%  If \code{recursive = FALSE} directories are not deleted,
%  not even empty ones.
%
%#ifdef unix
%  On most platforms \sQuote{file} includes symbolic links, fifos and
%  sockets.  Prior to \R 2.15.0 \code{unlink(x, recursive = TRUE)} would
%  delete the contents of a directory target of a symbolic link: it now
%  only deletes the symbolic link (as \code{unlink(x, recursive = FALSE)}
%  always has).
%
%#endif
%  Wildcard expansion is done by the internal code of
%  \code{\link{Sys.glob}}.  Wildcards never match a leading \file{.} in
%  the filename, and files \file{.} and \file{..} will never be
%  considered for deletion.
%#ifdef unix
%  Wildcards will only be expanded if the system supports it.  Most
%  systems will support not only \file{*} and \file{?} but also character
%  classes such as \file{[a-z]} (see the \command{man} pages for the system
%  call \code{glob} on your OS).  The metacharacters \code{* ? [} can
%  occur in Unix filenames, and this makes it difficult to use
%  \code{unlink} to delete such files (see \code{\link{file.remove}}),
%  although escaping the metacharacters by backslashes usually works.  If
%  a metacharacter matches nothing it is considered as a literal
%  character.
%
%  \code{recursive = TRUE} might not be supported on all platforms, when it
%  will be ignored, with a warning: however there are no known current
%  examples.
%#endif
%#ifdef Windows
%  Character classes such as \file{[a-z]} are supported.  The
%  metacharacter \code{[} can occur in Windows filenames, and this makes
%  it difficult to use \code{unlink} to delete such files (see
%  \code{\link{file.remove}}).  If a wildcard matches
%  nothing it is considered as a literal character.
%
%  Windows cannot remove the current working directory, nor any file
%  which is open nor any directory containing such a file.
%
%  UTF-8-encoded paths not valid in the current locale can be used.
%#endif
%}
%\value{
%  \code{0} for success, \code{1} for failure, invisibly.
%  Not deleting a non-existent file is not a failure, nor is being unable
%  to delete a directory if \code{recursive = FALSE}.  However, missing
%  values in \code{x} are regarded as failures.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{file.remove}}.
%}
%%Examples: tempfile has an 'unlink' example
%\keyword{file}
%