% File src/library/base/man/vector.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{vector}
\alias{vector}
\alias{as.vector}
\alias{as.vector.factor}
\alias{is.vector}
\alias{atomic} % for cat.Rd and read.table.Rd
\title{Vectors}
\usage{
vector(mode = "logical", length = 0)
as.vector(x, mode = "any")
is.vector(x, mode = "any")
}
\arguments{
  \item{mode}{原子的なモード，\code{"list"}，\code{"expression"} 又は
    (\code{vector} を除き) \code{"any"} に名前を与える文字列．}
  \item{length}{希望の長さを指定する非負整数．
    \code{length > .Machine$integer.max} であるロングベクトルに対しては，
    それは型 \code{"double"} でなければならない．長さ 1 以外の引数を与えるのは
    エラーである．}
  \item{x}{\R オブジェクト．}
}
%% The implementation of is.vector allows any _type_ to be named,
%% and MM uses "symbol" and "language" in str.default()
\description{
  \code{vector} は与えられた長さとモードのベクトルを生成する．

  総称的な \code{as.vector} はその引数をモード \code{mode} のベクトルに
  強制変換しようと試みる(既定では最も便利なモードのベクトルに変換する)：
  もし結果が原子的なら全ての属性を取り除く．

  もし \code{x} が指定されたモードで\emph{名前以外}の属性を持たなければ
  \code{TRUE} を返す．さもなければそれは \code{FALSE} を返す．
}

\details{
  原子的なモードは \code{"logical"}, \code{"integer"},
  \code{"numeric"} (\code{"double"} の同義語), \code{"complex"},
  \code{"character"} そして \code{"raw"} である．

  もし \code{mode = "any"} なら \code{is.vector} は原子的なモード，
  \code{\link{list}} そして \code{\link{expression}} に対して
  \code{TRUE} を返す．
  任意の \code{mode} に対して，もし \code{x} が名前以外の
  任意の属性を持てば \code{FALSE} を返す．
  (これは S と互換性がある．)  一方で \code{as.vector} は原子的なモード
  の結果に対して名前を含む\emph{全て}の属性を取り除く
  (しかしモード \code{"list"} や \code{"expression"} に対しては異なる)．

  因子はベクトルでは\emph{ない}；\code{is.vector} は \code{FALSE} を
  返し，そして \code{as.vector} は \code{mode = "any"} に対しては因子を
  文字列に変換する．
}

\value{
  \code{vector} に対しては与えられた長さとモードのベクトル．論理値ベクトル
  の要素は \code{FALSE} に，数値ベクトルの要素は \code{0} へ，
  文字列ベクトルの要素は \code{""} へ，バイト型ベクトルの要素は
  \code{nul} バイトに，そしてリスト/表現式要素は \code{NULL} に初期化される．

  \code{as.vector} に対してはベクトル(原子的，リスト型又は表現式)．
  もしそれが原子的モードなら全ての属性が結果から取り除かれるが，
  リストの結果に対しては一般にそうではない．既定メソッドは 24 の入力の型と
  12 の \code{type} の値を扱う：殆どの強制変換の詳細は文章化されておらず
  変更される可能性がある．

  \code{is.vector} に対しては \code{TRUE} か \code{FALSE}．
  \code{is.vector(x, mode = "numeric")} は型 \code{"integer"} や
  \code{"double"} のベクトルに対して真になり得るが，
  一方で \code{is.vector(x, mode = "double")} は型 \code{"double"} のそれらに対しては
  真であり得る．
}

\section{\code{as.vector()} に対するメソッド}{
  \code{as.vector} に対するメソッドの作者は既定メソッドの慣習に従う必要がある．
  特に
  \itemize{
    \item 引数 \code{mode} は \code{"any"}, 任意の原子的モード，
    \code{"list"}，\code{"expression"}，\code{"symbol"}，
    \code{"pairlist"} 又は別名 \code{"double"} と \code{"name"}
    のどれかで良い．

    \item 返り値は適当なモードであるべきである．\code{mode = "any"} に
    対しては，これは原子的べクトルかリストを意味する．

    \item 属性は適切に扱われるべきである：特に結果が原子的なベクトルの時は
    名前を含む如何なる属性もあるべきではない．

    \item \code{is.vector(as.vector(x, m), m)} は既定の \code{"any"} を
    含む任意のモード \code{m} に対して真であるべきである．
  }
}

\note{
  \code{as.vector} と \code{is.vector} はパッケージ \pkg{methods} 中の
  形式的クラス \code{"vector"} の意味と非常に異なり，
  従って \code{\link{as}(x, "vector")} と \code{\link{is}(x, "vector")}
  の意味も異なる．

  \code{as.vector(x)} は \code{is.vector(x)} が真ならば
  必ずしも何もしないわけではない：原子的ベクトルからは任意の名前が
  取り去られる．

  ベクトルでない \code{mode} である \code{"symbol"} (\code{"name"} の同義語)と
  \code{"pairlist"} は受け入れられるが長い間文章化されていなかった：
  それらは \code{\link{as.name}} と \code{\link{as.pairlist}} を実装
  するために使われ，これらの関数は好んで直接的に使われる．
  ここでの記述はどれもこれらのモードには適用されない：
  好みの形式に対するヘルプを見よ．
}

\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{c}}, \code{\link{is.numeric}}, \code{\link{is.list}}, 等．
}
\examples{
df <- data.frame(x = 1:3, y = 5:7)
## エラー:
try(as.vector(data.frame(x = 1:3, y = 5:7), mode = "numeric"))

x <- c(a = 1, b = 2)
is.vector(x)
as.vector(x)
all.equal(x, as.vector(x)) ## FALSE


###-- 次は全て TRUE：
is.list(df)
! is.vector(df)
! is.vector(df, mode = "list")

is.vector(list(), mode = "list")
}
\keyword{classes}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/vector.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{vector}
%\alias{vector}
%\alias{as.vector}
%\alias{as.vector.factor}
%\alias{is.vector}
%\alias{atomic} % for cat.Rd and read.table.Rd
%\title{Vectors}
%\usage{
%vector(mode = "logical", length = 0)
%as.vector(x, mode = "any")
%is.vector(x, mode = "any")
%}
%\arguments{
%  \item{mode}{character string naming an atomic mode or
%    \code{"list"} or \code{"expression"} or (except for \code{vector})
%    \code{"any"}.}
%  \item{length}{a non-negative integer specifying the desired length.
%    For a long vector, i.e., \code{length > .Machine$integer.max}, it
%    has to be of type \code{"double"}.  Supplying an argument of length
%    other than one is an error.}
%  \item{x}{an \R object.}
%}
%%% The implementation of is.vector allows any _type_ to be named,
%%% and MM uses "symbol" and "language" in str.default()
%\description{
%  \code{vector} produces a vector of the given length and mode.
%
%  \code{as.vector}, a generic, attempts to coerce its argument into a
%  vector of mode \code{mode} (the default is to coerce to whichever
%  vector mode is most convenient): if the result is atomic all
%  attributes are removed.
%
%  \code{is.vector} returns \code{TRUE} if \code{x} is a vector of the
%  specified mode having no attributes \emph{other than names}.  It returns
%  \code{FALSE} otherwise.
%}
%
%\details{
%  The atomic modes are \code{"logical"}, \code{"integer"},
%  \code{"numeric"} (synonym \code{"double"}), \code{"complex"},
%  \code{"character"} and \code{"raw"}.
%
%  If \code{mode = "any"}, \code{is.vector} may return \code{TRUE} for
%  the atomic modes, \code{\link{list}} and \code{\link{expression}}.
%  For any \code{mode}, it will return \code{FALSE} if \code{x} has any
%  attributes except names.  (This is incompatible with S.)  On the other
%  hand, \code{as.vector} removes \emph{all} attributes including names
%  for results of atomic mode (but not those of mode \code{"list"} nor
%  \code{"expression"}).
%
%  Note that factors are \emph{not} vectors; \code{is.vector} returns
%  \code{FALSE} and \code{as.vector} converts a factor to a character
%  vector for \code{mode = "any"}.
%}
%
%\value{
%  For \code{vector}, a vector of the given length and mode.  Logical
%  vector elements are initialized to \code{FALSE}, numeric vector
%  elements to \code{0}, character vector elements to \code{""}, raw
%  vector elements to \code{nul} bytes and list/expression elements to
%  \code{NULL}.
%
%  For \code{as.vector}, a vector (atomic or of type list or expression).
%  All attributes are removed from the result if it is of an atomic mode,
%  but not in general for a list result.  The default method handles 24
%  input types and 12 values of \code{type}: the details of most
%  coercions are undocumented and subject to change.
%
%  For \code{is.vector}, \code{TRUE} or \code{FALSE}.
%  \code{is.vector(x, mode = "numeric")} can be true for vectors of types
%  \code{"integer"} or \code{"double"} whereas \code{is.vector(x, mode =
%  "double")} can only be true for those of type \code{"double"}.
%}
%
%\section{Methods for \code{as.vector()}}{
%  Writers of methods for \code{as.vector} need to take care to
%  follow the conventions of the default method.  In particular
%  \itemize{
%    \item Argument \code{mode} can be \code{"any"}, any of the atomic
%    modes, \code{"list"}, \code{"expression"}, \code{"symbol"},
%    \code{"pairlist"} or one of the aliases \code{"double"} and \code{"name"}.
%
%    \item The return value should be of the appropriate mode.  For
%    \code{mode = "any"} this means an atomic vector or list.
%
%    \item Attributes should be treated appropriately: in particular when
%    the result is an atomic vector there should be no attributes, not
%    even names.
%
%    \item \code{is.vector(as.vector(x, m), m)} should be true for any
%    mode \code{m}, including the default \code{"any"}.
%  }
%}
%
%\note{
%  \code{as.vector} and \code{is.vector} are quite distinct from the
%  meaning of the formal class \code{"vector"} in the \pkg{methods}
%  package, and hence \code{\link{as}(x, "vector")} and
%  \code{\link{is}(x, "vector")}.
%
%  Note that \code{as.vector(x)} is not necessarily a null operation if
%  \code{is.vector(x)} is true: any names will be removed from an atomic
%  vector.
%
%  Non-vector \code{mode}s \code{"symbol"} (synonym \code{"name"}) and
%  \code{"pairlist"} are accepted but have long been undocumented: they
%  are used to implement \code{\link{as.name}} and
%  \code{\link{as.pairlist}}, and those functions should preferably be
%  used directly.  None of the description here applies to those
%  \code{mode}s: see the help for the preferred forms.
%}
%
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{c}}, \code{\link{is.numeric}}, \code{\link{is.list}}, etc.
%}
%\examples{
%df <- data.frame(x = 1:3, y = 5:7)
%## Error:
%try(as.vector(data.frame(x = 1:3, y = 5:7), mode = "numeric"))
%
%x <- c(a = 1, b = 2)
%is.vector(x)
%as.vector(x)
%all.equal(x, as.vector(x)) ## FALSE
%
%
%###-- All the following are TRUE:
%is.list(df)
%! is.vector(df)
%! is.vector(df, mode = "list")
%
%is.vector(list(), mode = "list")
%}
%\keyword{classes}
%