% File src/library/base/man/warnings.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{warnings}
\title{Print Warning Messages}
\alias{warnings}
\alias{last.warning}
\alias{print.warnings}
\alias{[.warnings}
\alias{c.warnings}
\alias{unique.warnings}
\description{
  \code{warnings} とその \code{print} メソッドは変数
  \code{last.warning} を美しい形式でプリントする．
}
\usage{
warnings(\dots)
}
\arguments{
  \item{\dots}{\code{\link{cat}} に渡される引数．}
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\details{
  \code{last.warning} オブジェクトが存在し \code{warnings()} が
  使われる状況については \code{\link{options}("warn")} の説明を見よ．
  本質的にはこれは \code{options(warn = 0)} で \code{warning}
  が少なくとも一回は呼び出されている場合である．

  \code{last.warning} が最後の警告ではなく最後に記録された警告を
  参照することが可能である．例えば，\code{options(warn)} が変更
  されているか，又は破滅的なエラーが起きた時である．
}
\section{警告}{
  \code{last.warning} がどこに保管されるかとそれが可視かかは文章化されていない．
  これは変更されるかもしれない．
}
\seealso{
  \code{\link{warning}}.
}
\value{an object of S3 class \code{"warnings"}, basically a named
  \code{\link{list}}.
}
\examples{
## 注意：この例は example() で実行するよりもペイストすることを意図している
ow <- options("warn")
for(w in -1:1) {
   options(warn = w); cat("\n warn =", w, "\n")
   for(i in 1:3) { cat(i,"..\n"); m <- matrix(1:7, 3,4) }
}
warnings()
options(ow) # リセット
tail(warnings(), 2) # 最後の二つの警告だけを見る('[' メソッドを使い)
\dontshow{
ww <- warnings()
uw <- unique(ww)
stopifnot(identical(c(ww[1], ww[3]), ww[c(1, 3)]),
          length(uw) == 1, nchar(names(uw)) > 10)
}
}
\keyword{programming}
\keyword{error}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/warnings.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{warnings}
%\title{Print Warning Messages}
%\alias{warnings}
%\alias{last.warning}
%\alias{print.warnings}
%\alias{[.warnings}
%\alias{c.warnings}
%\alias{unique.warnings}
%\description{
%  \code{warnings} and its \code{print} method print the
%  variable \code{last.warning} in a pleasing form.
%}
%\usage{
%warnings(\dots)
%}
%\arguments{
%  \item{\dots}{arguments to be passed to \code{\link{cat}}.}
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\details{
%  See the description of \code{\link{options}("warn")} for the
%  circumstances under which there is a \code{last.warning} object and
%  \code{warnings()} is used.  In essence this is if \code{options(warn =
%    0)} and \code{warning} has been called at least once.
%
%  It is possible that \code{last.warning} refers to the last recorded
%  warning and not to the last warning, for example if \code{options(warn)} has
%  been changed or if a catastrophic error occurred.
%}
%\section{Warning}{
%  It is undocumented where \code{last.warning} is stored nor that it is
%  visible, and this is subject to change.
%}
%\seealso{
%  \code{\link{warning}}.
%}
%\value{an object of S3 class \code{"warnings"}, basically a named
%  \code{\link{list}}.
%}
%\examples{
%## NB this example is intended to be pasted in,
%##    rather than run by example()
%ow <- options("warn")
%for(w in -1:1) {
%   options(warn = w); cat("\n warn =", w, "\n")
%   for(i in 1:3) { cat(i,"..\n"); m <- matrix(1:7, 3,4) }
%}
%warnings()
%options(ow) # reset
%tail(warnings(), 2) # see the last two warnings only (via '[' method)
%\dontshow{
%ww <- warnings()
%uw <- unique(ww)
%stopifnot(identical(c(ww[1], ww[3]), ww[c(1, 3)]),
%          length(uw) == 1, nchar(names(uw)) > 10)
%}
%}
%\keyword{programming}
%\keyword{error}
%