% File src/library/base/man/write.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{write}
\title{Write Data to a File}
\usage{
write(x, file = "data",
      ncolumns = if(is.character(x)) 1 else 5,
      append = FALSE, sep = " ")
}
\alias{write}
\arguments{
  \item{x}{書き込まれるデータ，普通原子的ベクトル．}
  \item{file}{コネクション，又は書き込まれるファイルの名前である文字列．
    もし \code{""} なら標準出力コネクションにプリントされる．
#ifdef unix
    もしこれが \code{"|cmd"} なら，出力は \file{cmd} で与えられる命令に
    パイプされる．
#endif
  }
  \item{ncolumns}{データを書き込む列数．}
  \item{append}{もし \code{TRUE} ならデータ \code{x} はコネクションに追加
    される．}
  \item{sep}{列を分離するために使われる文字列．\code{sep = "\t"} を使うと
    タブで区切られる；既定は \code{" "}．}
}
\description{
  データ(普通行列) \code{x} はファイル \code{file} に書き込まれる．
  もし \code{x} が二次元行列ならば \code{file} 中の列と
  内部表現のそれらを同じにするためには行列を転置する必要がある．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{write} は \code{\link{cat}} に対するラッパで，これは使用される書式に関する
  より詳細を与える．

  任意の \R オブジェクトの書き込みには \code{\link{save}}，
  データフレームについては \code{\link{write.table}}，
  そしてデータの読み込みには \code{\link{scan}}．
}
\examples{
#  2 x 5 行列を作る
x <- matrix(1:10, ncol = 5)

# ファイルデータは x を含む，行数 2，列数 5
# 1 3 5 7 9 が最初の行
write(t(x))

# "console" に書き出す，タブで区切られている
# 行数 2，列数 5 だが最初の行は 1 2 3 4 5
write(x, "", sep = "\t")
unlink("data") # 後片付け
}
\keyword{file}
\keyword{connection}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/write.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{write}
%\title{Write Data to a File}
%\usage{
%write(x, file = "data",
%      ncolumns = if(is.character(x)) 1 else 5,
%      append = FALSE, sep = " ")
%}
%\alias{write}
%\arguments{
%  \item{x}{the data to be written out, usually an atomic vector.}
%  \item{file}{A connection, or a character string naming the file to write to.
%    If \code{""}, print to the standard output connection.
%#ifdef unix
%    If it is \code{"|cmd"}, the output is piped to the command given
%    by \file{cmd}.
%#endif
%  }
%  \item{ncolumns}{the number of columns to write the data in.}
%  \item{append}{if \code{TRUE} the data \code{x} are appended to the
%    connection.}
%  \item{sep}{a string used to separate columns.  Using \code{sep = "\t"}
%    gives tab delimited output; default is \code{" "}.}
%}
%\description{
%  The data (usually a matrix) \code{x} are written to file \code{file}.
%  If \code{x} is a two-dimensional matrix you need to transpose it to get the
%  columns in \code{file} the same as those in the internal representation.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{write} is a wrapper for \code{\link{cat}}, which gives further
%  details on the format used.
%
%  \code{\link{save}} for writing any \R objects,
%  \code{\link{write.table}} for data frames,
%  and \code{\link{scan}} for reading data.
%}
%\examples{
%# create a 2 by 5 matrix
%x <- matrix(1:10, ncol = 5)
%
%# the file data contains x, two rows, five cols
%# 1 3 5 7 9 will form the first row
%write(t(x))
%
%# Writing to the "console" 'tab-delimited'
%# two rows, five cols but the first row is 1 2 3 4 5
%write(x, "", sep = "\t")
%unlink("data") # tidy up
%}
%\keyword{file}
%\keyword{connection}
%