% File src/library/graphics/man/mtext.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{mtext}
\title{Write Text into the Margins of a Plot}
% mtext is defined via do_mtext(.) in  src/main/plot.c ---
\description{
  現在の図領域の四つのマージンの一つ，又はデバイス領域の外縁の一つ
  にテキストを書く．
}
\usage{
mtext(text, side = 3, line = 0, outer = FALSE, at = NA,
      adj = NA, padj = NA, cex = NA, col = NA, font = NA, \dots)
}
\alias{mtext}
\arguments{
  \item{text}{文字列もしくは表現式のベクトルで書き込まれる
    \emph{テキスト}を指定する．他のオブジェクトは
    \code{\link{as.graphicsAnnot}} で強制変換される．}
  \item{side}{プロットのどの側か(1=下部，2=左側，3=上部，4=右側)．}
  \item{line}{どのマージン線か，0 から始まり下方向にカウント．}
  \item{outer}{利用できれば外部マージンを使う．}
  \item{at}{ユーザ座標中の各文字列の位置を与える．
     もし特定のテキスト項目に対応する \code{at} が有限値でなければ(既定値)
     位置は \code{adj} で決定される．}
  \item{adj}{読み取り方向への各文字列の補正．軸に平行な文字列に対しては，
    \code{adj = 0} は左もしくは下揃え，
    \code{adj = 1} は右もしくは上揃えを意味する．

    もし \code{adj} が有限な値(既定)でなければ，値
    \code{par("las")} は補正を決定する．x 軸に平行にプロットされる文字列に
    対しては既定値は文字列をセンタリングする．}
  \item{padj}{読み取り方向に垂直な各文字列に対する補正
    (これは \code{adj} で制御される)．軸に平行な文字列に対しては
    \code{padj = 0} は右もしくは上揃えを意味し，
    \code{padj = 1} は左もしくは下揃えを意味する．

    もし \code{padj} が有限(既定値)でなければ，
    \code{par("las")} の値が補正を決定する．軸に対して垂直にプロットされる
    文字列に対しては，既定は文字列のセンタリングである．}
  \item{cex}{文字の拡大因子．\code{NULL} と \code{NA}
    は \code{1.0} に同値である．これは絶対値であり，
    \code{par("cex")} の比例因子ではなく \code{par("mfrow")}
    や \code{par("mfcol")} で設定されない．ベクトルで良い．}
  \item{col}{使用する色．ベクトルで良い．\code{NA} 値(既定)は
    \code{par("col")} の使用を意味する．}
  \item{font}{テキストに対するフォント．ベクトルで良い．\code{NA} 値(既定)
    は \code{par("font")} の使用を意味する．}
  \item{\dots}{追加のグラフィカルパラメータ(\code{\link{par}} を見よ)で，
    \code{family}, \code{las} そして \code{xpd} を含む．
    (\code{outer = TRUE} でない限り後者の既定値は図領域であり，
    さもなければでデバイス領域である．これは増加出来るだけである．)}
}
\details{
  外部マージン中のユーザ領域は常にゼロから1の範囲にあり，
  図領域中のユーザ座標に影響されない
  --- \R はここでは他の S の実装とは異なる．

  全ての名前付き引数はベクトルで良く，最長のベクトル引数と同じだけの
  文字列をプロットするためにリサイクルが行われる．

  ベクトル \code{adj} は \code{\link{text}} と異なる意味を持つ．
  \code{adj = 0.5} は文字列をセンタリングするが，
  \code{outer = TRUE} に対してはプロット領域ではなくデバイス領域上である．

  パラメータ \code{las} は文字列の方向を決める．
  軸に直交する文字列のプロットに対しては，既定のジャスティフィケーションは
  指定された線上の軸に最も近い文字列の終端で行われる．
  (これは，もし \code{at} が与えられれば \code{str} を使い，
  さもなければ \code{las} を用いる S とは異なることを注意しよう．
  パラメータ \code{srt} は \R では無視される．)

  もしテキストが軸に直交してプロットされれば，\code{at} が指定されていない限り，
  \code{adj} は文字列のジャスティフィケーションと
  軸に沿った位置決めを決める．

  グラフィックスパラメータ \code{"ylbias"} (\code{\link{par}} を見よ)は
  テキストのベースラインが名目上の線に関してどのように置かれるのかを決定する．
}
\section{副作用}{現在のプロットに与えられたテキストが書き込まれる．}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{title}}, \code{\link{text}}, \code{\link{plot}},
  \code{\link{par}};
  数学的注釈に関する詳細は \code{\link{plotmath}}．
}
\examples{
plot(1:10, (-4:5)^2, main = "Parabola Points", xlab = "xlab")
mtext("10 of them")
for(s in 1:4)
    mtext(paste("mtext(..., line= -1, {side, col, font} = ", s,
          ", cex = ", (1+s)/2, ")"), line = -1,
          side = s, col = s, font = s, cex = (1+s)/2)
mtext("mtext(..., line= -2)", line = -2)
mtext("mtext(..., line= -2, adj = 0)", line = -2, adj = 0)
##--- 対数軸：
plot(1:10, exp(1:10), log = "y", main = "log =\"y\"", xlab = "xlab")
for(s in 1:4) mtext(paste("mtext(...,side=", s ,")"), side = s)
}
\keyword{aplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/mtext.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{mtext}
%\title{Write Text into the Margins of a Plot}
%% mtext is defined via do_mtext(.) in  src/main/plot.c ---
%\description{
%  Text is written in one of the four margins of the current figure region
%  or one of the outer margins of the device region.
%}
%\usage{
%mtext(text, side = 3, line = 0, outer = FALSE, at = NA,
%      adj = NA, padj = NA, cex = NA, col = NA, font = NA, \dots)
%}
%\alias{mtext}
%\arguments{
%  \item{text}{a character or \link{expression} vector specifying
%    the \emph{text} to be written.  Other objects are coerced by
%    \code{\link{as.graphicsAnnot}}.}
%  \item{side}{on which side of the plot (1=bottom, 2=left, 3=top, 4=right).}
%  \item{line}{on which MARgin line, starting at 0 counting outwards.}
%  \item{outer}{use outer margins if available.}
%  \item{at}{give location of each string in user coordinates.  If the
%     component of \code{at} corresponding to a particular text item is
%     not a finite value (the default), the location will be determined
%     by \code{adj}.}
%  \item{adj}{adjustment for each string in reading direction.  For
%    strings parallel to the axes, \code{adj = 0} means left or bottom
%    alignment, and \code{adj = 1} means right or top alignment.
%
%    If \code{adj} is not a finite value (the default), the value of
%    \code{par("las")} determines the adjustment.  For strings plotted
%    parallel to the axis the default is to centre the string.}
%  \item{padj}{adjustment for each string perpendicular to the reading
%    direction (which is controlled by \code{adj}).  For strings parallel
%    to the axes, \code{padj = 0} means right or top alignment,
%    and \code{padj = 1} means left or bottom alignment.
%
%    If \code{padj} is not a finite value (the default), the value of
%    \code{par("las")} determines the adjustment.  For strings plotted
%    perpendicular to the axis the default is to centre the string.}
%  \item{cex}{character expansion factor.  \code{NULL} and \code{NA}
%    are equivalent to \code{1.0}.  This is an absolute measure, not
%    scaled by \code{par("cex")} or by setting \code{par("mfrow")}
%    or \code{par("mfcol")}.  Can be a vector.}
%  \item{col}{color to use.  Can be a vector.  \code{NA} values (the
%    default) mean use \code{par("col")}.}
%  \item{font}{font for text.  Can be a vector.  \code{NA} values (the
%    default) mean use \code{par("font")}.}
%  \item{\dots}{Further graphical parameters (see \code{\link{par}}),
%    including \code{family}, \code{las} and \code{xpd}. (The latter
%    defaults to the figure region unless \code{outer = TRUE}, otherwise
%    the device region.  It can only be increased.)}
%}
%\details{
%  The user coordinates in the outer margins always range from zero to
%  one, and are not affected by the user coordinates in the figure
%  region(s) --- \R differs here from other implementations of S.
%
%  All of the named arguments can be vectors, and recycling will take
%  place to plot as many strings as the longest of the vector arguments.
%
%  Note that a vector \code{adj} has a different meaning from
%  \code{\link{text}}.  \code{adj = 0.5} will centre the string, but for
%  \code{outer = TRUE} on the device region rather than the plot region.
%
%  Parameter \code{las} will determine the orientation of the string(s).
%  For strings plotted perpendicular to the axis the default justification
%  is to place the end of the string nearest the axis on the specified
%  line.  (Note that this differs from S, which uses \code{srt} if
%  \code{at} is supplied and \code{las} if it is not.  Parameter
%  \code{srt} is ignored in \R.)
%
%  Note that if the text is to be plotted perpendicular to the axis,
%  \code{adj} determines the justification of the string \emph{and} the
%  position along the axis unless \code{at} is specified.
%
%  Graphics parameter \code{"ylbias"} (see \code{\link{par}}) determines
%  how the text baseline is placed relative to the nominal line.
%}
%\section{Side Effects}{The given text is written onto the current plot.}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{title}}, \code{\link{text}}, \code{\link{plot}},
%  \code{\link{par}};
%  \code{\link{plotmath}} for details on mathematical annotation.
%}
%\examples{
%plot(1:10, (-4:5)^2, main = "Parabola Points", xlab = "xlab")
%mtext("10 of them")
%for(s in 1:4)
%    mtext(paste("mtext(..., line= -1, {side, col, font} = ", s,
%          ", cex = ", (1+s)/2, ")"), line = -1,
%          side = s, col = s, font = s, cex = (1+s)/2)
%mtext("mtext(..., line= -2)", line = -2)
%mtext("mtext(..., line= -2, adj = 0)", line = -2, adj = 0)
%##--- log axis :
%plot(1:10, exp(1:10), log = "y", main = "log =\"y\"", xlab = "xlab")
%for(s in 1:4) mtext(paste("mtext(...,side=", s ,")"), side = s)
%}
%\keyword{aplot}
%
%\encoding{UTF8}
%