% File src/library/graphics/man/screen.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{screen}
\title{Creating and Controlling Multiple Screens on a Single Device}
\usage{
split.screen(figs, screen, erase = TRUE)
screen(n = , new = TRUE)
erase.screen(n = )
close.screen(n, all.screens = FALSE)
}
\alias{screen}
\alias{split.screen}
\alias{erase.screen}
\alias{close.screen}
\arguments{
  \item{figs}{
    スクリーン行列の行と列の数を記述する要素2のベクトル，\emph{または}
    4列の行列．
    もし行列ならば各列は NDC 単位のスクリーンの左，右，下，上(この順序で)に
    対する値を持つスクリーンを記述する，
    これはデバイス面の左下が 0 で，右上が 1 である．}
  \item{screen}{分割されるべきスクリーンを与える番号．
    既定はもしあれば現在のスクリーンで，
    さもなければ全デバイス領域．}
  \item{erase}{論理値：選ばれたスクリーンをクリアすべきか?}
  \item{n}{どのスクリーンを
    描画(\code{screen})，消去(\code{erase.screen})，又は閉じる\cr
    (\code{close.screen})ために準備するかを指示する番号．
    (\code{close.screen} はスクリーン番号のベクトルを受け入れる．)}
  \item{new}{スクリーン中に描画するための準備の
    一部としてスクリーンを消去するかを指示する論理値．}
  \item{all.screens}{全てのスクリーンを消去するかを指示する論理値．}
}
\description{
  \code{split.screen} は現在のデバイス内に，ある程度別個のグラフィックス
  デバイスとして扱える幾つかの領域を定義する．
  これは一つのデバイス上に複数のプロットを生成するのに有用である．
  スクリーンはそれら自体分割でき，非常に複雑なプロットの配置を
  可能にする．

  \code{screen} はどのスクリーンに描画するかを選択するのに使われる．

  \code{erase.screen} は一つのスクリーンをクリアするのに使われ，
  それは背景色で塗りつぶすことでなされる．

  \code{close.screen} は指定されたスクリーン定義を取り除く．
}
\details{
  \code{split.screen} の最初の呼び出しは \R を分割スクリーン
  モードに置く．
  他の分割スクリーンモードはこのモード内部でのみ動作する．
  このモード中にいる場合，幾つかの他の命令は避けなければならない
  (下の警告節を見よ)．
  分割スクリーンモードは命令  
  \code{close.screen(all = TRUE)} で抜け出せる．

  もし現在のスクリーンが閉じられると，
  \code{close.screen} は現在のスクリーンをもしあれば
  次のより大きなスクリーン番号に設定し，さもなければ
  最初の利用可能なスクリーンに設定される．
}
\value{
  \code{split.screen} は新しく作られたスクリーンに対する
  スクリーン番号のベクトルを返す．
  引数なしでは \code{split.screen} は有効なスクリーンの番号の
  ベクトルを返す．

  \code{screen} は選択されたスクリーンの番号を不可視で返す．
  引数なしでは \code{screen} は現在のスクリーンの番号を返す．

  \code{close.screen} は有効なスクリーンの番号のベクトルを
  返す．

  \code{screen}, \code{erase.screen} そして \code{close.screen}
  全てはもし \R が分割スクリーンモードでなければ
  \code{FALSE} を返す．
}

\section{警告}{
  これらの関数のお勧めの用法は
  基本プロットに完全なプロットと全ての追加
  (つまり，点と線)を
  別のスクリーンを選択しプロットする前に描画することである．
  あるスクリーンに戻って既存のプロットにつけ加えることに
  伴う挙動は予測不可能であり，たやすく眺めることが出来ないという
  結果に陥るかもしれない．

  これらの関数はデバイスにプロットを配置する他の機構，
  \code{\link{par}(mfrow)},
  \code{par(mfcol)} そしてd \code{\link{layout}()}，
  と全く一貫性がない．
  
  関数はまた
  \code{\link{coplot}} の様なこれらの機構を使うある種のプロット
  関数とも一貫性がない．

  \code{erase.screen} はもし背景色が透明(殆どのデバイスで既定)
  ならば動作しないようである．
}

\seealso{
  \code{\link{par}}, \code{\link{layout}}, \code{\link{Devices}},
  \code{dev.*}
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical Models in S}.
  Wadsworth & Brooks/Cole.

  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
}

\examples{
if (interactive()) {
par(bg = "white")           # 既定では恐らく透明
split.screen(c(2, 1))       # ディスプレイを二つのスクリーンに分割
split.screen(c(1, 3), screen = 2) # 下半分を三つに分割
screen(1) # スクリーン1を出力用に準備
plot(10:1)
screen(4) # スクリーン4を出力用に準備
plot(10:1)
close.screen(all = TRUE)    # 分割スクリーンモードから抜ける

split.screen(c(2, 1))       # ディスプレイを二つのスクリーンに分割
split.screen(c(1, 2), 2)    # 下半分を三つに分割
plot(1:10)                  # スクリーン 3 がアクティブ，プロットを描く
erase.screen()              # ラベルを忘れていた，消して再描画
plot(1:10, ylab = "ylab 3")
screen(1)                   # スクリーン1を出力用に準備
plot(1:10)
screen(4)                   # スクリーン4を出力用に準備
plot(1:10, ylab = "ylab 4")
screen(1, FALSE)            # スクリーン 1 に戻るが，クリアしない
plot(10:1, axes = FALSE, lty = 2, ylab = "")  # 二番目のプロットを重ね描き
axis(4)                     # 右手の軸にチックマークを加える
title("Plot 1")
close.screen(all = TRUE)    # 分割スクリーンモードから抜ける
}
}
\keyword{aplot}
\keyword{dplot}
\keyword{device}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/screen.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{screen}
%\title{Creating and Controlling Multiple Screens on a Single Device}
%\usage{
%split.screen(figs, screen, erase = TRUE)
%screen(n = , new = TRUE)
%erase.screen(n = )
%close.screen(n, all.screens = FALSE)
%}
%\alias{screen}
%\alias{split.screen}
%\alias{erase.screen}
%\alias{close.screen}
%\arguments{
%  \item{figs}{A two-element vector describing the number of rows and the
%    number of columns in a screen matrix \emph{or} a matrix with 4 columns.
%    If a matrix, then each row describes a screen with values for the left,
%    right, bottom, and top of the screen (in that order) in NDC units,
%    that is 0 at the lower left corner of the device surface, and 1 at
%    the upper right corner.}
%  \item{screen}{A number giving the screen to be split.  It defaults to
%    the current screen if there is one, otherwise the whole device region.}
%  \item{erase}{logical: should be selected screen be cleared?}
%  \item{n}{A number indicating which screen to prepare for drawing
%    (\code{screen}), erase (\code{erase.screen}), or close
%    (\code{close.screen}).  (\code{close.screen} will accept a vector of
%    screen numbers.)}
%  \item{new}{A logical value indicating whether the screen should be
%    erased as part of the preparation for drawing in the screen.}
%  \item{all.screens}{A logical value indicating whether all of the
%    screens should be closed.}
%}
%\description{
%  \code{split.screen} defines a number of regions within the current
%  device which can, to some extent, be treated as separate graphics
%  devices.  It is useful for generating multiple plots on a single
%  device.  Screens can themselves be split, allowing for quite complex
%  arrangements of plots.
%
%  \code{screen} is used to select which screen to draw in.
%
%  \code{erase.screen} is used to clear a single screen, which it
%  does by filling with the background colour.
%
%  \code{close.screen} removes the specified screen definition(s).
%}
%\details{
%  The first call to \code{split.screen} places \R into split-screen
%  mode.  The other split-screen functions only work within this mode.
%  While in this mode, certain other commands should be avoided (see the
%  Warnings section below).  Split-screen mode is exited by the command
%  \code{close.screen(all = TRUE)}.
%
%  If the current screen is closed, \code{close.screen} sets the current
%  screen to be the next larger screen number if there is one, otherwise
%  to the first available screen.
%}
%\value{
%  \code{split.screen} returns a vector of screen numbers for the
%  newly-created screens.  With no arguments, \code{split.screen} returns
%  a vector of valid screen numbers.
%
%  \code{screen} invisibly returns the number of the selected screen.
%  With no arguments, \code{screen} returns the number of the current
%  screen.
%
%  \code{close.screen} returns a vector of valid screen numbers.
%
%  \code{screen}, \code{erase.screen}, and \code{close.screen} all return
%  \code{FALSE} if \R is not in split-screen mode.
%}
%
%\section{Warnings}{
%  The recommended way to use these functions is to completely draw a
%  plot and all additions (i.e., points and lines) to the base plot, prior to
%  selecting and plotting on another screen. The behavior associated with
%  returning to a screen to add to an existing plot is unpredictable and
%  may result in problems that are not readily visible.
%
%  These functions are totally incompatible with the other mechanisms for
%  arranging plots on a device: \code{\link{par}(mfrow)},
%  \code{par(mfcol)} and \code{\link{layout}()}.
%
%  The functions are also incompatible with some plotting functions,
%  such as \code{\link{coplot}}, which make use of these other mechanisms.
%
%  \code{erase.screen} will appear not to work if the background colour
%  is transparent (as it is by default on most devices).
%}
%
%\seealso{
%  \code{\link{par}}, \code{\link{layout}}, \code{\link{Devices}},
%  \code{dev.*}
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical Models in S}.
%  Wadsworth & Brooks/Cole.
%
%  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
%}
%
%\examples{
%if (interactive()) {
%par(bg = "white")           # default is likely to be transparent
%split.screen(c(2, 1))       # split display into two screens
%split.screen(c(1, 3), screen = 2) # now split the bottom half into 3
%screen(1) # prepare screen 1 for output
%plot(10:1)
%screen(4) # prepare screen 4 for output
%plot(10:1)
%close.screen(all = TRUE)    # exit split-screen mode
%
%split.screen(c(2, 1))       # split display into two screens
%split.screen(c(1, 2), 2)    # split bottom half in two
%plot(1:10)                  # screen 3 is active, draw plot
%erase.screen()              # forgot label, erase and redraw
%plot(1:10, ylab = "ylab 3")
%screen(1)                   # prepare screen 1 for output
%plot(1:10)
%screen(4)                   # prepare screen 4 for output
%plot(1:10, ylab = "ylab 4")
%screen(1, FALSE)            # return to screen 1, but do not clear
%plot(10:1, axes = FALSE, lty = 2, ylab = "")  # overlay second plot
%axis(4)                     # add tic marks to right-hand axis
%title("Plot 1")
%close.screen(all = TRUE)    # exit split-screen mode
%}
%}
%\keyword{aplot}
%\keyword{dplot}
%\keyword{device}
%
%\encoding{UTF8}
%