% File src/library/graphics/man/xspline.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{xspline}
\alias{xspline}
\title{Draw an X-spline}
\description{
  制御点に関して描かれる曲線である X-スプラインを描く．
}
\usage{
xspline(x, y = NULL, shape = 0, open = TRUE, repEnds = TRUE,
        draw = TRUE, border = par("fg"), col = NA, \dots)
}
\arguments{
  \item{x,y}{多角形の頂点座標を含むベクトル．
    別の指定方法は \code{\link{xy.coords}} を見よ．}
  \item{shape}{
    -1 と 1 の間の値の数値ベクトルで，
    制御点に関するスプラインの形状を制御する．}
  \item{open}{スプラインが開いているか閉じているかも指示する
    論理値．}
  \item{repEnds}{開いた X-スプラインに対して，
    曲線を描く再最初と最後の制御点を複製するべきかどうかを
    指示する論理値．
    閉じた X-スプラインに対しては無視される．}
  \item{draw}{論理値：X-スプラインを描くべきか?  
    もし偽なら，曲線を描く線分が返され，何も描かれない．}
  \item{border}{曲線を描く色．
    境界を除外するためには \code{border = NA} を使う．}
  \item{col}{図形を塗りつぶす色．
    既定の \code{NA} では塗りつぶさない．}
  \item{\dots}{
    \code{lty}, \code{xpd}, \code{lend}, \code{ljoin} そして
    \code{lmitre} の様なグラフィカルパラメータを
    引数として渡すことが出来る．}
}
\details{
  X-スプラインは制御点を用いて描かれる曲線である．
  各制御点に対し，曲線は制御点を通る(補間)かもしれないし，
  制御点に(近似的に)近づくだけかもしれない；
  その挙動は各制御点に対する形状パラメータにより決定される．

  もし形状パラメータがゼロより大きければ，
  スプラインは制御点を近似する
  (そして形状が 1 ならば3次 B-スプラインに非常に近い)．
  もし形状がゼロ以下ならば，スプラインは制御点を補間する
  (そして形状が -1 ならば Catmull-Rom スプラインに非常に近い)．
  もし形状パラメータが 0 ならば，スプラインはその制御点で
  鋭角な角を作る．

  開いた X-スプラインに対しては制御点の開始と終了制御点は
  形状 0 を持たなければならない
  (そしてゼロでない値は黙ってゼロに変換される)．

  開いた X-スプラインに対しては，既定では制御点の開始と終了制御点は
  曲線が描かれる前に複製される．
  曲線は各四つの制御点セットの二番目と三番目の間に
  描かれる(補間もしくは近似)ので，
  この既定動作は結果の曲線が指定された最初の制御点から始まり，
  最後の制御点で終わることを保証する．
  この既定動作は \code{repEnds} 引数により無効に出来る．
}
\value{
  もし \code{draw = TRUE} なら \code{NULL}，さもなければ
  要素 \code{x} と \code{y} を持つリストで
  \code{\link{lines}}, \code{\link{polygon}} 等に渡すことが出来る．

  どちらのケースも不可視である．
}
\note{
   2次元スプラインは等方的な座標システム中で作られる必要がある．
   (必要なら異方性補正とともに)デバイス座標が使われる．
}
\references{
  Blanc, C. and Schlick, C. (1995),
  \emph{X-splines : A Spline Model Designed for the End User},
  in \emph{Proceedings of SIGGRAPH 95}, pp.\sspace{}377--386.
  \url{http://dept-info.labri.fr/~schlick/DOC/sig1.html}
}
\seealso{
  \code{\link{polygon}}.

  色の指定法は \code{\link{par}}．
}
\examples{
## ?grid.xspline 中の例を使う．

xsplineTest <- function(s, open = TRUE,
                        x = c(1,1,3,3)/4,
                        y = c(1,3,3,1)/4, ...) {
    plot(c(0,1), c(0,1), type = "n", axes = FALSE, xlab = "", ylab = "")
    points(x, y, pch = 19)
    xspline(x, y, s, open, ...)
    text(x+0.05*c(-1,-1,1,1), y+0.05*c(-1,1,1,-1), s)
}
op <- par(mfrow = c(3,3), mar = rep(0,4), oma = c(0,0,2,0))
xsplineTest(c(0, -1, -1, 0))
xsplineTest(c(0, -1,  0, 0))
xsplineTest(c(0, -1,  1, 0))
xsplineTest(c(0,  0, -1, 0))
xsplineTest(c(0,  0,  0, 0))
xsplineTest(c(0,  0,  1, 0))
xsplineTest(c(0,  1, -1, 0))
xsplineTest(c(0,  1,  0, 0))
xsplineTest(c(0,  1,  1, 0))
title("Open X-splines", outer = TRUE)

par(mfrow = c(3,3), mar = rep(0,4), oma = c(0,0,2,0))
xsplineTest(c(0, -1, -1, 0), FALSE, col = "grey80")
xsplineTest(c(0, -1,  0, 0), FALSE, col = "grey80")
xsplineTest(c(0, -1,  1, 0), FALSE, col = "grey80")
xsplineTest(c(0,  0, -1, 0), FALSE, col = "grey80")
xsplineTest(c(0,  0,  0, 0), FALSE, col = "grey80")
xsplineTest(c(0,  0,  1, 0), FALSE, col = "grey80")
xsplineTest(c(0,  1, -1, 0), FALSE, col = "grey80")
xsplineTest(c(0,  1,  0, 0), FALSE, col = "grey80")
xsplineTest(c(0,  1,  1, 0), FALSE, col = "grey80")
title("Closed X-splines", outer = TRUE)

par(op)

x <- sort(stats::rnorm(5))
y <- sort(stats::rnorm(5))
plot(x, y, pch = 19)
res <- xspline(x, y, 1, draw = FALSE)
lines(res)
## 端の点は非常に近いかもしれず，方向のためには最後の少数を使う
nr <- length(res$x)
arrows(res$x[1], res$y[1], res$x[4], res$y[4], code = 1, length = 0.1)
arrows(res$x[nr-3], res$y[nr-3], res$x[nr], res$y[nr], code = 2, length = 0.1)
}
\keyword{aplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/xspline.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{xspline}
%\alias{xspline}
%\title{Draw an X-spline}
%\description{
%  Draw an X-spline, a curve drawn relative to control points.
%}
%\usage{
%xspline(x, y = NULL, shape = 0, open = TRUE, repEnds = TRUE,
%        draw = TRUE, border = par("fg"), col = NA, \dots)
%}
%\arguments{
%  \item{x,y}{vectors containing the coordinates of the vertices
%    of the polygon. See \code{\link{xy.coords}} for alternatives.}
%  \item{shape}{A numeric vector of values between -1 and 1, which
%    control the shape of the spline relative to the control points.}
%  \item{open}{A logical value indicating whether the spline is
%    an open or a closed shape.}
%  \item{repEnds}{For open X-splines, a logical value indicating whether
%    the first and last control points should be replicated for drawing
%    the curve. Ignored for closed X-splines.}
%  \item{draw}{logical: should the X-spline be drawn?  If false, a set of
%    line segments to draw the curve is returned, and nothing is drawn.}
%  \item{border}{the color to draw the curve.   Use \code{border = NA} to
%    omit borders.}
%  \item{col}{the color for filling the shape. The default,
%    \code{NA}, is to leave unfilled.}
%  \item{\dots}{\link{graphical parameters} such as \code{lty}, \code{xpd},
%    \code{lend}, \code{ljoin} and \code{lmitre} can be given as arguments.}
%}
%\details{
%  An X-spline is a line drawn relative to control points.  For each
%  control point, the line may pass through (interpolate) the control
%  point or it may only approach (approximate) the control point;  the
%  behaviour is determined by a shape parameter for each control point.
%
%  If the shape parameter is greater than zero, the spline approximates
%  the control points (and is very similar to a cubic B-spline when the
%  shape is 1).  If the shape parameter is less than zero, the spline
%  interpolates the control points (and is very similar to a Catmull-Rom
%  spline when the shape is -1).  If the shape parameter is 0, the spline
%  forms a sharp corner at that control point.
%
%  For open X-splines, the start and end control points must have a shape
%  of 0 (and non-zero values are silently converted to zero).
%
%  For open X-splines, by default the start and end control points are
%  replicated before the curve is drawn.  A curve is drawn between
%  (interpolating or approximating) the second and third of each set of
%  four control points, so this default behaviour ensures that the
%  resulting curve starts at the first control point you have specified
%  and ends at the last control point.  The default behaviour can be
%  turned off via the \code{repEnds} argument.
%}
%\value{
%  If \code{draw = TRUE}, \code{NULL} otherwise a list with elements
%  \code{x} and \code{y} which could be passed to \code{\link{lines}},
%  \code{\link{polygon}} and so on.
%
%  Invisible in both cases.
%}
%\note{
%  Two-dimensional splines need to be created in an isotropic coordinate
%  system.  Device coordinates are used (with an anisotropy correction if
%  needed.)
%}
%\references{
%  Blanc, C. and Schlick, C. (1995),
%  \emph{X-splines : A Spline Model Designed for the End User},
%  in \emph{Proceedings of SIGGRAPH 95}, pp.\sspace{}377--386.
%  \url{http://dept-info.labri.fr/~schlick/DOC/sig1.html}
%}
%\seealso{
%  \code{\link{polygon}}.
%
%  \code{\link{par}} for how to specify colors.
%}
%\examples{
%## based on examples in ?grid.xspline
%
%xsplineTest <- function(s, open = TRUE,
%                        x = c(1,1,3,3)/4,
%                        y = c(1,3,3,1)/4, ...) {
%    plot(c(0,1), c(0,1), type = "n", axes = FALSE, xlab = "", ylab = "")
%    points(x, y, pch = 19)
%    xspline(x, y, s, open, ...)
%    text(x+0.05*c(-1,-1,1,1), y+0.05*c(-1,1,1,-1), s)
%}
%op <- par(mfrow = c(3,3), mar = rep(0,4), oma = c(0,0,2,0))
%xsplineTest(c(0, -1, -1, 0))
%xsplineTest(c(0, -1,  0, 0))
%xsplineTest(c(0, -1,  1, 0))
%xsplineTest(c(0,  0, -1, 0))
%xsplineTest(c(0,  0,  0, 0))
%xsplineTest(c(0,  0,  1, 0))
%xsplineTest(c(0,  1, -1, 0))
%xsplineTest(c(0,  1,  0, 0))
%xsplineTest(c(0,  1,  1, 0))
%title("Open X-splines", outer = TRUE)
%
%par(mfrow = c(3,3), mar = rep(0,4), oma = c(0,0,2,0))
%xsplineTest(c(0, -1, -1, 0), FALSE, col = "grey80")
%xsplineTest(c(0, -1,  0, 0), FALSE, col = "grey80")
%xsplineTest(c(0, -1,  1, 0), FALSE, col = "grey80")
%xsplineTest(c(0,  0, -1, 0), FALSE, col = "grey80")
%xsplineTest(c(0,  0,  0, 0), FALSE, col = "grey80")
%xsplineTest(c(0,  0,  1, 0), FALSE, col = "grey80")
%xsplineTest(c(0,  1, -1, 0), FALSE, col = "grey80")
%xsplineTest(c(0,  1,  0, 0), FALSE, col = "grey80")
%xsplineTest(c(0,  1,  1, 0), FALSE, col = "grey80")
%title("Closed X-splines", outer = TRUE)
%
%par(op)
%
%x <- sort(stats::rnorm(5))
%y <- sort(stats::rnorm(5))
%plot(x, y, pch = 19)
%res <- xspline(x, y, 1, draw = FALSE)
%lines(res)
%## the end points may be very close together,
%## so use last few for direction
%nr <- length(res$x)
%arrows(res$x[1], res$y[1], res$x[4], res$y[4], code = 1, length = 0.1)
%arrows(res$x[nr-3], res$y[nr-3], res$x[nr], res$y[nr], code = 2, length = 0.1)
%}
%\keyword{aplot}
%
%\encoding{UTF8}
%