% File src/library/graphics/man/zAxis.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{Axis}
\alias{Axis}
\title{Generic Function to Add an Axis to a Plot}
\description{
  現在のプロットに適当な軸を加える総称的関数．
}
\usage{
Axis(x = NULL, at = NULL, \dots, side, labels = NULL)
}
\arguments{
  \item{x}{軸が引かれる範囲を指示するオブジェクト．}
  \item{at}{チックマークが描かれる点．}
  \item{side}{プロットのどの側に軸を描くかを指示する整数．
    軸は次のように置かれる： 1=下側，2=左側，3=上側，そして 4=右側．}
  \item{labels}{これは
    チックマーク位置に(数値の)注釈を行うことを指示する論理値でも，
    チック点に置かれる文字列もしくは表現式のラベルのベクトル
    でも良い．
    もしこれが文字列又は表現式のベクトルとして指定されると
    \code{at} を提供すべきで同じ長さでなければならない．}
  \item{\dots}{メソッドに渡され，恐らくそれから
    \code{\link{axis}} に渡される引数．}
}
\value{
  プロットが最初に描かれる時
  (\sQuote{詳細}を見よ)にチックマークが描かれる軸スケール上の
  位置の数値．

  この関数は普通その副作用のために起動され，
  既存のプロットに軸を加える．
}
\details{
  これは総称的関数である．
  これは少々標準的ではない仕方で動作する：
  もし \code{x} が提供され NULL でなければそれは
  \code{x} に関してメソッドを選択適用し，
  さもなければ，もし \code{at} が提供され NULL でなければ
  それは \code{at} に関してメソッドを選択適用し，
  そして既定動作は \code{\link{axis}} を引数
  \code{x} を除いて呼び出す．

  アイデアは一方もしくは双方の軸が数値であるが特殊な解釈を持てば，
  標準的なプロット関数
  (\code{\link{boxplot}}, \code{\link{contour}},
  \code{\link{coplot}}, \code{\link{filled.contour}},
  \code{\link{pairs}}, \code{\link{plot.default}}, \code{\link{rug}} そして
  \code{\link{stripchart}} を含む)がユーザ座標を設定し，それから
  \code{Axis} がそれらのラベルを適当に付けるために呼び出される，
  ということである．

  \code{"Date"} と \code{"POSIXt"} メソッドがあり，それらは
  引数 \code{format} を適当な \code{axis} メソッドに
  渡す(\code{\link{axis.POSIXct}} を見よ)．
}
\seealso{
  \code{\link{axis}}.
}
\keyword{aplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/zAxis.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Axis}
%\alias{Axis}
%\title{Generic Function to Add an Axis to a Plot}
%\description{
%  Generic function to add a suitable axis to the current plot.
%}
%\usage{
%Axis(x = NULL, at = NULL, \dots, side, labels = NULL)
%}
%\arguments{
%  \item{x}{an object which indicates the range over which an axis should
%    be drawn}
%  \item{at}{the points at which tick-marks are to be drawn.}
%  \item{side}{an integer specifying which side of the plot the axis is
%    to be drawn on.  The axis is placed as follows: 1=below,
%    2=left, 3=above and 4=right.}
%  \item{labels}{this can either be a logical value specifying whether
%    (numerical) annotations are to be made at the tickmarks, or a
%    character or expression vector of labels to be placed at the
%    tickpoints. If this is specified as a character or expression
%    vector, \code{at} should be supplied and they should be the same
%    length.}
%  \item{\dots}{Arguments to be passed to methods and perhaps then to
%    \code{\link{axis}}.}
%}
%\value{
%  The numeric locations on the axis scale at which tick marks were drawn
%  when the plot was first drawn (see \sQuote{Details}).
%
%  This function is usually invoked for its side effect, which is to add
%  an axis to an already existing plot.
%}
%\details{
%  This is a generic function.  It works in a slightly non-standard way:
%  if \code{x} is supplied and non-NULL it dispatches on \code{x},
%  otherwise if \code{at} is supplied and non-NULL it dispatches on \code{at},
%  and the default action is to call \code{\link{axis}}, omitting argument
%  \code{x}.
%
%  The idea is that for plots for which either or both of the axes are
%  numerical but with a special interpretation, the standard plotting
%  functions (including \code{\link{boxplot}}, \code{\link{contour}},
%  \code{\link{coplot}}, \code{\link{filled.contour}},
%  \code{\link{pairs}}, \code{\link{plot.default}}, \code{\link{rug}} and
%  \code{\link{stripchart}}) will set up user coordinates and \code{Axis}
%  will be called to label them appropriately.
%
%  There are \code{"Date"} and \code{"POSIXt"} methods which can pass an
%  argument \code{format} on to the appropriate \code{axis} method (see
%  \code{\link{axis.POSIXct}}).
%}
%\seealso{
%  \code{\link{axis}}.
%}
%\keyword{aplot}
%
%\encoding{UTF8}
%