% File src/library/parallel/man/unix/mcaffinity.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009-2014 R Core Team
% Distributed under GPL 2 or later

\name{mcaffinity}
\alias{mcaffinity}

\title{Get or Set CPU Affinity Mask of the Current Process}
\description{
  \code{mcaffinity} は現在のプロセスの CPU アフィニティマスクを
  回収したり設定したりする，つまり
  プロセスがその上で実行を許される CPU のセットである．
  (ここで CPU とは CPU になり得る論理 CPU，コア又は
  ハイパースレッドユニットを意味する．)
}
\usage{
mcaffinity(affinity = NULL)
}
\arguments{
  \item{affinity}{
    このプロセスをロックする CPU の指定
    (数値ベクトル) 又はもし変更が要求されなければ \code{NULL}．}
}
\details{
  \code{mcaffinity} は現在のプロセスの CPU アフィニティマスクを
  得たり(\code{affinity = NULL})又は設定するのに使える．
  CPU アフィニティマスクはこのプロセスがその上で実行を
  許される整数の CPU 識別子(1 から始まる)のリストである．
  全てのシステムが CPU アフィニティマスクへのユーザのアクセスを
  許すわけではなく，サポートが全くされない場合は
  \code{mcaffinity()} は \code{NULL} を返す．
  ある種のシステムはマスク中にある CPU の数だけを考慮するかもしれない．

  典型的には，論理 CPU の数よりも大きなセットを指定することは
  適正であり
  (しかし最大でも OS が扱えるだけの多さに限られる)，そしてシステムは
  実際に存在するセットに復帰する．
}
\value{
  もし CPU アフィニティがシステムによりサポートされていなければ
  \code{NULL} を，又はこのプロセスに対してアクティブな CPU
  アフィニティマスク中の CPU セットの整数ベクトル
  (これは \code{affinity} とは異なるかもしれない)．
}
\author{
  Simon Urbanek.
}
\seealso{
  \code{\link{mcparallel}}
}
\keyword{interface}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/parallel/man/unix/mcaffinity.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{mcaffinity}
%\alias{mcaffinity}
%
%\title{Get or Set CPU Affinity Mask of the Current Process}
%\description{
%  \code{mcaffinity} retrieves or sets the CPU affinity mask of the
%  current process, i.e., the set of CPUs the process is allowed to be
%  run on. (CPU here means logical CPU which can be CPU, core or
%  hyperthread unit.)
%}
%\usage{
%mcaffinity(affinity = NULL)
%}
%\arguments{
%  \item{affinity}{specification of the CPUs to lock this process to
%    (numeric vector) or \code{NULL} if no change is requested}
%}
%\details{
%  \code{mcaffinity} can be used to obtain (\code{affinity = NULL})
%  or set the CPU affinity mask of the current process. The affinity mask
%  is a list of integer CPU identifiers (starting from 1) that this
%  process is allowed to run on. Not all systems provide user access to
%  the process CPU affinity, in cases where no support is present at all
%  \code{mcaffinity()} will return \code{NULL}. Some systems may take
%  into account only the number of CPUs present in the mask.
%
%  Typically, it is legal to specify larger set than the number of
%  logical CPUs (but at most as many as the OS can handle) and the system
%  will return back the actually present set.
%}
%\value{
%  \code{NULL} if CPU affinity is not supported by the system or an
%  integer vector with the set of CPUs in the active affinity mask for
%  this process (this may be different than \code{affinity}).
%}
%\author{
%  Simon Urbanek.
%}
%\seealso{
%  \code{\link{mcparallel}}
%}
%\keyword{interface}
%
%\encoding{UTF-8}
%