% File src/library/parallel/man/unix/mcparallel.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2009-2014 R Core Team
% Distributed under GPL 2 or later

\name{mcparallel}
\alias{mccollect}
\alias{mcparallel}

\title{Evaluate an \R Expression Asynchronously in a Separate Process}
\description{
  これらの関数はフォークに基づいており，従って
  Windows では利用できない．

  \code{mcparallel} は与えられた表現式を評価する並列 \R プロセスを
  開始する．

  \code{mccollect} は一つもしくはそれ以上の並列プロセスから結果を回収する．
}
\usage{
mcparallel(expr, name, mc.set.seed = TRUE, silent = FALSE,
           mc.affinity = NULL, mc.interactive = FALSE,
	   detached = FALSE)

mccollect(jobs, wait = TRUE, timeout = 0, intermediate = FALSE)
}
\arguments{
  \item{expr}{評価する表現式(コード中ではスクリーン使用のデバイスや
    GUI 要素を\emph{使わない}．}
  \item{name}{ジョブに関連付けられるオプションの名前
    (長さ 1 の文字列)．}
  \item{mc.set.seed}{論理値：\sQuote{乱数}節を見よ．}
  \item{silent}{もし \code{TRUE} に設定すると標準出力上の全ての
    出力は抑制される(標準エラーは影響されない)．}
  \item{mc.affinity}{
    子プロセスを制限する CPU を指定する(1-based)数値ベクトル．
    もしくは \code{NULL} ならば CPU のアフィニティーを変更しない．}
  \item{mc.interactive}{論理値，もし \code{TRUE} か \code{FALSE}
    ならば子プロセスはそれぞれ対話的もしくは非対話的とされる．
    もし \code{NA} なら子プロセスは親プロセスから対話フラグを受け継ぐ．}
  \item{detached}{論理値，もし \code{TRUE} なら
    ジョブは現在のセッションから取り除かれ，如何なる結果も
    配送し返せない
    - これは副作用だけのためのコードに対して使われる．}
  \item{jobs}{
    結果を収集する対象のジョブのリスト(又は単一のジョブ)．
    別法として
    \code{jobs} はまたプロセス ID の整数ベクトルでも良い．
    もし省略されると \code{collect} は現在存在する全ての子プロセス
    を待つ．}
  \item{wait}{もし \code{FALSE} に設定すると，これは
    今から \code{timeout} 秒経過以内に利用可能な任意の結果を
    チェックする．さもなければそれは全ての指定されたジョブが
    終了するのを待つ．}
  \item{timeout}{ジョブの結果のチェックの時間切れ(秒単位)．
    \code{wait} が \code{FALSE} の時だけ適用される．}
  \item{intermediate}{\code{FALSE} 又は
    \code{collect} が結果を待つ間に呼び出される関数．
    この関数はこれまで受け取った結果のリストである一つのパラメータ
    と共に呼び出される．}
}
\details{
  \code{mcparallel} は \code{expr} 表現式を
  現在の \R プロセスに対して並列に評価する．
  全てが並列プロセスと現在のプロセスの間で
  読み込み専用(又は実際には copy-on-write で)で共有される，
  つまり表現式の副作用はいずれも主プロセスに影響しない．
  並列実行の結果は \code{mccollect} 関数を用いて収集することが出来る．

  \code{mccollect} 関数は並列ジョブ(又は実際は任意の子プロセス)から
  任意の利用可能な結果を収集する．
  もし \code{wait} が \code{TRUE} ならば
  \code{collect} は
  各ジョブに対する最後に報告された結果を含むリストを返す前に
  全ての指定されたジョブが終了するのを待つ．
  もし \code{wait} が \code{FALSE} ならば \code{mccollect} は
  その時に利用可能な任意の値をチェックするだけで，ジョブが終了するのを
  待たない．
  もし \code{jobs} が指定されると，そこにリストされていない
  ジョブは影響されないし働きかけも受けない．

  ノート：もし \code{expr} が
  \code{\link{sendMaster}} のような低水準の多コア関数を使えば
  一つのジョブは結果を何度も提供するので，
  それらを正確に解釈するのはユーザの責任になる．
  \code{mccollect} は
  その後にはジョブが最早利用できないその結果を送ってしまった
  終了済みジョブに対しては \code{NULL} を返す．

  \code{mc.affinity} パラメータは
  子プロセスを特定の CPU に制限するのに使うことが出来る．
  この特性の利用可能性と程度はシステム依存である
  (例えばある種のシステムは CPU の数だけを考慮し，
  それを全く無視するものもある)．
}
\value{
  \code{mcparallel} は
  クラス
  \code{"parallelJob"} のオブジェクトを返す，これは
  \code{"childProcess"} を継承する
  (\code{\link{mcfork}} に対するヘルプの\sQuote{値}節を見よ)．
  もし引数 \code{name} が提供されているとこれは追加の成分
  \code{name} を持つ．

  \code{mccollect} はリスト中で利用可能な任意の結果を返す．
  結果は指定されたジョブと同じ順序を持つ．
  もし複数のジョブがありジョブが名前を持てばそれが
  結果の名前に使われる．さもなければ
  そのプロセス ID が使われる．
  もし指定された子プロセスがどれも稼働していなければ
  それは \code{NULL} を返す．
}
\section{乱数}{
  もし \code{mc.set.seed = FALSE} ならば子プロセスは現在の \R セッションと
  同じ初期乱数生成器 (RNG) 状態を持つ．
  もし RNG
  (又は \code{.Random.seed} が保存された作業スペースから復元されると)
  が使われていると子プロセスは現在のセッションと
  同じ箇所から乱数抽出を開始する．
  もし RNG がまだ使われていなければ，
  子プロセスはそれが RNG を最初に使うときに時刻とプロセス ID に
  基づいて乱数種を設定する：
  これは現在のセッションや他の子プロセスと異なった乱数ストリームを
  与えることをかなりの程度に保証する．

  \code{mc.set.seed = TRUE} の時の挙動は
  \code{\link{RNGkind}("L'Ecuyer-CMRG")} が選択されている時だけ
  異なる．その時は子プロセスがフォークされる度に
  それに次のストリームが与えられる
  (\code{\link{nextRNGStream}} を見よ)．
  従ってもしその生成器を選び，乱数種を設定しそして
  \code{\link{mc.reset.stream}} を
  \code{mcparallel} の最初の使用の前に呼びだせば，
  シミュレーションの結果は同じ作業が最初，二番目，
  \ldots{} のフォークされたプロセスに与えられる限り
  再生性を持つ．
}

\note{
  Package
  パッケージ \CRANpkg{multicore} はまた
  関数 \code{collect} と \code{parallel} を移出する．
  これらの名前は容易にマスクされる
  (例えばパッケージ \CRANpkg{lattice} は同様に関数 \code{parallel} を持つ)
  のでこのパッケージでは提供されない．
}


\author{
  Simon Urbanek と R Core．

  パッケージ \CRANpkg{multicore} に由来する(しかし
  異なった RNG ストリームを持つ)．
}
\seealso{
  \code{\link{pvec}}, \code{\link{mclapply}}
}
\examples{
p <- mcparallel(1:10)
q <- mcparallel(1:20)
# 両方のジョブが終了するのを待ち，それから全ての結果を集める
res <- mccollect(list(p, q))

p <- mcparallel(1:10)
mccollect(p, wait = FALSE, 10) # 結果を回収する(それは速いので)
mccollect(p, wait = FALSE)     # ジョブに終了シグナルを送る
mccollect(p, wait = FALSE)     # そうしたジョブは最早無い

\dontshow{set.seed(123, "L'Ecuyer"); mc.reset.stream()}
# 素朴な並列 lapply は mcparallel だけを使い作れる：
jobs <- lapply(1:10, function(x) mcparallel(rnorm(x), name = x))
mccollect(jobs)
}
\keyword{interface}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/parallel/man/unix/mcparallel.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2009-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{mcparallel}
%\alias{mccollect}
%\alias{mcparallel}
%
%\title{Evaluate an \R Expression Asynchronously in a Separate Process}
%\description{
%  These functions are based on forking and so are not available on Windows.
%
%  \code{mcparallel} starts a parallel \R process which evaluates the
%  given expression.
%
%  \code{mccollect} collects results from one or more parallel processes.
%}
%\usage{
%mcparallel(expr, name, mc.set.seed = TRUE, silent = FALSE,
%           mc.affinity = NULL, mc.interactive = FALSE,
%	   detached = FALSE)
%
%mccollect(jobs, wait = TRUE, timeout = 0, intermediate = FALSE)
%}
%\arguments{
%  \item{expr}{expression to evaluate (do \emph{not} use any on-screen
%    devices or GUI elements in this code).}
%  \item{name}{an optional name (character vector of length one) that can
%    be associated with the job.}
%  \item{mc.set.seed}{logical: see section \sQuote{Random numbers}.}
%  \item{silent}{if set to \code{TRUE} then all output on stdout will be
%    suppressed (stderr is not affected).}
%  \item{mc.affinity}{either a numeric vector specifying CPUs to restrict
%    the child process to (1-based) or \code{NULL} to not modify the CPU
%    affinity}
%  \item{mc.interactive}{logical, if \code{TRUE} or \code{FALSE} then the
%    child process will be set as interactive or non-interactive
%    respectively. If \code{NA} then the child process will inherit the
%    interactive flag from the parent.}
%  \item{detached}{logical, if \code{TRUE} then the job is detached from
%    the current session and cannot deliver any results back - it is used
%    for the code side-effect only.}
%  \item{jobs}{list of jobs (or a single job) to collect results
%    for.  Alternatively \code{jobs} can also be an integer vector of
%    process IDs.  If omitted \code{collect} will wait for all currently
%    existing children.}
%  \item{wait}{if set to \code{FALSE} it checks for any results that are
%    available within \code{timeout} seconds from now, otherwise it waits
%    for all specified jobs to finish.}
%  \item{timeout}{timeout (in seconds) to check for job results -- applies
%    only if \code{wait} is \code{FALSE}.}
%  \item{intermediate}{\code{FALSE} or a function which will be called while
%    \code{collect} waits for results.  The function will be called with one
%    parameter which is the list of results received so far.}
%}
%\details{
%  \code{mcparallel} evaluates the \code{expr} expression in parallel to
%  the current \R process.  Everything is shared read-only (or in fact
%  copy-on-write) between the parallel process and the current process,
%  i.e.\sspace{}no side-effects of the expression affect the main process.  The
%  result of the parallel execution can be collected using
%  \code{mccollect} function.
%
%  \code{mccollect} function collects any available results from parallel
%  jobs (or in fact any child process).  If \code{wait} is \code{TRUE}
%  then \code{collect} waits for all specified jobs to finish before
%  returning a list containing the last reported result for each
%  job.   If \code{wait} is \code{FALSE} then \code{mccollect} merely
%  checks for any results available at the moment and will not wait for
%  jobs to finish.   If \code{jobs} is specified, jobs not listed there
%  will not be affected or acted upon.
%
%  Note: If \code{expr} uses low-level multicore functions such
%  as \code{\link{sendMaster}} a single job can deliver results
%  multiple times and it is the responsibility of the user to interpret
%  them correctly.  \code{mccollect} will return \code{NULL} for a
%  terminating job that has sent its results already after which the
%  job is no longer available.
%
%  The \code{mc.affinity} parameter can be used to try to restrict
%  the child process to specific CPUs. The availability and the extent of
%  this feature is system-dependent (e.g., some systems will only
%  consider the CPU count, others will ignore it completely).
%}
%\value{
%  \code{mcparallel} returns an object of the class \code{"parallelJob"}
%  which inherits from \code{"childProcess"} (see the \sQuote{Value}
%  section of the help for \code{\link{mcfork}}).  If argument
%  \code{name} was supplied this will have an additional component
%  \code{name}.
%
%  \code{mccollect} returns any results that are available in a list.  The
%  results will have the same order as the specified jobs.  If there are
%  multiple jobs and a job has a name it will be used to name the
%  result, otherwise its process ID will be used.  If none of the
%  specified children are still running, it returns \code{NULL}.
%}
%\section{Random numbers}{
%  If \code{mc.set.seed = FALSE}, the child process has the same initial
%  random number generator (RNG) state as the current \R session.  If the
%  RNG has been used (or \code{.Random.seed} was restored from a saved
%  workspace), the child will start drawing random numbers at the same
%  point as the current session.  If the RNG has not yet been used, the
%  child will set a seed based on the time and process ID when it first
%  uses the RNG: this is pretty much guaranteed to give a different
%  random-number stream from the current session and any other child
%  process.
%
%  The behaviour with \code{mc.set.seed = TRUE} is different only if
%  \code{\link{RNGkind}("L'Ecuyer-CMRG")} has been selected.  Then each
%  time a child is forked it is given the next stream (see
%  \code{\link{nextRNGStream}}).  So if you select that generator, set a
%  seed and call \code{\link{mc.reset.stream}} just before the first use
%  of \code{mcparallel} the results of simulations will be reproducible
%  provided the same tasks are given to the first, second, \ldots{}
%  forked process.
%}
%
%\note{
%  Package \CRANpkg{multicore} also exported functions \code{collect} and
%  \code{parallel}.  These names are easily masked (for example package
%  \CRANpkg{lattice} also has a function \code{parallel}) and they are not
%  supplied in this package.
%}
%
%
%\author{
%  Simon Urbanek and R Core.
%
%  Derived from the \CRANpkg{multicore} package (but with different
%  handling of the RNG stream).
%}
%\seealso{
%  \code{\link{pvec}}, \code{\link{mclapply}}
%}
%\examples{
%p <- mcparallel(1:10)
%q <- mcparallel(1:20)
%# wait for both jobs to finish and collect all results
%res <- mccollect(list(p, q))
%
%p <- mcparallel(1:10)
%mccollect(p, wait = FALSE, 10) # will retrieve the result (since it's fast)
%mccollect(p, wait = FALSE)     # will signal the job as terminating
%mccollect(p, wait = FALSE)     # there is no longer such a job
%
%\dontshow{set.seed(123, "L'Ecuyer"); mc.reset.stream()}
%# a naive parallel lapply can be created using mcparallel alone:
%jobs <- lapply(1:10, function(x) mcparallel(rnorm(x), name = x))
%mccollect(jobs)
%}
%\keyword{interface}
%
%\encoding{UTF-8}
%